/* Generated by ./src/xlat/gen.sh from ./src/xlat/evdev_keycode.in; do not edit. */

#include "gcc_compat.h"
#include "static_assert.h"

#undef XLAT_PREV_VAL

#ifndef XLAT_MACROS_ONLY

# ifdef IN_MPERS

#  error static const struct xlat evdev_keycode in mpers mode

# else

DIAG_PUSH_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE
static const struct xlat_data evdev_keycode_xdata[] = {

 [KEY_RESERVED] = XLAT(KEY_RESERVED),
 #define XLAT_VAL_0 ((unsigned) (KEY_RESERVED))
 #define XLAT_STR_0 STRINGIFY(KEY_RESERVED)
 [KEY_ESC] = XLAT(KEY_ESC),
 #define XLAT_VAL_1 ((unsigned) (KEY_ESC))
 #define XLAT_STR_1 STRINGIFY(KEY_ESC)
 [KEY_1] = XLAT(KEY_1),
 #define XLAT_VAL_2 ((unsigned) (KEY_1))
 #define XLAT_STR_2 STRINGIFY(KEY_1)
 [KEY_2] = XLAT(KEY_2),
 #define XLAT_VAL_3 ((unsigned) (KEY_2))
 #define XLAT_STR_3 STRINGIFY(KEY_2)
 [KEY_3] = XLAT(KEY_3),
 #define XLAT_VAL_4 ((unsigned) (KEY_3))
 #define XLAT_STR_4 STRINGIFY(KEY_3)
 [KEY_4] = XLAT(KEY_4),
 #define XLAT_VAL_5 ((unsigned) (KEY_4))
 #define XLAT_STR_5 STRINGIFY(KEY_4)
 [KEY_5] = XLAT(KEY_5),
 #define XLAT_VAL_6 ((unsigned) (KEY_5))
 #define XLAT_STR_6 STRINGIFY(KEY_5)
 [KEY_6] = XLAT(KEY_6),
 #define XLAT_VAL_7 ((unsigned) (KEY_6))
 #define XLAT_STR_7 STRINGIFY(KEY_6)
 [KEY_7] = XLAT(KEY_7),
 #define XLAT_VAL_8 ((unsigned) (KEY_7))
 #define XLAT_STR_8 STRINGIFY(KEY_7)
 [KEY_8] = XLAT(KEY_8),
 #define XLAT_VAL_9 ((unsigned) (KEY_8))
 #define XLAT_STR_9 STRINGIFY(KEY_8)
 [KEY_9] = XLAT(KEY_9),
 #define XLAT_VAL_10 ((unsigned) (KEY_9))
 #define XLAT_STR_10 STRINGIFY(KEY_9)
 [KEY_0] = XLAT(KEY_0),
 #define XLAT_VAL_11 ((unsigned) (KEY_0))
 #define XLAT_STR_11 STRINGIFY(KEY_0)
 [KEY_MINUS] = XLAT(KEY_MINUS),
 #define XLAT_VAL_12 ((unsigned) (KEY_MINUS))
 #define XLAT_STR_12 STRINGIFY(KEY_MINUS)
 [KEY_EQUAL] = XLAT(KEY_EQUAL),
 #define XLAT_VAL_13 ((unsigned) (KEY_EQUAL))
 #define XLAT_STR_13 STRINGIFY(KEY_EQUAL)
 [KEY_BACKSPACE] = XLAT(KEY_BACKSPACE),
 #define XLAT_VAL_14 ((unsigned) (KEY_BACKSPACE))
 #define XLAT_STR_14 STRINGIFY(KEY_BACKSPACE)
 [KEY_TAB] = XLAT(KEY_TAB),
 #define XLAT_VAL_15 ((unsigned) (KEY_TAB))
 #define XLAT_STR_15 STRINGIFY(KEY_TAB)
 [KEY_Q] = XLAT(KEY_Q),
 #define XLAT_VAL_16 ((unsigned) (KEY_Q))
 #define XLAT_STR_16 STRINGIFY(KEY_Q)
 [KEY_W] = XLAT(KEY_W),
 #define XLAT_VAL_17 ((unsigned) (KEY_W))
 #define XLAT_STR_17 STRINGIFY(KEY_W)
 [KEY_E] = XLAT(KEY_E),
 #define XLAT_VAL_18 ((unsigned) (KEY_E))
 #define XLAT_STR_18 STRINGIFY(KEY_E)
 [KEY_R] = XLAT(KEY_R),
 #define XLAT_VAL_19 ((unsigned) (KEY_R))
 #define XLAT_STR_19 STRINGIFY(KEY_R)
 [KEY_T] = XLAT(KEY_T),
 #define XLAT_VAL_20 ((unsigned) (KEY_T))
 #define XLAT_STR_20 STRINGIFY(KEY_T)
 [KEY_Y] = XLAT(KEY_Y),
 #define XLAT_VAL_21 ((unsigned) (KEY_Y))
 #define XLAT_STR_21 STRINGIFY(KEY_Y)
 [KEY_U] = XLAT(KEY_U),
 #define XLAT_VAL_22 ((unsigned) (KEY_U))
 #define XLAT_STR_22 STRINGIFY(KEY_U)
 [KEY_I] = XLAT(KEY_I),
 #define XLAT_VAL_23 ((unsigned) (KEY_I))
 #define XLAT_STR_23 STRINGIFY(KEY_I)
 [KEY_O] = XLAT(KEY_O),
 #define XLAT_VAL_24 ((unsigned) (KEY_O))
 #define XLAT_STR_24 STRINGIFY(KEY_O)
 [KEY_P] = XLAT(KEY_P),
 #define XLAT_VAL_25 ((unsigned) (KEY_P))
 #define XLAT_STR_25 STRINGIFY(KEY_P)
 [KEY_LEFTBRACE] = XLAT(KEY_LEFTBRACE),
 #define XLAT_VAL_26 ((unsigned) (KEY_LEFTBRACE))
 #define XLAT_STR_26 STRINGIFY(KEY_LEFTBRACE)
 [KEY_RIGHTBRACE] = XLAT(KEY_RIGHTBRACE),
 #define XLAT_VAL_27 ((unsigned) (KEY_RIGHTBRACE))
 #define XLAT_STR_27 STRINGIFY(KEY_RIGHTBRACE)
 [KEY_ENTER] = XLAT(KEY_ENTER),
 #define XLAT_VAL_28 ((unsigned) (KEY_ENTER))
 #define XLAT_STR_28 STRINGIFY(KEY_ENTER)
 [KEY_LEFTCTRL] = XLAT(KEY_LEFTCTRL),
 #define XLAT_VAL_29 ((unsigned) (KEY_LEFTCTRL))
 #define XLAT_STR_29 STRINGIFY(KEY_LEFTCTRL)
 [KEY_A] = XLAT(KEY_A),
 #define XLAT_VAL_30 ((unsigned) (KEY_A))
 #define XLAT_STR_30 STRINGIFY(KEY_A)
 [KEY_S] = XLAT(KEY_S),
 #define XLAT_VAL_31 ((unsigned) (KEY_S))
 #define XLAT_STR_31 STRINGIFY(KEY_S)
 [KEY_D] = XLAT(KEY_D),
 #define XLAT_VAL_32 ((unsigned) (KEY_D))
 #define XLAT_STR_32 STRINGIFY(KEY_D)
 [KEY_F] = XLAT(KEY_F),
 #define XLAT_VAL_33 ((unsigned) (KEY_F))
 #define XLAT_STR_33 STRINGIFY(KEY_F)
 [KEY_G] = XLAT(KEY_G),
 #define XLAT_VAL_34 ((unsigned) (KEY_G))
 #define XLAT_STR_34 STRINGIFY(KEY_G)
 [KEY_H] = XLAT(KEY_H),
 #define XLAT_VAL_35 ((unsigned) (KEY_H))
 #define XLAT_STR_35 STRINGIFY(KEY_H)
 [KEY_J] = XLAT(KEY_J),
 #define XLAT_VAL_36 ((unsigned) (KEY_J))
 #define XLAT_STR_36 STRINGIFY(KEY_J)
 [KEY_K] = XLAT(KEY_K),
 #define XLAT_VAL_37 ((unsigned) (KEY_K))
 #define XLAT_STR_37 STRINGIFY(KEY_K)
 [KEY_L] = XLAT(KEY_L),
 #define XLAT_VAL_38 ((unsigned) (KEY_L))
 #define XLAT_STR_38 STRINGIFY(KEY_L)
 [KEY_SEMICOLON] = XLAT(KEY_SEMICOLON),
 #define XLAT_VAL_39 ((unsigned) (KEY_SEMICOLON))
 #define XLAT_STR_39 STRINGIFY(KEY_SEMICOLON)
 [KEY_APOSTROPHE] = XLAT(KEY_APOSTROPHE),
 #define XLAT_VAL_40 ((unsigned) (KEY_APOSTROPHE))
 #define XLAT_STR_40 STRINGIFY(KEY_APOSTROPHE)
 [KEY_GRAVE] = XLAT(KEY_GRAVE),
 #define XLAT_VAL_41 ((unsigned) (KEY_GRAVE))
 #define XLAT_STR_41 STRINGIFY(KEY_GRAVE)
 [KEY_LEFTSHIFT] = XLAT(KEY_LEFTSHIFT),
 #define XLAT_VAL_42 ((unsigned) (KEY_LEFTSHIFT))
 #define XLAT_STR_42 STRINGIFY(KEY_LEFTSHIFT)
 [KEY_BACKSLASH] = XLAT(KEY_BACKSLASH),
 #define XLAT_VAL_43 ((unsigned) (KEY_BACKSLASH))
 #define XLAT_STR_43 STRINGIFY(KEY_BACKSLASH)
 [KEY_Z] = XLAT(KEY_Z),
 #define XLAT_VAL_44 ((unsigned) (KEY_Z))
 #define XLAT_STR_44 STRINGIFY(KEY_Z)
 [KEY_X] = XLAT(KEY_X),
 #define XLAT_VAL_45 ((unsigned) (KEY_X))
 #define XLAT_STR_45 STRINGIFY(KEY_X)
 [KEY_C] = XLAT(KEY_C),
 #define XLAT_VAL_46 ((unsigned) (KEY_C))
 #define XLAT_STR_46 STRINGIFY(KEY_C)
 [KEY_V] = XLAT(KEY_V),
 #define XLAT_VAL_47 ((unsigned) (KEY_V))
 #define XLAT_STR_47 STRINGIFY(KEY_V)
 [KEY_B] = XLAT(KEY_B),
 #define XLAT_VAL_48 ((unsigned) (KEY_B))
 #define XLAT_STR_48 STRINGIFY(KEY_B)
 [KEY_N] = XLAT(KEY_N),
 #define XLAT_VAL_49 ((unsigned) (KEY_N))
 #define XLAT_STR_49 STRINGIFY(KEY_N)
 [KEY_M] = XLAT(KEY_M),
 #define XLAT_VAL_50 ((unsigned) (KEY_M))
 #define XLAT_STR_50 STRINGIFY(KEY_M)
 [KEY_COMMA] = XLAT(KEY_COMMA),
 #define XLAT_VAL_51 ((unsigned) (KEY_COMMA))
 #define XLAT_STR_51 STRINGIFY(KEY_COMMA)
 [KEY_DOT] = XLAT(KEY_DOT),
 #define XLAT_VAL_52 ((unsigned) (KEY_DOT))
 #define XLAT_STR_52 STRINGIFY(KEY_DOT)
 [KEY_SLASH] = XLAT(KEY_SLASH),
 #define XLAT_VAL_53 ((unsigned) (KEY_SLASH))
 #define XLAT_STR_53 STRINGIFY(KEY_SLASH)
 [KEY_RIGHTSHIFT] = XLAT(KEY_RIGHTSHIFT),
 #define XLAT_VAL_54 ((unsigned) (KEY_RIGHTSHIFT))
 #define XLAT_STR_54 STRINGIFY(KEY_RIGHTSHIFT)
 [KEY_KPASTERISK] = XLAT(KEY_KPASTERISK),
 #define XLAT_VAL_55 ((unsigned) (KEY_KPASTERISK))
 #define XLAT_STR_55 STRINGIFY(KEY_KPASTERISK)
 [KEY_LEFTALT] = XLAT(KEY_LEFTALT),
 #define XLAT_VAL_56 ((unsigned) (KEY_LEFTALT))
 #define XLAT_STR_56 STRINGIFY(KEY_LEFTALT)
 [KEY_SPACE] = XLAT(KEY_SPACE),
 #define XLAT_VAL_57 ((unsigned) (KEY_SPACE))
 #define XLAT_STR_57 STRINGIFY(KEY_SPACE)
 [KEY_CAPSLOCK] = XLAT(KEY_CAPSLOCK),
 #define XLAT_VAL_58 ((unsigned) (KEY_CAPSLOCK))
 #define XLAT_STR_58 STRINGIFY(KEY_CAPSLOCK)
 [KEY_F1] = XLAT(KEY_F1),
 #define XLAT_VAL_59 ((unsigned) (KEY_F1))
 #define XLAT_STR_59 STRINGIFY(KEY_F1)
 [KEY_F2] = XLAT(KEY_F2),
 #define XLAT_VAL_60 ((unsigned) (KEY_F2))
 #define XLAT_STR_60 STRINGIFY(KEY_F2)
 [KEY_F3] = XLAT(KEY_F3),
 #define XLAT_VAL_61 ((unsigned) (KEY_F3))
 #define XLAT_STR_61 STRINGIFY(KEY_F3)
 [KEY_F4] = XLAT(KEY_F4),
 #define XLAT_VAL_62 ((unsigned) (KEY_F4))
 #define XLAT_STR_62 STRINGIFY(KEY_F4)
 [KEY_F5] = XLAT(KEY_F5),
 #define XLAT_VAL_63 ((unsigned) (KEY_F5))
 #define XLAT_STR_63 STRINGIFY(KEY_F5)
 [KEY_F6] = XLAT(KEY_F6),
 #define XLAT_VAL_64 ((unsigned) (KEY_F6))
 #define XLAT_STR_64 STRINGIFY(KEY_F6)
 [KEY_F7] = XLAT(KEY_F7),
 #define XLAT_VAL_65 ((unsigned) (KEY_F7))
 #define XLAT_STR_65 STRINGIFY(KEY_F7)
 [KEY_F8] = XLAT(KEY_F8),
 #define XLAT_VAL_66 ((unsigned) (KEY_F8))
 #define XLAT_STR_66 STRINGIFY(KEY_F8)
 [KEY_F9] = XLAT(KEY_F9),
 #define XLAT_VAL_67 ((unsigned) (KEY_F9))
 #define XLAT_STR_67 STRINGIFY(KEY_F9)
 [KEY_F10] = XLAT(KEY_F10),
 #define XLAT_VAL_68 ((unsigned) (KEY_F10))
 #define XLAT_STR_68 STRINGIFY(KEY_F10)
 [KEY_NUMLOCK] = XLAT(KEY_NUMLOCK),
 #define XLAT_VAL_69 ((unsigned) (KEY_NUMLOCK))
 #define XLAT_STR_69 STRINGIFY(KEY_NUMLOCK)
 [KEY_SCROLLLOCK] = XLAT(KEY_SCROLLLOCK),
 #define XLAT_VAL_70 ((unsigned) (KEY_SCROLLLOCK))
 #define XLAT_STR_70 STRINGIFY(KEY_SCROLLLOCK)
 [KEY_KP7] = XLAT(KEY_KP7),
 #define XLAT_VAL_71 ((unsigned) (KEY_KP7))
 #define XLAT_STR_71 STRINGIFY(KEY_KP7)
 [KEY_KP8] = XLAT(KEY_KP8),
 #define XLAT_VAL_72 ((unsigned) (KEY_KP8))
 #define XLAT_STR_72 STRINGIFY(KEY_KP8)
 [KEY_KP9] = XLAT(KEY_KP9),
 #define XLAT_VAL_73 ((unsigned) (KEY_KP9))
 #define XLAT_STR_73 STRINGIFY(KEY_KP9)
 [KEY_KPMINUS] = XLAT(KEY_KPMINUS),
 #define XLAT_VAL_74 ((unsigned) (KEY_KPMINUS))
 #define XLAT_STR_74 STRINGIFY(KEY_KPMINUS)
 [KEY_KP4] = XLAT(KEY_KP4),
 #define XLAT_VAL_75 ((unsigned) (KEY_KP4))
 #define XLAT_STR_75 STRINGIFY(KEY_KP4)
 [KEY_KP5] = XLAT(KEY_KP5),
 #define XLAT_VAL_76 ((unsigned) (KEY_KP5))
 #define XLAT_STR_76 STRINGIFY(KEY_KP5)
 [KEY_KP6] = XLAT(KEY_KP6),
 #define XLAT_VAL_77 ((unsigned) (KEY_KP6))
 #define XLAT_STR_77 STRINGIFY(KEY_KP6)
 [KEY_KPPLUS] = XLAT(KEY_KPPLUS),
 #define XLAT_VAL_78 ((unsigned) (KEY_KPPLUS))
 #define XLAT_STR_78 STRINGIFY(KEY_KPPLUS)
 [KEY_KP1] = XLAT(KEY_KP1),
 #define XLAT_VAL_79 ((unsigned) (KEY_KP1))
 #define XLAT_STR_79 STRINGIFY(KEY_KP1)
 [KEY_KP2] = XLAT(KEY_KP2),
 #define XLAT_VAL_80 ((unsigned) (KEY_KP2))
 #define XLAT_STR_80 STRINGIFY(KEY_KP2)
 [KEY_KP3] = XLAT(KEY_KP3),
 #define XLAT_VAL_81 ((unsigned) (KEY_KP3))
 #define XLAT_STR_81 STRINGIFY(KEY_KP3)
 [KEY_KP0] = XLAT(KEY_KP0),
 #define XLAT_VAL_82 ((unsigned) (KEY_KP0))
 #define XLAT_STR_82 STRINGIFY(KEY_KP0)
 [KEY_KPDOT] = XLAT(KEY_KPDOT),
 #define XLAT_VAL_83 ((unsigned) (KEY_KPDOT))
 #define XLAT_STR_83 STRINGIFY(KEY_KPDOT)

 [KEY_ZENKAKUHANKAKU] = XLAT(KEY_ZENKAKUHANKAKU),
 #define XLAT_VAL_84 ((unsigned) (KEY_ZENKAKUHANKAKU))
 #define XLAT_STR_84 STRINGIFY(KEY_ZENKAKUHANKAKU)
 [KEY_102ND] = XLAT(KEY_102ND),
 #define XLAT_VAL_85 ((unsigned) (KEY_102ND))
 #define XLAT_STR_85 STRINGIFY(KEY_102ND)
 [KEY_F11] = XLAT(KEY_F11),
 #define XLAT_VAL_86 ((unsigned) (KEY_F11))
 #define XLAT_STR_86 STRINGIFY(KEY_F11)
 [KEY_F12] = XLAT(KEY_F12),
 #define XLAT_VAL_87 ((unsigned) (KEY_F12))
 #define XLAT_STR_87 STRINGIFY(KEY_F12)
 [KEY_RO] = XLAT(KEY_RO),
 #define XLAT_VAL_88 ((unsigned) (KEY_RO))
 #define XLAT_STR_88 STRINGIFY(KEY_RO)
 [KEY_KATAKANA] = XLAT(KEY_KATAKANA),
 #define XLAT_VAL_89 ((unsigned) (KEY_KATAKANA))
 #define XLAT_STR_89 STRINGIFY(KEY_KATAKANA)
 [KEY_HIRAGANA] = XLAT(KEY_HIRAGANA),
 #define XLAT_VAL_90 ((unsigned) (KEY_HIRAGANA))
 #define XLAT_STR_90 STRINGIFY(KEY_HIRAGANA)
 [KEY_HENKAN] = XLAT(KEY_HENKAN),
 #define XLAT_VAL_91 ((unsigned) (KEY_HENKAN))
 #define XLAT_STR_91 STRINGIFY(KEY_HENKAN)
 [KEY_KATAKANAHIRAGANA] = XLAT(KEY_KATAKANAHIRAGANA),
 #define XLAT_VAL_92 ((unsigned) (KEY_KATAKANAHIRAGANA))
 #define XLAT_STR_92 STRINGIFY(KEY_KATAKANAHIRAGANA)
 [KEY_MUHENKAN] = XLAT(KEY_MUHENKAN),
 #define XLAT_VAL_93 ((unsigned) (KEY_MUHENKAN))
 #define XLAT_STR_93 STRINGIFY(KEY_MUHENKAN)
 [KEY_KPJPCOMMA] = XLAT(KEY_KPJPCOMMA),
 #define XLAT_VAL_94 ((unsigned) (KEY_KPJPCOMMA))
 #define XLAT_STR_94 STRINGIFY(KEY_KPJPCOMMA)
 [KEY_KPENTER] = XLAT(KEY_KPENTER),
 #define XLAT_VAL_95 ((unsigned) (KEY_KPENTER))
 #define XLAT_STR_95 STRINGIFY(KEY_KPENTER)
 [KEY_RIGHTCTRL] = XLAT(KEY_RIGHTCTRL),
 #define XLAT_VAL_96 ((unsigned) (KEY_RIGHTCTRL))
 #define XLAT_STR_96 STRINGIFY(KEY_RIGHTCTRL)
 [KEY_KPSLASH] = XLAT(KEY_KPSLASH),
 #define XLAT_VAL_97 ((unsigned) (KEY_KPSLASH))
 #define XLAT_STR_97 STRINGIFY(KEY_KPSLASH)
 [KEY_SYSRQ] = XLAT(KEY_SYSRQ),
 #define XLAT_VAL_98 ((unsigned) (KEY_SYSRQ))
 #define XLAT_STR_98 STRINGIFY(KEY_SYSRQ)
 [KEY_RIGHTALT] = XLAT(KEY_RIGHTALT),
 #define XLAT_VAL_99 ((unsigned) (KEY_RIGHTALT))
 #define XLAT_STR_99 STRINGIFY(KEY_RIGHTALT)
 [KEY_LINEFEED] = XLAT(KEY_LINEFEED),
 #define XLAT_VAL_100 ((unsigned) (KEY_LINEFEED))
 #define XLAT_STR_100 STRINGIFY(KEY_LINEFEED)
 [KEY_HOME] = XLAT(KEY_HOME),
 #define XLAT_VAL_101 ((unsigned) (KEY_HOME))
 #define XLAT_STR_101 STRINGIFY(KEY_HOME)
 [KEY_UP] = XLAT(KEY_UP),
 #define XLAT_VAL_102 ((unsigned) (KEY_UP))
 #define XLAT_STR_102 STRINGIFY(KEY_UP)
 [KEY_PAGEUP] = XLAT(KEY_PAGEUP),
 #define XLAT_VAL_103 ((unsigned) (KEY_PAGEUP))
 #define XLAT_STR_103 STRINGIFY(KEY_PAGEUP)
 [KEY_LEFT] = XLAT(KEY_LEFT),
 #define XLAT_VAL_104 ((unsigned) (KEY_LEFT))
 #define XLAT_STR_104 STRINGIFY(KEY_LEFT)
 [KEY_RIGHT] = XLAT(KEY_RIGHT),
 #define XLAT_VAL_105 ((unsigned) (KEY_RIGHT))
 #define XLAT_STR_105 STRINGIFY(KEY_RIGHT)
 [KEY_END] = XLAT(KEY_END),
 #define XLAT_VAL_106 ((unsigned) (KEY_END))
 #define XLAT_STR_106 STRINGIFY(KEY_END)
 [KEY_DOWN] = XLAT(KEY_DOWN),
 #define XLAT_VAL_107 ((unsigned) (KEY_DOWN))
 #define XLAT_STR_107 STRINGIFY(KEY_DOWN)
 [KEY_PAGEDOWN] = XLAT(KEY_PAGEDOWN),
 #define XLAT_VAL_108 ((unsigned) (KEY_PAGEDOWN))
 #define XLAT_STR_108 STRINGIFY(KEY_PAGEDOWN)
 [KEY_INSERT] = XLAT(KEY_INSERT),
 #define XLAT_VAL_109 ((unsigned) (KEY_INSERT))
 #define XLAT_STR_109 STRINGIFY(KEY_INSERT)
 [KEY_DELETE] = XLAT(KEY_DELETE),
 #define XLAT_VAL_110 ((unsigned) (KEY_DELETE))
 #define XLAT_STR_110 STRINGIFY(KEY_DELETE)
 [KEY_MACRO] = XLAT(KEY_MACRO),
 #define XLAT_VAL_111 ((unsigned) (KEY_MACRO))
 #define XLAT_STR_111 STRINGIFY(KEY_MACRO)
 [KEY_MUTE] = XLAT(KEY_MUTE),
 #define XLAT_VAL_112 ((unsigned) (KEY_MUTE))
 #define XLAT_STR_112 STRINGIFY(KEY_MUTE)
 [KEY_VOLUMEDOWN] = XLAT(KEY_VOLUMEDOWN),
 #define XLAT_VAL_113 ((unsigned) (KEY_VOLUMEDOWN))
 #define XLAT_STR_113 STRINGIFY(KEY_VOLUMEDOWN)
 [KEY_VOLUMEUP] = XLAT(KEY_VOLUMEUP),
 #define XLAT_VAL_114 ((unsigned) (KEY_VOLUMEUP))
 #define XLAT_STR_114 STRINGIFY(KEY_VOLUMEUP)
 [KEY_POWER] = XLAT(KEY_POWER),
 #define XLAT_VAL_115 ((unsigned) (KEY_POWER))
 #define XLAT_STR_115 STRINGIFY(KEY_POWER)
 [KEY_KPEQUAL] = XLAT(KEY_KPEQUAL),
 #define XLAT_VAL_116 ((unsigned) (KEY_KPEQUAL))
 #define XLAT_STR_116 STRINGIFY(KEY_KPEQUAL)
 [KEY_KPPLUSMINUS] = XLAT(KEY_KPPLUSMINUS),
 #define XLAT_VAL_117 ((unsigned) (KEY_KPPLUSMINUS))
 #define XLAT_STR_117 STRINGIFY(KEY_KPPLUSMINUS)
 [KEY_PAUSE] = XLAT(KEY_PAUSE),
 #define XLAT_VAL_118 ((unsigned) (KEY_PAUSE))
 #define XLAT_STR_118 STRINGIFY(KEY_PAUSE)
 [KEY_SCALE] = XLAT(KEY_SCALE),
 #define XLAT_VAL_119 ((unsigned) (KEY_SCALE))
 #define XLAT_STR_119 STRINGIFY(KEY_SCALE)

 [KEY_KPCOMMA] = XLAT(KEY_KPCOMMA),
 #define XLAT_VAL_120 ((unsigned) (KEY_KPCOMMA))
 #define XLAT_STR_120 STRINGIFY(KEY_KPCOMMA)
 [KEY_HANGEUL] = XLAT(KEY_HANGEUL),
 #define XLAT_VAL_121 ((unsigned) (KEY_HANGEUL))
 #define XLAT_STR_121 STRINGIFY(KEY_HANGEUL)
 [KEY_HANJA] = XLAT(KEY_HANJA),
 #define XLAT_VAL_122 ((unsigned) (KEY_HANJA))
 #define XLAT_STR_122 STRINGIFY(KEY_HANJA)
 [KEY_YEN] = XLAT(KEY_YEN),
 #define XLAT_VAL_123 ((unsigned) (KEY_YEN))
 #define XLAT_STR_123 STRINGIFY(KEY_YEN)
 [KEY_LEFTMETA] = XLAT(KEY_LEFTMETA),
 #define XLAT_VAL_124 ((unsigned) (KEY_LEFTMETA))
 #define XLAT_STR_124 STRINGIFY(KEY_LEFTMETA)
 [KEY_RIGHTMETA] = XLAT(KEY_RIGHTMETA),
 #define XLAT_VAL_125 ((unsigned) (KEY_RIGHTMETA))
 #define XLAT_STR_125 STRINGIFY(KEY_RIGHTMETA)
 [KEY_COMPOSE] = XLAT(KEY_COMPOSE),
 #define XLAT_VAL_126 ((unsigned) (KEY_COMPOSE))
 #define XLAT_STR_126 STRINGIFY(KEY_COMPOSE)

 [KEY_STOP] = XLAT(KEY_STOP),
 #define XLAT_VAL_127 ((unsigned) (KEY_STOP))
 #define XLAT_STR_127 STRINGIFY(KEY_STOP)
 [KEY_AGAIN] = XLAT(KEY_AGAIN),
 #define XLAT_VAL_128 ((unsigned) (KEY_AGAIN))
 #define XLAT_STR_128 STRINGIFY(KEY_AGAIN)
 [KEY_PROPS] = XLAT(KEY_PROPS),
 #define XLAT_VAL_129 ((unsigned) (KEY_PROPS))
 #define XLAT_STR_129 STRINGIFY(KEY_PROPS)
 [KEY_UNDO] = XLAT(KEY_UNDO),
 #define XLAT_VAL_130 ((unsigned) (KEY_UNDO))
 #define XLAT_STR_130 STRINGIFY(KEY_UNDO)
 [KEY_FRONT] = XLAT(KEY_FRONT),
 #define XLAT_VAL_131 ((unsigned) (KEY_FRONT))
 #define XLAT_STR_131 STRINGIFY(KEY_FRONT)
 [KEY_COPY] = XLAT(KEY_COPY),
 #define XLAT_VAL_132 ((unsigned) (KEY_COPY))
 #define XLAT_STR_132 STRINGIFY(KEY_COPY)
 [KEY_OPEN] = XLAT(KEY_OPEN),
 #define XLAT_VAL_133 ((unsigned) (KEY_OPEN))
 #define XLAT_STR_133 STRINGIFY(KEY_OPEN)
 [KEY_PASTE] = XLAT(KEY_PASTE),
 #define XLAT_VAL_134 ((unsigned) (KEY_PASTE))
 #define XLAT_STR_134 STRINGIFY(KEY_PASTE)
 [KEY_FIND] = XLAT(KEY_FIND),
 #define XLAT_VAL_135 ((unsigned) (KEY_FIND))
 #define XLAT_STR_135 STRINGIFY(KEY_FIND)
 [KEY_CUT] = XLAT(KEY_CUT),
 #define XLAT_VAL_136 ((unsigned) (KEY_CUT))
 #define XLAT_STR_136 STRINGIFY(KEY_CUT)
 [KEY_HELP] = XLAT(KEY_HELP),
 #define XLAT_VAL_137 ((unsigned) (KEY_HELP))
 #define XLAT_STR_137 STRINGIFY(KEY_HELP)
 [KEY_MENU] = XLAT(KEY_MENU),
 #define XLAT_VAL_138 ((unsigned) (KEY_MENU))
 #define XLAT_STR_138 STRINGIFY(KEY_MENU)
 [KEY_CALC] = XLAT(KEY_CALC),
 #define XLAT_VAL_139 ((unsigned) (KEY_CALC))
 #define XLAT_STR_139 STRINGIFY(KEY_CALC)
 [KEY_SETUP] = XLAT(KEY_SETUP),
 #define XLAT_VAL_140 ((unsigned) (KEY_SETUP))
 #define XLAT_STR_140 STRINGIFY(KEY_SETUP)
 [KEY_SLEEP] = XLAT(KEY_SLEEP),
 #define XLAT_VAL_141 ((unsigned) (KEY_SLEEP))
 #define XLAT_STR_141 STRINGIFY(KEY_SLEEP)
 [KEY_WAKEUP] = XLAT(KEY_WAKEUP),
 #define XLAT_VAL_142 ((unsigned) (KEY_WAKEUP))
 #define XLAT_STR_142 STRINGIFY(KEY_WAKEUP)
 [KEY_FILE] = XLAT(KEY_FILE),
 #define XLAT_VAL_143 ((unsigned) (KEY_FILE))
 #define XLAT_STR_143 STRINGIFY(KEY_FILE)
 [KEY_SENDFILE] = XLAT(KEY_SENDFILE),
 #define XLAT_VAL_144 ((unsigned) (KEY_SENDFILE))
 #define XLAT_STR_144 STRINGIFY(KEY_SENDFILE)
 [KEY_DELETEFILE] = XLAT(KEY_DELETEFILE),
 #define XLAT_VAL_145 ((unsigned) (KEY_DELETEFILE))
 #define XLAT_STR_145 STRINGIFY(KEY_DELETEFILE)
 [KEY_XFER] = XLAT(KEY_XFER),
 #define XLAT_VAL_146 ((unsigned) (KEY_XFER))
 #define XLAT_STR_146 STRINGIFY(KEY_XFER)
 [KEY_PROG1] = XLAT(KEY_PROG1),
 #define XLAT_VAL_147 ((unsigned) (KEY_PROG1))
 #define XLAT_STR_147 STRINGIFY(KEY_PROG1)
 [KEY_PROG2] = XLAT(KEY_PROG2),
 #define XLAT_VAL_148 ((unsigned) (KEY_PROG2))
 #define XLAT_STR_148 STRINGIFY(KEY_PROG2)
 [KEY_WWW] = XLAT(KEY_WWW),
 #define XLAT_VAL_149 ((unsigned) (KEY_WWW))
 #define XLAT_STR_149 STRINGIFY(KEY_WWW)
 [KEY_MSDOS] = XLAT(KEY_MSDOS),
 #define XLAT_VAL_150 ((unsigned) (KEY_MSDOS))
 #define XLAT_STR_150 STRINGIFY(KEY_MSDOS)
 [KEY_COFFEE] = XLAT(KEY_COFFEE),
 #define XLAT_VAL_151 ((unsigned) (KEY_COFFEE))
 #define XLAT_STR_151 STRINGIFY(KEY_COFFEE)
 [KEY_ROTATE_DISPLAY] = XLAT(KEY_ROTATE_DISPLAY),
 #define XLAT_VAL_152 ((unsigned) (KEY_ROTATE_DISPLAY))
 #define XLAT_STR_152 STRINGIFY(KEY_ROTATE_DISPLAY)
 [KEY_CYCLEWINDOWS] = XLAT(KEY_CYCLEWINDOWS),
 #define XLAT_VAL_153 ((unsigned) (KEY_CYCLEWINDOWS))
 #define XLAT_STR_153 STRINGIFY(KEY_CYCLEWINDOWS)
 [KEY_MAIL] = XLAT(KEY_MAIL),
 #define XLAT_VAL_154 ((unsigned) (KEY_MAIL))
 #define XLAT_STR_154 STRINGIFY(KEY_MAIL)
 [KEY_BOOKMARKS] = XLAT(KEY_BOOKMARKS),
 #define XLAT_VAL_155 ((unsigned) (KEY_BOOKMARKS))
 #define XLAT_STR_155 STRINGIFY(KEY_BOOKMARKS)
 [KEY_COMPUTER] = XLAT(KEY_COMPUTER),
 #define XLAT_VAL_156 ((unsigned) (KEY_COMPUTER))
 #define XLAT_STR_156 STRINGIFY(KEY_COMPUTER)
 [KEY_BACK] = XLAT(KEY_BACK),
 #define XLAT_VAL_157 ((unsigned) (KEY_BACK))
 #define XLAT_STR_157 STRINGIFY(KEY_BACK)
 [KEY_FORWARD] = XLAT(KEY_FORWARD),
 #define XLAT_VAL_158 ((unsigned) (KEY_FORWARD))
 #define XLAT_STR_158 STRINGIFY(KEY_FORWARD)
 [KEY_CLOSECD] = XLAT(KEY_CLOSECD),
 #define XLAT_VAL_159 ((unsigned) (KEY_CLOSECD))
 #define XLAT_STR_159 STRINGIFY(KEY_CLOSECD)
 [KEY_EJECTCD] = XLAT(KEY_EJECTCD),
 #define XLAT_VAL_160 ((unsigned) (KEY_EJECTCD))
 #define XLAT_STR_160 STRINGIFY(KEY_EJECTCD)
 [KEY_EJECTCLOSECD] = XLAT(KEY_EJECTCLOSECD),
 #define XLAT_VAL_161 ((unsigned) (KEY_EJECTCLOSECD))
 #define XLAT_STR_161 STRINGIFY(KEY_EJECTCLOSECD)
 [KEY_NEXTSONG] = XLAT(KEY_NEXTSONG),
 #define XLAT_VAL_162 ((unsigned) (KEY_NEXTSONG))
 #define XLAT_STR_162 STRINGIFY(KEY_NEXTSONG)
 [KEY_PLAYPAUSE] = XLAT(KEY_PLAYPAUSE),
 #define XLAT_VAL_163 ((unsigned) (KEY_PLAYPAUSE))
 #define XLAT_STR_163 STRINGIFY(KEY_PLAYPAUSE)
 [KEY_PREVIOUSSONG] = XLAT(KEY_PREVIOUSSONG),
 #define XLAT_VAL_164 ((unsigned) (KEY_PREVIOUSSONG))
 #define XLAT_STR_164 STRINGIFY(KEY_PREVIOUSSONG)
 [KEY_STOPCD] = XLAT(KEY_STOPCD),
 #define XLAT_VAL_165 ((unsigned) (KEY_STOPCD))
 #define XLAT_STR_165 STRINGIFY(KEY_STOPCD)
 [KEY_RECORD] = XLAT(KEY_RECORD),
 #define XLAT_VAL_166 ((unsigned) (KEY_RECORD))
 #define XLAT_STR_166 STRINGIFY(KEY_RECORD)
 [KEY_REWIND] = XLAT(KEY_REWIND),
 #define XLAT_VAL_167 ((unsigned) (KEY_REWIND))
 #define XLAT_STR_167 STRINGIFY(KEY_REWIND)
 [KEY_PHONE] = XLAT(KEY_PHONE),
 #define XLAT_VAL_168 ((unsigned) (KEY_PHONE))
 #define XLAT_STR_168 STRINGIFY(KEY_PHONE)
 [KEY_ISO] = XLAT(KEY_ISO),
 #define XLAT_VAL_169 ((unsigned) (KEY_ISO))
 #define XLAT_STR_169 STRINGIFY(KEY_ISO)
 [KEY_CONFIG] = XLAT(KEY_CONFIG),
 #define XLAT_VAL_170 ((unsigned) (KEY_CONFIG))
 #define XLAT_STR_170 STRINGIFY(KEY_CONFIG)
 [KEY_HOMEPAGE] = XLAT(KEY_HOMEPAGE),
 #define XLAT_VAL_171 ((unsigned) (KEY_HOMEPAGE))
 #define XLAT_STR_171 STRINGIFY(KEY_HOMEPAGE)
 [KEY_REFRESH] = XLAT(KEY_REFRESH),
 #define XLAT_VAL_172 ((unsigned) (KEY_REFRESH))
 #define XLAT_STR_172 STRINGIFY(KEY_REFRESH)
 [KEY_EXIT] = XLAT(KEY_EXIT),
 #define XLAT_VAL_173 ((unsigned) (KEY_EXIT))
 #define XLAT_STR_173 STRINGIFY(KEY_EXIT)
 [KEY_MOVE] = XLAT(KEY_MOVE),
 #define XLAT_VAL_174 ((unsigned) (KEY_MOVE))
 #define XLAT_STR_174 STRINGIFY(KEY_MOVE)
 [KEY_EDIT] = XLAT(KEY_EDIT),
 #define XLAT_VAL_175 ((unsigned) (KEY_EDIT))
 #define XLAT_STR_175 STRINGIFY(KEY_EDIT)
 [KEY_SCROLLUP] = XLAT(KEY_SCROLLUP),
 #define XLAT_VAL_176 ((unsigned) (KEY_SCROLLUP))
 #define XLAT_STR_176 STRINGIFY(KEY_SCROLLUP)
 [KEY_SCROLLDOWN] = XLAT(KEY_SCROLLDOWN),
 #define XLAT_VAL_177 ((unsigned) (KEY_SCROLLDOWN))
 #define XLAT_STR_177 STRINGIFY(KEY_SCROLLDOWN)
 [KEY_KPLEFTPAREN] = XLAT(KEY_KPLEFTPAREN),
 #define XLAT_VAL_178 ((unsigned) (KEY_KPLEFTPAREN))
 #define XLAT_STR_178 STRINGIFY(KEY_KPLEFTPAREN)
 [KEY_KPRIGHTPAREN] = XLAT(KEY_KPRIGHTPAREN),
 #define XLAT_VAL_179 ((unsigned) (KEY_KPRIGHTPAREN))
 #define XLAT_STR_179 STRINGIFY(KEY_KPRIGHTPAREN)
 [KEY_NEW] = XLAT(KEY_NEW),
 #define XLAT_VAL_180 ((unsigned) (KEY_NEW))
 #define XLAT_STR_180 STRINGIFY(KEY_NEW)
 [KEY_REDO] = XLAT(KEY_REDO),
 #define XLAT_VAL_181 ((unsigned) (KEY_REDO))
 #define XLAT_STR_181 STRINGIFY(KEY_REDO)

 [KEY_F13] = XLAT(KEY_F13),
 #define XLAT_VAL_182 ((unsigned) (KEY_F13))
 #define XLAT_STR_182 STRINGIFY(KEY_F13)
 [KEY_F14] = XLAT(KEY_F14),
 #define XLAT_VAL_183 ((unsigned) (KEY_F14))
 #define XLAT_STR_183 STRINGIFY(KEY_F14)
 [KEY_F15] = XLAT(KEY_F15),
 #define XLAT_VAL_184 ((unsigned) (KEY_F15))
 #define XLAT_STR_184 STRINGIFY(KEY_F15)
 [KEY_F16] = XLAT(KEY_F16),
 #define XLAT_VAL_185 ((unsigned) (KEY_F16))
 #define XLAT_STR_185 STRINGIFY(KEY_F16)
 [KEY_F17] = XLAT(KEY_F17),
 #define XLAT_VAL_186 ((unsigned) (KEY_F17))
 #define XLAT_STR_186 STRINGIFY(KEY_F17)
 [KEY_F18] = XLAT(KEY_F18),
 #define XLAT_VAL_187 ((unsigned) (KEY_F18))
 #define XLAT_STR_187 STRINGIFY(KEY_F18)
 [KEY_F19] = XLAT(KEY_F19),
 #define XLAT_VAL_188 ((unsigned) (KEY_F19))
 #define XLAT_STR_188 STRINGIFY(KEY_F19)
 [KEY_F20] = XLAT(KEY_F20),
 #define XLAT_VAL_189 ((unsigned) (KEY_F20))
 #define XLAT_STR_189 STRINGIFY(KEY_F20)
 [KEY_F21] = XLAT(KEY_F21),
 #define XLAT_VAL_190 ((unsigned) (KEY_F21))
 #define XLAT_STR_190 STRINGIFY(KEY_F21)
 [KEY_F22] = XLAT(KEY_F22),
 #define XLAT_VAL_191 ((unsigned) (KEY_F22))
 #define XLAT_STR_191 STRINGIFY(KEY_F22)
 [KEY_F23] = XLAT(KEY_F23),
 #define XLAT_VAL_192 ((unsigned) (KEY_F23))
 #define XLAT_STR_192 STRINGIFY(KEY_F23)
 [KEY_F24] = XLAT(KEY_F24),
 #define XLAT_VAL_193 ((unsigned) (KEY_F24))
 #define XLAT_STR_193 STRINGIFY(KEY_F24)

 [KEY_PLAYCD] = XLAT(KEY_PLAYCD),
 #define XLAT_VAL_194 ((unsigned) (KEY_PLAYCD))
 #define XLAT_STR_194 STRINGIFY(KEY_PLAYCD)
 [KEY_PAUSECD] = XLAT(KEY_PAUSECD),
 #define XLAT_VAL_195 ((unsigned) (KEY_PAUSECD))
 #define XLAT_STR_195 STRINGIFY(KEY_PAUSECD)
 [KEY_PROG3] = XLAT(KEY_PROG3),
 #define XLAT_VAL_196 ((unsigned) (KEY_PROG3))
 #define XLAT_STR_196 STRINGIFY(KEY_PROG3)
 [KEY_PROG4] = XLAT(KEY_PROG4),
 #define XLAT_VAL_197 ((unsigned) (KEY_PROG4))
 #define XLAT_STR_197 STRINGIFY(KEY_PROG4)
 [KEY_ALL_APPLICATIONS] = XLAT(KEY_ALL_APPLICATIONS),
 #define XLAT_VAL_198 ((unsigned) (KEY_ALL_APPLICATIONS))
 #define XLAT_STR_198 STRINGIFY(KEY_ALL_APPLICATIONS)
 [KEY_SUSPEND] = XLAT(KEY_SUSPEND),
 #define XLAT_VAL_199 ((unsigned) (KEY_SUSPEND))
 #define XLAT_STR_199 STRINGIFY(KEY_SUSPEND)
 [KEY_CLOSE] = XLAT(KEY_CLOSE),
 #define XLAT_VAL_200 ((unsigned) (KEY_CLOSE))
 #define XLAT_STR_200 STRINGIFY(KEY_CLOSE)
 [KEY_PLAY] = XLAT(KEY_PLAY),
 #define XLAT_VAL_201 ((unsigned) (KEY_PLAY))
 #define XLAT_STR_201 STRINGIFY(KEY_PLAY)
 [KEY_FASTFORWARD] = XLAT(KEY_FASTFORWARD),
 #define XLAT_VAL_202 ((unsigned) (KEY_FASTFORWARD))
 #define XLAT_STR_202 STRINGIFY(KEY_FASTFORWARD)
 [KEY_BASSBOOST] = XLAT(KEY_BASSBOOST),
 #define XLAT_VAL_203 ((unsigned) (KEY_BASSBOOST))
 #define XLAT_STR_203 STRINGIFY(KEY_BASSBOOST)
 [KEY_PRINT] = XLAT(KEY_PRINT),
 #define XLAT_VAL_204 ((unsigned) (KEY_PRINT))
 #define XLAT_STR_204 STRINGIFY(KEY_PRINT)
 [KEY_HP] = XLAT(KEY_HP),
 #define XLAT_VAL_205 ((unsigned) (KEY_HP))
 #define XLAT_STR_205 STRINGIFY(KEY_HP)
 [KEY_CAMERA] = XLAT(KEY_CAMERA),
 #define XLAT_VAL_206 ((unsigned) (KEY_CAMERA))
 #define XLAT_STR_206 STRINGIFY(KEY_CAMERA)
 [KEY_SOUND] = XLAT(KEY_SOUND),
 #define XLAT_VAL_207 ((unsigned) (KEY_SOUND))
 #define XLAT_STR_207 STRINGIFY(KEY_SOUND)
 [KEY_QUESTION] = XLAT(KEY_QUESTION),
 #define XLAT_VAL_208 ((unsigned) (KEY_QUESTION))
 #define XLAT_STR_208 STRINGIFY(KEY_QUESTION)
 [KEY_EMAIL] = XLAT(KEY_EMAIL),
 #define XLAT_VAL_209 ((unsigned) (KEY_EMAIL))
 #define XLAT_STR_209 STRINGIFY(KEY_EMAIL)
 [KEY_CHAT] = XLAT(KEY_CHAT),
 #define XLAT_VAL_210 ((unsigned) (KEY_CHAT))
 #define XLAT_STR_210 STRINGIFY(KEY_CHAT)
 [KEY_SEARCH] = XLAT(KEY_SEARCH),
 #define XLAT_VAL_211 ((unsigned) (KEY_SEARCH))
 #define XLAT_STR_211 STRINGIFY(KEY_SEARCH)
 [KEY_CONNECT] = XLAT(KEY_CONNECT),
 #define XLAT_VAL_212 ((unsigned) (KEY_CONNECT))
 #define XLAT_STR_212 STRINGIFY(KEY_CONNECT)
 [KEY_FINANCE] = XLAT(KEY_FINANCE),
 #define XLAT_VAL_213 ((unsigned) (KEY_FINANCE))
 #define XLAT_STR_213 STRINGIFY(KEY_FINANCE)
 [KEY_SPORT] = XLAT(KEY_SPORT),
 #define XLAT_VAL_214 ((unsigned) (KEY_SPORT))
 #define XLAT_STR_214 STRINGIFY(KEY_SPORT)
 [KEY_SHOP] = XLAT(KEY_SHOP),
 #define XLAT_VAL_215 ((unsigned) (KEY_SHOP))
 #define XLAT_STR_215 STRINGIFY(KEY_SHOP)
 [KEY_ALTERASE] = XLAT(KEY_ALTERASE),
 #define XLAT_VAL_216 ((unsigned) (KEY_ALTERASE))
 #define XLAT_STR_216 STRINGIFY(KEY_ALTERASE)
 [KEY_CANCEL] = XLAT(KEY_CANCEL),
 #define XLAT_VAL_217 ((unsigned) (KEY_CANCEL))
 #define XLAT_STR_217 STRINGIFY(KEY_CANCEL)
 [KEY_BRIGHTNESSDOWN] = XLAT(KEY_BRIGHTNESSDOWN),
 #define XLAT_VAL_218 ((unsigned) (KEY_BRIGHTNESSDOWN))
 #define XLAT_STR_218 STRINGIFY(KEY_BRIGHTNESSDOWN)
 [KEY_BRIGHTNESSUP] = XLAT(KEY_BRIGHTNESSUP),
 #define XLAT_VAL_219 ((unsigned) (KEY_BRIGHTNESSUP))
 #define XLAT_STR_219 STRINGIFY(KEY_BRIGHTNESSUP)
 [KEY_MEDIA] = XLAT(KEY_MEDIA),
 #define XLAT_VAL_220 ((unsigned) (KEY_MEDIA))
 #define XLAT_STR_220 STRINGIFY(KEY_MEDIA)

 [KEY_SWITCHVIDEOMODE] = XLAT(KEY_SWITCHVIDEOMODE),
 #define XLAT_VAL_221 ((unsigned) (KEY_SWITCHVIDEOMODE))
 #define XLAT_STR_221 STRINGIFY(KEY_SWITCHVIDEOMODE)

 [KEY_KBDILLUMTOGGLE] = XLAT(KEY_KBDILLUMTOGGLE),
 #define XLAT_VAL_222 ((unsigned) (KEY_KBDILLUMTOGGLE))
 #define XLAT_STR_222 STRINGIFY(KEY_KBDILLUMTOGGLE)
 [KEY_KBDILLUMDOWN] = XLAT(KEY_KBDILLUMDOWN),
 #define XLAT_VAL_223 ((unsigned) (KEY_KBDILLUMDOWN))
 #define XLAT_STR_223 STRINGIFY(KEY_KBDILLUMDOWN)
 [KEY_KBDILLUMUP] = XLAT(KEY_KBDILLUMUP),
 #define XLAT_VAL_224 ((unsigned) (KEY_KBDILLUMUP))
 #define XLAT_STR_224 STRINGIFY(KEY_KBDILLUMUP)

 [KEY_SEND] = XLAT(KEY_SEND),
 #define XLAT_VAL_225 ((unsigned) (KEY_SEND))
 #define XLAT_STR_225 STRINGIFY(KEY_SEND)
 [KEY_REPLY] = XLAT(KEY_REPLY),
 #define XLAT_VAL_226 ((unsigned) (KEY_REPLY))
 #define XLAT_STR_226 STRINGIFY(KEY_REPLY)
 [KEY_FORWARDMAIL] = XLAT(KEY_FORWARDMAIL),
 #define XLAT_VAL_227 ((unsigned) (KEY_FORWARDMAIL))
 #define XLAT_STR_227 STRINGIFY(KEY_FORWARDMAIL)
 [KEY_SAVE] = XLAT(KEY_SAVE),
 #define XLAT_VAL_228 ((unsigned) (KEY_SAVE))
 #define XLAT_STR_228 STRINGIFY(KEY_SAVE)
 [KEY_DOCUMENTS] = XLAT(KEY_DOCUMENTS),
 #define XLAT_VAL_229 ((unsigned) (KEY_DOCUMENTS))
 #define XLAT_STR_229 STRINGIFY(KEY_DOCUMENTS)

 [KEY_BATTERY] = XLAT(KEY_BATTERY),
 #define XLAT_VAL_230 ((unsigned) (KEY_BATTERY))
 #define XLAT_STR_230 STRINGIFY(KEY_BATTERY)

 [KEY_BLUETOOTH] = XLAT(KEY_BLUETOOTH),
 #define XLAT_VAL_231 ((unsigned) (KEY_BLUETOOTH))
 #define XLAT_STR_231 STRINGIFY(KEY_BLUETOOTH)
 [KEY_WLAN] = XLAT(KEY_WLAN),
 #define XLAT_VAL_232 ((unsigned) (KEY_WLAN))
 #define XLAT_STR_232 STRINGIFY(KEY_WLAN)
 [KEY_UWB] = XLAT(KEY_UWB),
 #define XLAT_VAL_233 ((unsigned) (KEY_UWB))
 #define XLAT_STR_233 STRINGIFY(KEY_UWB)

 [KEY_UNKNOWN] = XLAT(KEY_UNKNOWN),
 #define XLAT_VAL_234 ((unsigned) (KEY_UNKNOWN))
 #define XLAT_STR_234 STRINGIFY(KEY_UNKNOWN)

 [KEY_VIDEO_NEXT] = XLAT(KEY_VIDEO_NEXT),
 #define XLAT_VAL_235 ((unsigned) (KEY_VIDEO_NEXT))
 #define XLAT_STR_235 STRINGIFY(KEY_VIDEO_NEXT)
 [KEY_VIDEO_PREV] = XLAT(KEY_VIDEO_PREV),
 #define XLAT_VAL_236 ((unsigned) (KEY_VIDEO_PREV))
 #define XLAT_STR_236 STRINGIFY(KEY_VIDEO_PREV)
 [KEY_BRIGHTNESS_CYCLE] = XLAT(KEY_BRIGHTNESS_CYCLE),
 #define XLAT_VAL_237 ((unsigned) (KEY_BRIGHTNESS_CYCLE))
 #define XLAT_STR_237 STRINGIFY(KEY_BRIGHTNESS_CYCLE)
 [KEY_BRIGHTNESS_AUTO] = XLAT(KEY_BRIGHTNESS_AUTO),
 #define XLAT_VAL_238 ((unsigned) (KEY_BRIGHTNESS_AUTO))
 #define XLAT_STR_238 STRINGIFY(KEY_BRIGHTNESS_AUTO)
 [KEY_DISPLAY_OFF] = XLAT(KEY_DISPLAY_OFF),
 #define XLAT_VAL_239 ((unsigned) (KEY_DISPLAY_OFF))
 #define XLAT_STR_239 STRINGIFY(KEY_DISPLAY_OFF)

 [KEY_WWAN] = XLAT(KEY_WWAN),
 #define XLAT_VAL_240 ((unsigned) (KEY_WWAN))
 #define XLAT_STR_240 STRINGIFY(KEY_WWAN)
 [KEY_RFKILL] = XLAT(KEY_RFKILL),
 #define XLAT_VAL_241 ((unsigned) (KEY_RFKILL))
 #define XLAT_STR_241 STRINGIFY(KEY_RFKILL)

 [KEY_MICMUTE] = XLAT(KEY_MICMUTE),
 #define XLAT_VAL_242 ((unsigned) (KEY_MICMUTE))
 #define XLAT_STR_242 STRINGIFY(KEY_MICMUTE)

 [BTN_0] = XLAT(BTN_0),
 #define XLAT_VAL_243 ((unsigned) (BTN_0))
 #define XLAT_STR_243 STRINGIFY(BTN_0)
 [BTN_1] = XLAT(BTN_1),
 #define XLAT_VAL_244 ((unsigned) (BTN_1))
 #define XLAT_STR_244 STRINGIFY(BTN_1)
 [BTN_2] = XLAT(BTN_2),
 #define XLAT_VAL_245 ((unsigned) (BTN_2))
 #define XLAT_STR_245 STRINGIFY(BTN_2)
 [BTN_3] = XLAT(BTN_3),
 #define XLAT_VAL_246 ((unsigned) (BTN_3))
 #define XLAT_STR_246 STRINGIFY(BTN_3)
 [BTN_4] = XLAT(BTN_4),
 #define XLAT_VAL_247 ((unsigned) (BTN_4))
 #define XLAT_STR_247 STRINGIFY(BTN_4)
 [BTN_5] = XLAT(BTN_5),
 #define XLAT_VAL_248 ((unsigned) (BTN_5))
 #define XLAT_STR_248 STRINGIFY(BTN_5)
 [BTN_6] = XLAT(BTN_6),
 #define XLAT_VAL_249 ((unsigned) (BTN_6))
 #define XLAT_STR_249 STRINGIFY(BTN_6)
 [BTN_7] = XLAT(BTN_7),
 #define XLAT_VAL_250 ((unsigned) (BTN_7))
 #define XLAT_STR_250 STRINGIFY(BTN_7)
 [BTN_8] = XLAT(BTN_8),
 #define XLAT_VAL_251 ((unsigned) (BTN_8))
 #define XLAT_STR_251 STRINGIFY(BTN_8)
 [BTN_9] = XLAT(BTN_9),
 #define XLAT_VAL_252 ((unsigned) (BTN_9))
 #define XLAT_STR_252 STRINGIFY(BTN_9)

 [BTN_LEFT] = XLAT(BTN_LEFT),
 #define XLAT_VAL_253 ((unsigned) (BTN_LEFT))
 #define XLAT_STR_253 STRINGIFY(BTN_LEFT)
 [BTN_RIGHT] = XLAT(BTN_RIGHT),
 #define XLAT_VAL_254 ((unsigned) (BTN_RIGHT))
 #define XLAT_STR_254 STRINGIFY(BTN_RIGHT)
 [BTN_MIDDLE] = XLAT(BTN_MIDDLE),
 #define XLAT_VAL_255 ((unsigned) (BTN_MIDDLE))
 #define XLAT_STR_255 STRINGIFY(BTN_MIDDLE)
 [BTN_SIDE] = XLAT(BTN_SIDE),
 #define XLAT_VAL_256 ((unsigned) (BTN_SIDE))
 #define XLAT_STR_256 STRINGIFY(BTN_SIDE)
 [BTN_EXTRA] = XLAT(BTN_EXTRA),
 #define XLAT_VAL_257 ((unsigned) (BTN_EXTRA))
 #define XLAT_STR_257 STRINGIFY(BTN_EXTRA)
 [BTN_FORWARD] = XLAT(BTN_FORWARD),
 #define XLAT_VAL_258 ((unsigned) (BTN_FORWARD))
 #define XLAT_STR_258 STRINGIFY(BTN_FORWARD)
 [BTN_BACK] = XLAT(BTN_BACK),
 #define XLAT_VAL_259 ((unsigned) (BTN_BACK))
 #define XLAT_STR_259 STRINGIFY(BTN_BACK)
 [BTN_TASK] = XLAT(BTN_TASK),
 #define XLAT_VAL_260 ((unsigned) (BTN_TASK))
 #define XLAT_STR_260 STRINGIFY(BTN_TASK)

 [BTN_TRIGGER] = XLAT(BTN_TRIGGER),
 #define XLAT_VAL_261 ((unsigned) (BTN_TRIGGER))
 #define XLAT_STR_261 STRINGIFY(BTN_TRIGGER)
 [BTN_THUMB] = XLAT(BTN_THUMB),
 #define XLAT_VAL_262 ((unsigned) (BTN_THUMB))
 #define XLAT_STR_262 STRINGIFY(BTN_THUMB)
 [BTN_THUMB2] = XLAT(BTN_THUMB2),
 #define XLAT_VAL_263 ((unsigned) (BTN_THUMB2))
 #define XLAT_STR_263 STRINGIFY(BTN_THUMB2)
 [BTN_TOP] = XLAT(BTN_TOP),
 #define XLAT_VAL_264 ((unsigned) (BTN_TOP))
 #define XLAT_STR_264 STRINGIFY(BTN_TOP)
 [BTN_TOP2] = XLAT(BTN_TOP2),
 #define XLAT_VAL_265 ((unsigned) (BTN_TOP2))
 #define XLAT_STR_265 STRINGIFY(BTN_TOP2)
 [BTN_PINKIE] = XLAT(BTN_PINKIE),
 #define XLAT_VAL_266 ((unsigned) (BTN_PINKIE))
 #define XLAT_STR_266 STRINGIFY(BTN_PINKIE)
 [BTN_BASE] = XLAT(BTN_BASE),
 #define XLAT_VAL_267 ((unsigned) (BTN_BASE))
 #define XLAT_STR_267 STRINGIFY(BTN_BASE)
 [BTN_BASE2] = XLAT(BTN_BASE2),
 #define XLAT_VAL_268 ((unsigned) (BTN_BASE2))
 #define XLAT_STR_268 STRINGIFY(BTN_BASE2)
 [BTN_BASE3] = XLAT(BTN_BASE3),
 #define XLAT_VAL_269 ((unsigned) (BTN_BASE3))
 #define XLAT_STR_269 STRINGIFY(BTN_BASE3)
 [BTN_BASE4] = XLAT(BTN_BASE4),
 #define XLAT_VAL_270 ((unsigned) (BTN_BASE4))
 #define XLAT_STR_270 STRINGIFY(BTN_BASE4)
 [BTN_BASE5] = XLAT(BTN_BASE5),
 #define XLAT_VAL_271 ((unsigned) (BTN_BASE5))
 #define XLAT_STR_271 STRINGIFY(BTN_BASE5)
 [BTN_BASE6] = XLAT(BTN_BASE6),
 #define XLAT_VAL_272 ((unsigned) (BTN_BASE6))
 #define XLAT_STR_272 STRINGIFY(BTN_BASE6)
 [BTN_DEAD] = XLAT(BTN_DEAD),
 #define XLAT_VAL_273 ((unsigned) (BTN_DEAD))
 #define XLAT_STR_273 STRINGIFY(BTN_DEAD)

 [BTN_SOUTH] = XLAT(BTN_SOUTH),
 #define XLAT_VAL_274 ((unsigned) (BTN_SOUTH))
 #define XLAT_STR_274 STRINGIFY(BTN_SOUTH)
 [BTN_EAST] = XLAT(BTN_EAST),
 #define XLAT_VAL_275 ((unsigned) (BTN_EAST))
 #define XLAT_STR_275 STRINGIFY(BTN_EAST)
 [BTN_C] = XLAT(BTN_C),
 #define XLAT_VAL_276 ((unsigned) (BTN_C))
 #define XLAT_STR_276 STRINGIFY(BTN_C)
 [BTN_NORTH] = XLAT(BTN_NORTH),
 #define XLAT_VAL_277 ((unsigned) (BTN_NORTH))
 #define XLAT_STR_277 STRINGIFY(BTN_NORTH)
 [BTN_WEST] = XLAT(BTN_WEST),
 #define XLAT_VAL_278 ((unsigned) (BTN_WEST))
 #define XLAT_STR_278 STRINGIFY(BTN_WEST)
 [BTN_Z] = XLAT(BTN_Z),
 #define XLAT_VAL_279 ((unsigned) (BTN_Z))
 #define XLAT_STR_279 STRINGIFY(BTN_Z)
 [BTN_TL] = XLAT(BTN_TL),
 #define XLAT_VAL_280 ((unsigned) (BTN_TL))
 #define XLAT_STR_280 STRINGIFY(BTN_TL)
 [BTN_TR] = XLAT(BTN_TR),
 #define XLAT_VAL_281 ((unsigned) (BTN_TR))
 #define XLAT_STR_281 STRINGIFY(BTN_TR)
 [BTN_TL2] = XLAT(BTN_TL2),
 #define XLAT_VAL_282 ((unsigned) (BTN_TL2))
 #define XLAT_STR_282 STRINGIFY(BTN_TL2)
 [BTN_TR2] = XLAT(BTN_TR2),
 #define XLAT_VAL_283 ((unsigned) (BTN_TR2))
 #define XLAT_STR_283 STRINGIFY(BTN_TR2)
 [BTN_SELECT] = XLAT(BTN_SELECT),
 #define XLAT_VAL_284 ((unsigned) (BTN_SELECT))
 #define XLAT_STR_284 STRINGIFY(BTN_SELECT)
 [BTN_START] = XLAT(BTN_START),
 #define XLAT_VAL_285 ((unsigned) (BTN_START))
 #define XLAT_STR_285 STRINGIFY(BTN_START)
 [BTN_MODE] = XLAT(BTN_MODE),
 #define XLAT_VAL_286 ((unsigned) (BTN_MODE))
 #define XLAT_STR_286 STRINGIFY(BTN_MODE)
 [BTN_THUMBL] = XLAT(BTN_THUMBL),
 #define XLAT_VAL_287 ((unsigned) (BTN_THUMBL))
 #define XLAT_STR_287 STRINGIFY(BTN_THUMBL)
 [BTN_THUMBR] = XLAT(BTN_THUMBR),
 #define XLAT_VAL_288 ((unsigned) (BTN_THUMBR))
 #define XLAT_STR_288 STRINGIFY(BTN_THUMBR)

 [BTN_TOOL_PEN] = XLAT(BTN_TOOL_PEN),
 #define XLAT_VAL_289 ((unsigned) (BTN_TOOL_PEN))
 #define XLAT_STR_289 STRINGIFY(BTN_TOOL_PEN)
 [BTN_TOOL_RUBBER] = XLAT(BTN_TOOL_RUBBER),
 #define XLAT_VAL_290 ((unsigned) (BTN_TOOL_RUBBER))
 #define XLAT_STR_290 STRINGIFY(BTN_TOOL_RUBBER)
 [BTN_TOOL_BRUSH] = XLAT(BTN_TOOL_BRUSH),
 #define XLAT_VAL_291 ((unsigned) (BTN_TOOL_BRUSH))
 #define XLAT_STR_291 STRINGIFY(BTN_TOOL_BRUSH)
 [BTN_TOOL_PENCIL] = XLAT(BTN_TOOL_PENCIL),
 #define XLAT_VAL_292 ((unsigned) (BTN_TOOL_PENCIL))
 #define XLAT_STR_292 STRINGIFY(BTN_TOOL_PENCIL)
 [BTN_TOOL_AIRBRUSH] = XLAT(BTN_TOOL_AIRBRUSH),
 #define XLAT_VAL_293 ((unsigned) (BTN_TOOL_AIRBRUSH))
 #define XLAT_STR_293 STRINGIFY(BTN_TOOL_AIRBRUSH)
 [BTN_TOOL_FINGER] = XLAT(BTN_TOOL_FINGER),
 #define XLAT_VAL_294 ((unsigned) (BTN_TOOL_FINGER))
 #define XLAT_STR_294 STRINGIFY(BTN_TOOL_FINGER)
 [BTN_TOOL_MOUSE] = XLAT(BTN_TOOL_MOUSE),
 #define XLAT_VAL_295 ((unsigned) (BTN_TOOL_MOUSE))
 #define XLAT_STR_295 STRINGIFY(BTN_TOOL_MOUSE)
 [BTN_TOOL_LENS] = XLAT(BTN_TOOL_LENS),
 #define XLAT_VAL_296 ((unsigned) (BTN_TOOL_LENS))
 #define XLAT_STR_296 STRINGIFY(BTN_TOOL_LENS)
 [BTN_TOOL_QUINTTAP] = XLAT(BTN_TOOL_QUINTTAP),
 #define XLAT_VAL_297 ((unsigned) (BTN_TOOL_QUINTTAP))
 #define XLAT_STR_297 STRINGIFY(BTN_TOOL_QUINTTAP)
 [BTN_STYLUS3] = XLAT(BTN_STYLUS3),
 #define XLAT_VAL_298 ((unsigned) (BTN_STYLUS3))
 #define XLAT_STR_298 STRINGIFY(BTN_STYLUS3)
 [BTN_TOUCH] = XLAT(BTN_TOUCH),
 #define XLAT_VAL_299 ((unsigned) (BTN_TOUCH))
 #define XLAT_STR_299 STRINGIFY(BTN_TOUCH)
 [BTN_STYLUS] = XLAT(BTN_STYLUS),
 #define XLAT_VAL_300 ((unsigned) (BTN_STYLUS))
 #define XLAT_STR_300 STRINGIFY(BTN_STYLUS)
 [BTN_STYLUS2] = XLAT(BTN_STYLUS2),
 #define XLAT_VAL_301 ((unsigned) (BTN_STYLUS2))
 #define XLAT_STR_301 STRINGIFY(BTN_STYLUS2)
 [BTN_TOOL_DOUBLETAP] = XLAT(BTN_TOOL_DOUBLETAP),
 #define XLAT_VAL_302 ((unsigned) (BTN_TOOL_DOUBLETAP))
 #define XLAT_STR_302 STRINGIFY(BTN_TOOL_DOUBLETAP)
 [BTN_TOOL_TRIPLETAP] = XLAT(BTN_TOOL_TRIPLETAP),
 #define XLAT_VAL_303 ((unsigned) (BTN_TOOL_TRIPLETAP))
 #define XLAT_STR_303 STRINGIFY(BTN_TOOL_TRIPLETAP)
 [BTN_TOOL_QUADTAP] = XLAT(BTN_TOOL_QUADTAP),
 #define XLAT_VAL_304 ((unsigned) (BTN_TOOL_QUADTAP))
 #define XLAT_STR_304 STRINGIFY(BTN_TOOL_QUADTAP)

 [BTN_GEAR_DOWN] = XLAT(BTN_GEAR_DOWN),
 #define XLAT_VAL_305 ((unsigned) (BTN_GEAR_DOWN))
 #define XLAT_STR_305 STRINGIFY(BTN_GEAR_DOWN)
 [BTN_GEAR_UP] = XLAT(BTN_GEAR_UP),
 #define XLAT_VAL_306 ((unsigned) (BTN_GEAR_UP))
 #define XLAT_STR_306 STRINGIFY(BTN_GEAR_UP)

 [KEY_OK] = XLAT(KEY_OK),
 #define XLAT_VAL_307 ((unsigned) (KEY_OK))
 #define XLAT_STR_307 STRINGIFY(KEY_OK)
 [KEY_SELECT] = XLAT(KEY_SELECT),
 #define XLAT_VAL_308 ((unsigned) (KEY_SELECT))
 #define XLAT_STR_308 STRINGIFY(KEY_SELECT)
 [KEY_GOTO] = XLAT(KEY_GOTO),
 #define XLAT_VAL_309 ((unsigned) (KEY_GOTO))
 #define XLAT_STR_309 STRINGIFY(KEY_GOTO)
 [KEY_CLEAR] = XLAT(KEY_CLEAR),
 #define XLAT_VAL_310 ((unsigned) (KEY_CLEAR))
 #define XLAT_STR_310 STRINGIFY(KEY_CLEAR)
 [KEY_POWER2] = XLAT(KEY_POWER2),
 #define XLAT_VAL_311 ((unsigned) (KEY_POWER2))
 #define XLAT_STR_311 STRINGIFY(KEY_POWER2)
 [KEY_OPTION] = XLAT(KEY_OPTION),
 #define XLAT_VAL_312 ((unsigned) (KEY_OPTION))
 #define XLAT_STR_312 STRINGIFY(KEY_OPTION)
 [KEY_INFO] = XLAT(KEY_INFO),
 #define XLAT_VAL_313 ((unsigned) (KEY_INFO))
 #define XLAT_STR_313 STRINGIFY(KEY_INFO)
 [KEY_TIME] = XLAT(KEY_TIME),
 #define XLAT_VAL_314 ((unsigned) (KEY_TIME))
 #define XLAT_STR_314 STRINGIFY(KEY_TIME)
 [KEY_VENDOR] = XLAT(KEY_VENDOR),
 #define XLAT_VAL_315 ((unsigned) (KEY_VENDOR))
 #define XLAT_STR_315 STRINGIFY(KEY_VENDOR)
 [KEY_ARCHIVE] = XLAT(KEY_ARCHIVE),
 #define XLAT_VAL_316 ((unsigned) (KEY_ARCHIVE))
 #define XLAT_STR_316 STRINGIFY(KEY_ARCHIVE)
 [KEY_PROGRAM] = XLAT(KEY_PROGRAM),
 #define XLAT_VAL_317 ((unsigned) (KEY_PROGRAM))
 #define XLAT_STR_317 STRINGIFY(KEY_PROGRAM)
 [KEY_CHANNEL] = XLAT(KEY_CHANNEL),
 #define XLAT_VAL_318 ((unsigned) (KEY_CHANNEL))
 #define XLAT_STR_318 STRINGIFY(KEY_CHANNEL)
 [KEY_FAVORITES] = XLAT(KEY_FAVORITES),
 #define XLAT_VAL_319 ((unsigned) (KEY_FAVORITES))
 #define XLAT_STR_319 STRINGIFY(KEY_FAVORITES)
 [KEY_EPG] = XLAT(KEY_EPG),
 #define XLAT_VAL_320 ((unsigned) (KEY_EPG))
 #define XLAT_STR_320 STRINGIFY(KEY_EPG)
 [KEY_PVR] = XLAT(KEY_PVR),
 #define XLAT_VAL_321 ((unsigned) (KEY_PVR))
 #define XLAT_STR_321 STRINGIFY(KEY_PVR)
 [KEY_MHP] = XLAT(KEY_MHP),
 #define XLAT_VAL_322 ((unsigned) (KEY_MHP))
 #define XLAT_STR_322 STRINGIFY(KEY_MHP)
 [KEY_LANGUAGE] = XLAT(KEY_LANGUAGE),
 #define XLAT_VAL_323 ((unsigned) (KEY_LANGUAGE))
 #define XLAT_STR_323 STRINGIFY(KEY_LANGUAGE)
 [KEY_TITLE] = XLAT(KEY_TITLE),
 #define XLAT_VAL_324 ((unsigned) (KEY_TITLE))
 #define XLAT_STR_324 STRINGIFY(KEY_TITLE)
 [KEY_SUBTITLE] = XLAT(KEY_SUBTITLE),
 #define XLAT_VAL_325 ((unsigned) (KEY_SUBTITLE))
 #define XLAT_STR_325 STRINGIFY(KEY_SUBTITLE)
 [KEY_ANGLE] = XLAT(KEY_ANGLE),
 #define XLAT_VAL_326 ((unsigned) (KEY_ANGLE))
 #define XLAT_STR_326 STRINGIFY(KEY_ANGLE)
 [KEY_ZOOM] = XLAT(KEY_ZOOM),
 #define XLAT_VAL_327 ((unsigned) (KEY_ZOOM))
 #define XLAT_STR_327 STRINGIFY(KEY_ZOOM)
 [KEY_MODE] = XLAT(KEY_MODE),
 #define XLAT_VAL_328 ((unsigned) (KEY_MODE))
 #define XLAT_STR_328 STRINGIFY(KEY_MODE)
 [KEY_KEYBOARD] = XLAT(KEY_KEYBOARD),
 #define XLAT_VAL_329 ((unsigned) (KEY_KEYBOARD))
 #define XLAT_STR_329 STRINGIFY(KEY_KEYBOARD)
 [KEY_SCREEN] = XLAT(KEY_SCREEN),
 #define XLAT_VAL_330 ((unsigned) (KEY_SCREEN))
 #define XLAT_STR_330 STRINGIFY(KEY_SCREEN)
 [KEY_PC] = XLAT(KEY_PC),
 #define XLAT_VAL_331 ((unsigned) (KEY_PC))
 #define XLAT_STR_331 STRINGIFY(KEY_PC)
 [KEY_TV] = XLAT(KEY_TV),
 #define XLAT_VAL_332 ((unsigned) (KEY_TV))
 #define XLAT_STR_332 STRINGIFY(KEY_TV)
 [KEY_TV2] = XLAT(KEY_TV2),
 #define XLAT_VAL_333 ((unsigned) (KEY_TV2))
 #define XLAT_STR_333 STRINGIFY(KEY_TV2)
 [KEY_VCR] = XLAT(KEY_VCR),
 #define XLAT_VAL_334 ((unsigned) (KEY_VCR))
 #define XLAT_STR_334 STRINGIFY(KEY_VCR)
 [KEY_VCR2] = XLAT(KEY_VCR2),
 #define XLAT_VAL_335 ((unsigned) (KEY_VCR2))
 #define XLAT_STR_335 STRINGIFY(KEY_VCR2)
 [KEY_SAT] = XLAT(KEY_SAT),
 #define XLAT_VAL_336 ((unsigned) (KEY_SAT))
 #define XLAT_STR_336 STRINGIFY(KEY_SAT)
 [KEY_SAT2] = XLAT(KEY_SAT2),
 #define XLAT_VAL_337 ((unsigned) (KEY_SAT2))
 #define XLAT_STR_337 STRINGIFY(KEY_SAT2)
 [KEY_CD] = XLAT(KEY_CD),
 #define XLAT_VAL_338 ((unsigned) (KEY_CD))
 #define XLAT_STR_338 STRINGIFY(KEY_CD)
 [KEY_TAPE] = XLAT(KEY_TAPE),
 #define XLAT_VAL_339 ((unsigned) (KEY_TAPE))
 #define XLAT_STR_339 STRINGIFY(KEY_TAPE)
 [KEY_RADIO] = XLAT(KEY_RADIO),
 #define XLAT_VAL_340 ((unsigned) (KEY_RADIO))
 #define XLAT_STR_340 STRINGIFY(KEY_RADIO)
 [KEY_TUNER] = XLAT(KEY_TUNER),
 #define XLAT_VAL_341 ((unsigned) (KEY_TUNER))
 #define XLAT_STR_341 STRINGIFY(KEY_TUNER)
 [KEY_PLAYER] = XLAT(KEY_PLAYER),
 #define XLAT_VAL_342 ((unsigned) (KEY_PLAYER))
 #define XLAT_STR_342 STRINGIFY(KEY_PLAYER)
 [KEY_TEXT] = XLAT(KEY_TEXT),
 #define XLAT_VAL_343 ((unsigned) (KEY_TEXT))
 #define XLAT_STR_343 STRINGIFY(KEY_TEXT)
 [KEY_DVD] = XLAT(KEY_DVD),
 #define XLAT_VAL_344 ((unsigned) (KEY_DVD))
 #define XLAT_STR_344 STRINGIFY(KEY_DVD)
 [KEY_AUX] = XLAT(KEY_AUX),
 #define XLAT_VAL_345 ((unsigned) (KEY_AUX))
 #define XLAT_STR_345 STRINGIFY(KEY_AUX)
 [KEY_MP3] = XLAT(KEY_MP3),
 #define XLAT_VAL_346 ((unsigned) (KEY_MP3))
 #define XLAT_STR_346 STRINGIFY(KEY_MP3)
 [KEY_AUDIO] = XLAT(KEY_AUDIO),
 #define XLAT_VAL_347 ((unsigned) (KEY_AUDIO))
 #define XLAT_STR_347 STRINGIFY(KEY_AUDIO)
 [KEY_VIDEO] = XLAT(KEY_VIDEO),
 #define XLAT_VAL_348 ((unsigned) (KEY_VIDEO))
 #define XLAT_STR_348 STRINGIFY(KEY_VIDEO)
 [KEY_DIRECTORY] = XLAT(KEY_DIRECTORY),
 #define XLAT_VAL_349 ((unsigned) (KEY_DIRECTORY))
 #define XLAT_STR_349 STRINGIFY(KEY_DIRECTORY)
 [KEY_LIST] = XLAT(KEY_LIST),
 #define XLAT_VAL_350 ((unsigned) (KEY_LIST))
 #define XLAT_STR_350 STRINGIFY(KEY_LIST)
 [KEY_MEMO] = XLAT(KEY_MEMO),
 #define XLAT_VAL_351 ((unsigned) (KEY_MEMO))
 #define XLAT_STR_351 STRINGIFY(KEY_MEMO)
 [KEY_CALENDAR] = XLAT(KEY_CALENDAR),
 #define XLAT_VAL_352 ((unsigned) (KEY_CALENDAR))
 #define XLAT_STR_352 STRINGIFY(KEY_CALENDAR)
 [KEY_RED] = XLAT(KEY_RED),
 #define XLAT_VAL_353 ((unsigned) (KEY_RED))
 #define XLAT_STR_353 STRINGIFY(KEY_RED)
 [KEY_GREEN] = XLAT(KEY_GREEN),
 #define XLAT_VAL_354 ((unsigned) (KEY_GREEN))
 #define XLAT_STR_354 STRINGIFY(KEY_GREEN)
 [KEY_YELLOW] = XLAT(KEY_YELLOW),
 #define XLAT_VAL_355 ((unsigned) (KEY_YELLOW))
 #define XLAT_STR_355 STRINGIFY(KEY_YELLOW)
 [KEY_BLUE] = XLAT(KEY_BLUE),
 #define XLAT_VAL_356 ((unsigned) (KEY_BLUE))
 #define XLAT_STR_356 STRINGIFY(KEY_BLUE)
 [KEY_CHANNELUP] = XLAT(KEY_CHANNELUP),
 #define XLAT_VAL_357 ((unsigned) (KEY_CHANNELUP))
 #define XLAT_STR_357 STRINGIFY(KEY_CHANNELUP)
 [KEY_CHANNELDOWN] = XLAT(KEY_CHANNELDOWN),
 #define XLAT_VAL_358 ((unsigned) (KEY_CHANNELDOWN))
 #define XLAT_STR_358 STRINGIFY(KEY_CHANNELDOWN)
 [KEY_FIRST] = XLAT(KEY_FIRST),
 #define XLAT_VAL_359 ((unsigned) (KEY_FIRST))
 #define XLAT_STR_359 STRINGIFY(KEY_FIRST)
 [KEY_LAST] = XLAT(KEY_LAST),
 #define XLAT_VAL_360 ((unsigned) (KEY_LAST))
 #define XLAT_STR_360 STRINGIFY(KEY_LAST)
 [KEY_AB] = XLAT(KEY_AB),
 #define XLAT_VAL_361 ((unsigned) (KEY_AB))
 #define XLAT_STR_361 STRINGIFY(KEY_AB)
 [KEY_NEXT] = XLAT(KEY_NEXT),
 #define XLAT_VAL_362 ((unsigned) (KEY_NEXT))
 #define XLAT_STR_362 STRINGIFY(KEY_NEXT)
 [KEY_RESTART] = XLAT(KEY_RESTART),
 #define XLAT_VAL_363 ((unsigned) (KEY_RESTART))
 #define XLAT_STR_363 STRINGIFY(KEY_RESTART)
 [KEY_SLOW] = XLAT(KEY_SLOW),
 #define XLAT_VAL_364 ((unsigned) (KEY_SLOW))
 #define XLAT_STR_364 STRINGIFY(KEY_SLOW)
 [KEY_SHUFFLE] = XLAT(KEY_SHUFFLE),
 #define XLAT_VAL_365 ((unsigned) (KEY_SHUFFLE))
 #define XLAT_STR_365 STRINGIFY(KEY_SHUFFLE)
 [KEY_BREAK] = XLAT(KEY_BREAK),
 #define XLAT_VAL_366 ((unsigned) (KEY_BREAK))
 #define XLAT_STR_366 STRINGIFY(KEY_BREAK)
 [KEY_PREVIOUS] = XLAT(KEY_PREVIOUS),
 #define XLAT_VAL_367 ((unsigned) (KEY_PREVIOUS))
 #define XLAT_STR_367 STRINGIFY(KEY_PREVIOUS)
 [KEY_DIGITS] = XLAT(KEY_DIGITS),
 #define XLAT_VAL_368 ((unsigned) (KEY_DIGITS))
 #define XLAT_STR_368 STRINGIFY(KEY_DIGITS)
 [KEY_TEEN] = XLAT(KEY_TEEN),
 #define XLAT_VAL_369 ((unsigned) (KEY_TEEN))
 #define XLAT_STR_369 STRINGIFY(KEY_TEEN)
 [KEY_TWEN] = XLAT(KEY_TWEN),
 #define XLAT_VAL_370 ((unsigned) (KEY_TWEN))
 #define XLAT_STR_370 STRINGIFY(KEY_TWEN)
 [KEY_VIDEOPHONE] = XLAT(KEY_VIDEOPHONE),
 #define XLAT_VAL_371 ((unsigned) (KEY_VIDEOPHONE))
 #define XLAT_STR_371 STRINGIFY(KEY_VIDEOPHONE)
 [KEY_GAMES] = XLAT(KEY_GAMES),
 #define XLAT_VAL_372 ((unsigned) (KEY_GAMES))
 #define XLAT_STR_372 STRINGIFY(KEY_GAMES)
 [KEY_ZOOMIN] = XLAT(KEY_ZOOMIN),
 #define XLAT_VAL_373 ((unsigned) (KEY_ZOOMIN))
 #define XLAT_STR_373 STRINGIFY(KEY_ZOOMIN)
 [KEY_ZOOMOUT] = XLAT(KEY_ZOOMOUT),
 #define XLAT_VAL_374 ((unsigned) (KEY_ZOOMOUT))
 #define XLAT_STR_374 STRINGIFY(KEY_ZOOMOUT)
 [KEY_ZOOMRESET] = XLAT(KEY_ZOOMRESET),
 #define XLAT_VAL_375 ((unsigned) (KEY_ZOOMRESET))
 #define XLAT_STR_375 STRINGIFY(KEY_ZOOMRESET)
 [KEY_WORDPROCESSOR] = XLAT(KEY_WORDPROCESSOR),
 #define XLAT_VAL_376 ((unsigned) (KEY_WORDPROCESSOR))
 #define XLAT_STR_376 STRINGIFY(KEY_WORDPROCESSOR)
 [KEY_EDITOR] = XLAT(KEY_EDITOR),
 #define XLAT_VAL_377 ((unsigned) (KEY_EDITOR))
 #define XLAT_STR_377 STRINGIFY(KEY_EDITOR)
 [KEY_SPREADSHEET] = XLAT(KEY_SPREADSHEET),
 #define XLAT_VAL_378 ((unsigned) (KEY_SPREADSHEET))
 #define XLAT_STR_378 STRINGIFY(KEY_SPREADSHEET)
 [KEY_GRAPHICSEDITOR] = XLAT(KEY_GRAPHICSEDITOR),
 #define XLAT_VAL_379 ((unsigned) (KEY_GRAPHICSEDITOR))
 #define XLAT_STR_379 STRINGIFY(KEY_GRAPHICSEDITOR)
 [KEY_PRESENTATION] = XLAT(KEY_PRESENTATION),
 #define XLAT_VAL_380 ((unsigned) (KEY_PRESENTATION))
 #define XLAT_STR_380 STRINGIFY(KEY_PRESENTATION)
 [KEY_DATABASE] = XLAT(KEY_DATABASE),
 #define XLAT_VAL_381 ((unsigned) (KEY_DATABASE))
 #define XLAT_STR_381 STRINGIFY(KEY_DATABASE)
 [KEY_NEWS] = XLAT(KEY_NEWS),
 #define XLAT_VAL_382 ((unsigned) (KEY_NEWS))
 #define XLAT_STR_382 STRINGIFY(KEY_NEWS)
 [KEY_VOICEMAIL] = XLAT(KEY_VOICEMAIL),
 #define XLAT_VAL_383 ((unsigned) (KEY_VOICEMAIL))
 #define XLAT_STR_383 STRINGIFY(KEY_VOICEMAIL)
 [KEY_ADDRESSBOOK] = XLAT(KEY_ADDRESSBOOK),
 #define XLAT_VAL_384 ((unsigned) (KEY_ADDRESSBOOK))
 #define XLAT_STR_384 STRINGIFY(KEY_ADDRESSBOOK)
 [KEY_MESSENGER] = XLAT(KEY_MESSENGER),
 #define XLAT_VAL_385 ((unsigned) (KEY_MESSENGER))
 #define XLAT_STR_385 STRINGIFY(KEY_MESSENGER)
 [KEY_DISPLAYTOGGLE] = XLAT(KEY_DISPLAYTOGGLE),
 #define XLAT_VAL_386 ((unsigned) (KEY_DISPLAYTOGGLE))
 #define XLAT_STR_386 STRINGIFY(KEY_DISPLAYTOGGLE)
 [KEY_SPELLCHECK] = XLAT(KEY_SPELLCHECK),
 #define XLAT_VAL_387 ((unsigned) (KEY_SPELLCHECK))
 #define XLAT_STR_387 STRINGIFY(KEY_SPELLCHECK)
 [KEY_LOGOFF] = XLAT(KEY_LOGOFF),
 #define XLAT_VAL_388 ((unsigned) (KEY_LOGOFF))
 #define XLAT_STR_388 STRINGIFY(KEY_LOGOFF)

 [KEY_DOLLAR] = XLAT(KEY_DOLLAR),
 #define XLAT_VAL_389 ((unsigned) (KEY_DOLLAR))
 #define XLAT_STR_389 STRINGIFY(KEY_DOLLAR)
 [KEY_EURO] = XLAT(KEY_EURO),
 #define XLAT_VAL_390 ((unsigned) (KEY_EURO))
 #define XLAT_STR_390 STRINGIFY(KEY_EURO)

 [KEY_FRAMEBACK] = XLAT(KEY_FRAMEBACK),
 #define XLAT_VAL_391 ((unsigned) (KEY_FRAMEBACK))
 #define XLAT_STR_391 STRINGIFY(KEY_FRAMEBACK)
 [KEY_FRAMEFORWARD] = XLAT(KEY_FRAMEFORWARD),
 #define XLAT_VAL_392 ((unsigned) (KEY_FRAMEFORWARD))
 #define XLAT_STR_392 STRINGIFY(KEY_FRAMEFORWARD)
 [KEY_CONTEXT_MENU] = XLAT(KEY_CONTEXT_MENU),
 #define XLAT_VAL_393 ((unsigned) (KEY_CONTEXT_MENU))
 #define XLAT_STR_393 STRINGIFY(KEY_CONTEXT_MENU)
 [KEY_MEDIA_REPEAT] = XLAT(KEY_MEDIA_REPEAT),
 #define XLAT_VAL_394 ((unsigned) (KEY_MEDIA_REPEAT))
 #define XLAT_STR_394 STRINGIFY(KEY_MEDIA_REPEAT)
 [KEY_10CHANNELSUP] = XLAT(KEY_10CHANNELSUP),
 #define XLAT_VAL_395 ((unsigned) (KEY_10CHANNELSUP))
 #define XLAT_STR_395 STRINGIFY(KEY_10CHANNELSUP)
 [KEY_10CHANNELSDOWN] = XLAT(KEY_10CHANNELSDOWN),
 #define XLAT_VAL_396 ((unsigned) (KEY_10CHANNELSDOWN))
 #define XLAT_STR_396 STRINGIFY(KEY_10CHANNELSDOWN)
 [KEY_IMAGES] = XLAT(KEY_IMAGES),
 #define XLAT_VAL_397 ((unsigned) (KEY_IMAGES))
 #define XLAT_STR_397 STRINGIFY(KEY_IMAGES)
 [KEY_NOTIFICATION_CENTER] = XLAT(KEY_NOTIFICATION_CENTER),
 #define XLAT_VAL_398 ((unsigned) (KEY_NOTIFICATION_CENTER))
 #define XLAT_STR_398 STRINGIFY(KEY_NOTIFICATION_CENTER)
 [KEY_PICKUP_PHONE] = XLAT(KEY_PICKUP_PHONE),
 #define XLAT_VAL_399 ((unsigned) (KEY_PICKUP_PHONE))
 #define XLAT_STR_399 STRINGIFY(KEY_PICKUP_PHONE)
 [KEY_HANGUP_PHONE] = XLAT(KEY_HANGUP_PHONE),
 #define XLAT_VAL_400 ((unsigned) (KEY_HANGUP_PHONE))
 #define XLAT_STR_400 STRINGIFY(KEY_HANGUP_PHONE)
 [KEY_LINK_PHONE] = XLAT(KEY_LINK_PHONE),
 #define XLAT_VAL_401 ((unsigned) (KEY_LINK_PHONE))
 #define XLAT_STR_401 STRINGIFY(KEY_LINK_PHONE)

 [KEY_DEL_EOL] = XLAT(KEY_DEL_EOL),
 #define XLAT_VAL_402 ((unsigned) (KEY_DEL_EOL))
 #define XLAT_STR_402 STRINGIFY(KEY_DEL_EOL)
 [KEY_DEL_EOS] = XLAT(KEY_DEL_EOS),
 #define XLAT_VAL_403 ((unsigned) (KEY_DEL_EOS))
 #define XLAT_STR_403 STRINGIFY(KEY_DEL_EOS)
 [KEY_INS_LINE] = XLAT(KEY_INS_LINE),
 #define XLAT_VAL_404 ((unsigned) (KEY_INS_LINE))
 #define XLAT_STR_404 STRINGIFY(KEY_INS_LINE)
 [KEY_DEL_LINE] = XLAT(KEY_DEL_LINE),
 #define XLAT_VAL_405 ((unsigned) (KEY_DEL_LINE))
 #define XLAT_STR_405 STRINGIFY(KEY_DEL_LINE)

 [KEY_FN] = XLAT(KEY_FN),
 #define XLAT_VAL_406 ((unsigned) (KEY_FN))
 #define XLAT_STR_406 STRINGIFY(KEY_FN)
 [KEY_FN_ESC] = XLAT(KEY_FN_ESC),
 #define XLAT_VAL_407 ((unsigned) (KEY_FN_ESC))
 #define XLAT_STR_407 STRINGIFY(KEY_FN_ESC)
 [KEY_FN_F1] = XLAT(KEY_FN_F1),
 #define XLAT_VAL_408 ((unsigned) (KEY_FN_F1))
 #define XLAT_STR_408 STRINGIFY(KEY_FN_F1)
 [KEY_FN_F2] = XLAT(KEY_FN_F2),
 #define XLAT_VAL_409 ((unsigned) (KEY_FN_F2))
 #define XLAT_STR_409 STRINGIFY(KEY_FN_F2)
 [KEY_FN_F3] = XLAT(KEY_FN_F3),
 #define XLAT_VAL_410 ((unsigned) (KEY_FN_F3))
 #define XLAT_STR_410 STRINGIFY(KEY_FN_F3)
 [KEY_FN_F4] = XLAT(KEY_FN_F4),
 #define XLAT_VAL_411 ((unsigned) (KEY_FN_F4))
 #define XLAT_STR_411 STRINGIFY(KEY_FN_F4)
 [KEY_FN_F5] = XLAT(KEY_FN_F5),
 #define XLAT_VAL_412 ((unsigned) (KEY_FN_F5))
 #define XLAT_STR_412 STRINGIFY(KEY_FN_F5)
 [KEY_FN_F6] = XLAT(KEY_FN_F6),
 #define XLAT_VAL_413 ((unsigned) (KEY_FN_F6))
 #define XLAT_STR_413 STRINGIFY(KEY_FN_F6)
 [KEY_FN_F7] = XLAT(KEY_FN_F7),
 #define XLAT_VAL_414 ((unsigned) (KEY_FN_F7))
 #define XLAT_STR_414 STRINGIFY(KEY_FN_F7)
 [KEY_FN_F8] = XLAT(KEY_FN_F8),
 #define XLAT_VAL_415 ((unsigned) (KEY_FN_F8))
 #define XLAT_STR_415 STRINGIFY(KEY_FN_F8)
 [KEY_FN_F9] = XLAT(KEY_FN_F9),
 #define XLAT_VAL_416 ((unsigned) (KEY_FN_F9))
 #define XLAT_STR_416 STRINGIFY(KEY_FN_F9)
 [KEY_FN_F10] = XLAT(KEY_FN_F10),
 #define XLAT_VAL_417 ((unsigned) (KEY_FN_F10))
 #define XLAT_STR_417 STRINGIFY(KEY_FN_F10)
 [KEY_FN_F11] = XLAT(KEY_FN_F11),
 #define XLAT_VAL_418 ((unsigned) (KEY_FN_F11))
 #define XLAT_STR_418 STRINGIFY(KEY_FN_F11)
 [KEY_FN_F12] = XLAT(KEY_FN_F12),
 #define XLAT_VAL_419 ((unsigned) (KEY_FN_F12))
 #define XLAT_STR_419 STRINGIFY(KEY_FN_F12)
 [KEY_FN_1] = XLAT(KEY_FN_1),
 #define XLAT_VAL_420 ((unsigned) (KEY_FN_1))
 #define XLAT_STR_420 STRINGIFY(KEY_FN_1)
 [KEY_FN_2] = XLAT(KEY_FN_2),
 #define XLAT_VAL_421 ((unsigned) (KEY_FN_2))
 #define XLAT_STR_421 STRINGIFY(KEY_FN_2)
 [KEY_FN_D] = XLAT(KEY_FN_D),
 #define XLAT_VAL_422 ((unsigned) (KEY_FN_D))
 #define XLAT_STR_422 STRINGIFY(KEY_FN_D)
 [KEY_FN_E] = XLAT(KEY_FN_E),
 #define XLAT_VAL_423 ((unsigned) (KEY_FN_E))
 #define XLAT_STR_423 STRINGIFY(KEY_FN_E)
 [KEY_FN_F] = XLAT(KEY_FN_F),
 #define XLAT_VAL_424 ((unsigned) (KEY_FN_F))
 #define XLAT_STR_424 STRINGIFY(KEY_FN_F)
 [KEY_FN_S] = XLAT(KEY_FN_S),
 #define XLAT_VAL_425 ((unsigned) (KEY_FN_S))
 #define XLAT_STR_425 STRINGIFY(KEY_FN_S)
 [KEY_FN_B] = XLAT(KEY_FN_B),
 #define XLAT_VAL_426 ((unsigned) (KEY_FN_B))
 #define XLAT_STR_426 STRINGIFY(KEY_FN_B)
 [KEY_FN_RIGHT_SHIFT] = XLAT(KEY_FN_RIGHT_SHIFT),
 #define XLAT_VAL_427 ((unsigned) (KEY_FN_RIGHT_SHIFT))
 #define XLAT_STR_427 STRINGIFY(KEY_FN_RIGHT_SHIFT)

 [KEY_BRL_DOT1] = XLAT(KEY_BRL_DOT1),
 #define XLAT_VAL_428 ((unsigned) (KEY_BRL_DOT1))
 #define XLAT_STR_428 STRINGIFY(KEY_BRL_DOT1)
 [KEY_BRL_DOT2] = XLAT(KEY_BRL_DOT2),
 #define XLAT_VAL_429 ((unsigned) (KEY_BRL_DOT2))
 #define XLAT_STR_429 STRINGIFY(KEY_BRL_DOT2)
 [KEY_BRL_DOT3] = XLAT(KEY_BRL_DOT3),
 #define XLAT_VAL_430 ((unsigned) (KEY_BRL_DOT3))
 #define XLAT_STR_430 STRINGIFY(KEY_BRL_DOT3)
 [KEY_BRL_DOT4] = XLAT(KEY_BRL_DOT4),
 #define XLAT_VAL_431 ((unsigned) (KEY_BRL_DOT4))
 #define XLAT_STR_431 STRINGIFY(KEY_BRL_DOT4)
 [KEY_BRL_DOT5] = XLAT(KEY_BRL_DOT5),
 #define XLAT_VAL_432 ((unsigned) (KEY_BRL_DOT5))
 #define XLAT_STR_432 STRINGIFY(KEY_BRL_DOT5)
 [KEY_BRL_DOT6] = XLAT(KEY_BRL_DOT6),
 #define XLAT_VAL_433 ((unsigned) (KEY_BRL_DOT6))
 #define XLAT_STR_433 STRINGIFY(KEY_BRL_DOT6)
 [KEY_BRL_DOT7] = XLAT(KEY_BRL_DOT7),
 #define XLAT_VAL_434 ((unsigned) (KEY_BRL_DOT7))
 #define XLAT_STR_434 STRINGIFY(KEY_BRL_DOT7)
 [KEY_BRL_DOT8] = XLAT(KEY_BRL_DOT8),
 #define XLAT_VAL_435 ((unsigned) (KEY_BRL_DOT8))
 #define XLAT_STR_435 STRINGIFY(KEY_BRL_DOT8)
 [KEY_BRL_DOT9] = XLAT(KEY_BRL_DOT9),
 #define XLAT_VAL_436 ((unsigned) (KEY_BRL_DOT9))
 #define XLAT_STR_436 STRINGIFY(KEY_BRL_DOT9)
 [KEY_BRL_DOT10] = XLAT(KEY_BRL_DOT10),
 #define XLAT_VAL_437 ((unsigned) (KEY_BRL_DOT10))
 #define XLAT_STR_437 STRINGIFY(KEY_BRL_DOT10)

 [KEY_NUMERIC_0] = XLAT(KEY_NUMERIC_0),
 #define XLAT_VAL_438 ((unsigned) (KEY_NUMERIC_0))
 #define XLAT_STR_438 STRINGIFY(KEY_NUMERIC_0)
 [KEY_NUMERIC_1] = XLAT(KEY_NUMERIC_1),
 #define XLAT_VAL_439 ((unsigned) (KEY_NUMERIC_1))
 #define XLAT_STR_439 STRINGIFY(KEY_NUMERIC_1)
 [KEY_NUMERIC_2] = XLAT(KEY_NUMERIC_2),
 #define XLAT_VAL_440 ((unsigned) (KEY_NUMERIC_2))
 #define XLAT_STR_440 STRINGIFY(KEY_NUMERIC_2)
 [KEY_NUMERIC_3] = XLAT(KEY_NUMERIC_3),
 #define XLAT_VAL_441 ((unsigned) (KEY_NUMERIC_3))
 #define XLAT_STR_441 STRINGIFY(KEY_NUMERIC_3)
 [KEY_NUMERIC_4] = XLAT(KEY_NUMERIC_4),
 #define XLAT_VAL_442 ((unsigned) (KEY_NUMERIC_4))
 #define XLAT_STR_442 STRINGIFY(KEY_NUMERIC_4)
 [KEY_NUMERIC_5] = XLAT(KEY_NUMERIC_5),
 #define XLAT_VAL_443 ((unsigned) (KEY_NUMERIC_5))
 #define XLAT_STR_443 STRINGIFY(KEY_NUMERIC_5)
 [KEY_NUMERIC_6] = XLAT(KEY_NUMERIC_6),
 #define XLAT_VAL_444 ((unsigned) (KEY_NUMERIC_6))
 #define XLAT_STR_444 STRINGIFY(KEY_NUMERIC_6)
 [KEY_NUMERIC_7] = XLAT(KEY_NUMERIC_7),
 #define XLAT_VAL_445 ((unsigned) (KEY_NUMERIC_7))
 #define XLAT_STR_445 STRINGIFY(KEY_NUMERIC_7)
 [KEY_NUMERIC_8] = XLAT(KEY_NUMERIC_8),
 #define XLAT_VAL_446 ((unsigned) (KEY_NUMERIC_8))
 #define XLAT_STR_446 STRINGIFY(KEY_NUMERIC_8)
 [KEY_NUMERIC_9] = XLAT(KEY_NUMERIC_9),
 #define XLAT_VAL_447 ((unsigned) (KEY_NUMERIC_9))
 #define XLAT_STR_447 STRINGIFY(KEY_NUMERIC_9)
 [KEY_NUMERIC_STAR] = XLAT(KEY_NUMERIC_STAR),
 #define XLAT_VAL_448 ((unsigned) (KEY_NUMERIC_STAR))
 #define XLAT_STR_448 STRINGIFY(KEY_NUMERIC_STAR)
 [KEY_NUMERIC_POUND] = XLAT(KEY_NUMERIC_POUND),
 #define XLAT_VAL_449 ((unsigned) (KEY_NUMERIC_POUND))
 #define XLAT_STR_449 STRINGIFY(KEY_NUMERIC_POUND)
 [KEY_NUMERIC_A] = XLAT(KEY_NUMERIC_A),
 #define XLAT_VAL_450 ((unsigned) (KEY_NUMERIC_A))
 #define XLAT_STR_450 STRINGIFY(KEY_NUMERIC_A)
 [KEY_NUMERIC_B] = XLAT(KEY_NUMERIC_B),
 #define XLAT_VAL_451 ((unsigned) (KEY_NUMERIC_B))
 #define XLAT_STR_451 STRINGIFY(KEY_NUMERIC_B)
 [KEY_NUMERIC_C] = XLAT(KEY_NUMERIC_C),
 #define XLAT_VAL_452 ((unsigned) (KEY_NUMERIC_C))
 #define XLAT_STR_452 STRINGIFY(KEY_NUMERIC_C)
 [KEY_NUMERIC_D] = XLAT(KEY_NUMERIC_D),
 #define XLAT_VAL_453 ((unsigned) (KEY_NUMERIC_D))
 #define XLAT_STR_453 STRINGIFY(KEY_NUMERIC_D)

 [KEY_CAMERA_FOCUS] = XLAT(KEY_CAMERA_FOCUS),
 #define XLAT_VAL_454 ((unsigned) (KEY_CAMERA_FOCUS))
 #define XLAT_STR_454 STRINGIFY(KEY_CAMERA_FOCUS)
 [KEY_WPS_BUTTON] = XLAT(KEY_WPS_BUTTON),
 #define XLAT_VAL_455 ((unsigned) (KEY_WPS_BUTTON))
 #define XLAT_STR_455 STRINGIFY(KEY_WPS_BUTTON)

 [KEY_TOUCHPAD_TOGGLE] = XLAT(KEY_TOUCHPAD_TOGGLE),
 #define XLAT_VAL_456 ((unsigned) (KEY_TOUCHPAD_TOGGLE))
 #define XLAT_STR_456 STRINGIFY(KEY_TOUCHPAD_TOGGLE)
 [KEY_TOUCHPAD_ON] = XLAT(KEY_TOUCHPAD_ON),
 #define XLAT_VAL_457 ((unsigned) (KEY_TOUCHPAD_ON))
 #define XLAT_STR_457 STRINGIFY(KEY_TOUCHPAD_ON)
 [KEY_TOUCHPAD_OFF] = XLAT(KEY_TOUCHPAD_OFF),
 #define XLAT_VAL_458 ((unsigned) (KEY_TOUCHPAD_OFF))
 #define XLAT_STR_458 STRINGIFY(KEY_TOUCHPAD_OFF)

 [KEY_CAMERA_ZOOMIN] = XLAT(KEY_CAMERA_ZOOMIN),
 #define XLAT_VAL_459 ((unsigned) (KEY_CAMERA_ZOOMIN))
 #define XLAT_STR_459 STRINGIFY(KEY_CAMERA_ZOOMIN)
 [KEY_CAMERA_ZOOMOUT] = XLAT(KEY_CAMERA_ZOOMOUT),
 #define XLAT_VAL_460 ((unsigned) (KEY_CAMERA_ZOOMOUT))
 #define XLAT_STR_460 STRINGIFY(KEY_CAMERA_ZOOMOUT)
 [KEY_CAMERA_UP] = XLAT(KEY_CAMERA_UP),
 #define XLAT_VAL_461 ((unsigned) (KEY_CAMERA_UP))
 #define XLAT_STR_461 STRINGIFY(KEY_CAMERA_UP)
 [KEY_CAMERA_DOWN] = XLAT(KEY_CAMERA_DOWN),
 #define XLAT_VAL_462 ((unsigned) (KEY_CAMERA_DOWN))
 #define XLAT_STR_462 STRINGIFY(KEY_CAMERA_DOWN)
 [KEY_CAMERA_LEFT] = XLAT(KEY_CAMERA_LEFT),
 #define XLAT_VAL_463 ((unsigned) (KEY_CAMERA_LEFT))
 #define XLAT_STR_463 STRINGIFY(KEY_CAMERA_LEFT)
 [KEY_CAMERA_RIGHT] = XLAT(KEY_CAMERA_RIGHT),
 #define XLAT_VAL_464 ((unsigned) (KEY_CAMERA_RIGHT))
 #define XLAT_STR_464 STRINGIFY(KEY_CAMERA_RIGHT)

 [KEY_ATTENDANT_ON] = XLAT(KEY_ATTENDANT_ON),
 #define XLAT_VAL_465 ((unsigned) (KEY_ATTENDANT_ON))
 #define XLAT_STR_465 STRINGIFY(KEY_ATTENDANT_ON)
 [KEY_ATTENDANT_OFF] = XLAT(KEY_ATTENDANT_OFF),
 #define XLAT_VAL_466 ((unsigned) (KEY_ATTENDANT_OFF))
 #define XLAT_STR_466 STRINGIFY(KEY_ATTENDANT_OFF)
 [KEY_ATTENDANT_TOGGLE] = XLAT(KEY_ATTENDANT_TOGGLE),
 #define XLAT_VAL_467 ((unsigned) (KEY_ATTENDANT_TOGGLE))
 #define XLAT_STR_467 STRINGIFY(KEY_ATTENDANT_TOGGLE)
 [KEY_LIGHTS_TOGGLE] = XLAT(KEY_LIGHTS_TOGGLE),
 #define XLAT_VAL_468 ((unsigned) (KEY_LIGHTS_TOGGLE))
 #define XLAT_STR_468 STRINGIFY(KEY_LIGHTS_TOGGLE)

 [BTN_DPAD_UP] = XLAT(BTN_DPAD_UP),
 #define XLAT_VAL_469 ((unsigned) (BTN_DPAD_UP))
 #define XLAT_STR_469 STRINGIFY(BTN_DPAD_UP)
 [BTN_DPAD_DOWN] = XLAT(BTN_DPAD_DOWN),
 #define XLAT_VAL_470 ((unsigned) (BTN_DPAD_DOWN))
 #define XLAT_STR_470 STRINGIFY(BTN_DPAD_DOWN)
 [BTN_DPAD_LEFT] = XLAT(BTN_DPAD_LEFT),
 #define XLAT_VAL_471 ((unsigned) (BTN_DPAD_LEFT))
 #define XLAT_STR_471 STRINGIFY(BTN_DPAD_LEFT)
 [BTN_DPAD_RIGHT] = XLAT(BTN_DPAD_RIGHT),
 #define XLAT_VAL_472 ((unsigned) (BTN_DPAD_RIGHT))
 #define XLAT_STR_472 STRINGIFY(BTN_DPAD_RIGHT)

 [BTN_GRIPL] = XLAT(BTN_GRIPL),
 #define XLAT_VAL_473 ((unsigned) (BTN_GRIPL))
 #define XLAT_STR_473 STRINGIFY(BTN_GRIPL)
 [BTN_GRIPR] = XLAT(BTN_GRIPR),
 #define XLAT_VAL_474 ((unsigned) (BTN_GRIPR))
 #define XLAT_STR_474 STRINGIFY(BTN_GRIPR)
 [BTN_GRIPL2] = XLAT(BTN_GRIPL2),
 #define XLAT_VAL_475 ((unsigned) (BTN_GRIPL2))
 #define XLAT_STR_475 STRINGIFY(BTN_GRIPL2)
 [BTN_GRIPR2] = XLAT(BTN_GRIPR2),
 #define XLAT_VAL_476 ((unsigned) (BTN_GRIPR2))
 #define XLAT_STR_476 STRINGIFY(BTN_GRIPR2)

 [KEY_ALS_TOGGLE] = XLAT(KEY_ALS_TOGGLE),
 #define XLAT_VAL_477 ((unsigned) (KEY_ALS_TOGGLE))
 #define XLAT_STR_477 STRINGIFY(KEY_ALS_TOGGLE)
 [KEY_ROTATE_LOCK_TOGGLE] = XLAT(KEY_ROTATE_LOCK_TOGGLE),
 #define XLAT_VAL_478 ((unsigned) (KEY_ROTATE_LOCK_TOGGLE))
 #define XLAT_STR_478 STRINGIFY(KEY_ROTATE_LOCK_TOGGLE)
 [KEY_REFRESH_RATE_TOGGLE] = XLAT(KEY_REFRESH_RATE_TOGGLE),
 #define XLAT_VAL_479 ((unsigned) (KEY_REFRESH_RATE_TOGGLE))
 #define XLAT_STR_479 STRINGIFY(KEY_REFRESH_RATE_TOGGLE)

 [KEY_BUTTONCONFIG] = XLAT(KEY_BUTTONCONFIG),
 #define XLAT_VAL_480 ((unsigned) (KEY_BUTTONCONFIG))
 #define XLAT_STR_480 STRINGIFY(KEY_BUTTONCONFIG)
 [KEY_TASKMANAGER] = XLAT(KEY_TASKMANAGER),
 #define XLAT_VAL_481 ((unsigned) (KEY_TASKMANAGER))
 #define XLAT_STR_481 STRINGIFY(KEY_TASKMANAGER)
 [KEY_JOURNAL] = XLAT(KEY_JOURNAL),
 #define XLAT_VAL_482 ((unsigned) (KEY_JOURNAL))
 #define XLAT_STR_482 STRINGIFY(KEY_JOURNAL)
 [KEY_CONTROLPANEL] = XLAT(KEY_CONTROLPANEL),
 #define XLAT_VAL_483 ((unsigned) (KEY_CONTROLPANEL))
 #define XLAT_STR_483 STRINGIFY(KEY_CONTROLPANEL)
 [KEY_APPSELECT] = XLAT(KEY_APPSELECT),
 #define XLAT_VAL_484 ((unsigned) (KEY_APPSELECT))
 #define XLAT_STR_484 STRINGIFY(KEY_APPSELECT)
 [KEY_SCREENSAVER] = XLAT(KEY_SCREENSAVER),
 #define XLAT_VAL_485 ((unsigned) (KEY_SCREENSAVER))
 #define XLAT_STR_485 STRINGIFY(KEY_SCREENSAVER)
 [KEY_VOICECOMMAND] = XLAT(KEY_VOICECOMMAND),
 #define XLAT_VAL_486 ((unsigned) (KEY_VOICECOMMAND))
 #define XLAT_STR_486 STRINGIFY(KEY_VOICECOMMAND)
 [KEY_ASSISTANT] = XLAT(KEY_ASSISTANT),
 #define XLAT_VAL_487 ((unsigned) (KEY_ASSISTANT))
 #define XLAT_STR_487 STRINGIFY(KEY_ASSISTANT)
 [KEY_KBD_LAYOUT_NEXT] = XLAT(KEY_KBD_LAYOUT_NEXT),
 #define XLAT_VAL_488 ((unsigned) (KEY_KBD_LAYOUT_NEXT))
 #define XLAT_STR_488 STRINGIFY(KEY_KBD_LAYOUT_NEXT)
 [KEY_EMOJI_PICKER] = XLAT(KEY_EMOJI_PICKER),
 #define XLAT_VAL_489 ((unsigned) (KEY_EMOJI_PICKER))
 #define XLAT_STR_489 STRINGIFY(KEY_EMOJI_PICKER)
 [KEY_DICTATE] = XLAT(KEY_DICTATE),
 #define XLAT_VAL_490 ((unsigned) (KEY_DICTATE))
 #define XLAT_STR_490 STRINGIFY(KEY_DICTATE)
 [KEY_CAMERA_ACCESS_ENABLE] = XLAT(KEY_CAMERA_ACCESS_ENABLE),
 #define XLAT_VAL_491 ((unsigned) (KEY_CAMERA_ACCESS_ENABLE))
 #define XLAT_STR_491 STRINGIFY(KEY_CAMERA_ACCESS_ENABLE)
 [KEY_CAMERA_ACCESS_DISABLE] = XLAT(KEY_CAMERA_ACCESS_DISABLE),
 #define XLAT_VAL_492 ((unsigned) (KEY_CAMERA_ACCESS_DISABLE))
 #define XLAT_STR_492 STRINGIFY(KEY_CAMERA_ACCESS_DISABLE)
 [KEY_CAMERA_ACCESS_TOGGLE] = XLAT(KEY_CAMERA_ACCESS_TOGGLE),
 #define XLAT_VAL_493 ((unsigned) (KEY_CAMERA_ACCESS_TOGGLE))
 #define XLAT_STR_493 STRINGIFY(KEY_CAMERA_ACCESS_TOGGLE)
 [KEY_ACCESSIBILITY] = XLAT(KEY_ACCESSIBILITY),
 #define XLAT_VAL_494 ((unsigned) (KEY_ACCESSIBILITY))
 #define XLAT_STR_494 STRINGIFY(KEY_ACCESSIBILITY)
 [KEY_DO_NOT_DISTURB] = XLAT(KEY_DO_NOT_DISTURB),
 #define XLAT_VAL_495 ((unsigned) (KEY_DO_NOT_DISTURB))
 #define XLAT_STR_495 STRINGIFY(KEY_DO_NOT_DISTURB)

 [KEY_BRIGHTNESS_MIN] = XLAT(KEY_BRIGHTNESS_MIN),
 #define XLAT_VAL_496 ((unsigned) (KEY_BRIGHTNESS_MIN))
 #define XLAT_STR_496 STRINGIFY(KEY_BRIGHTNESS_MIN)
 [KEY_BRIGHTNESS_MAX] = XLAT(KEY_BRIGHTNESS_MAX),
 #define XLAT_VAL_497 ((unsigned) (KEY_BRIGHTNESS_MAX))
 #define XLAT_STR_497 STRINGIFY(KEY_BRIGHTNESS_MAX)

 [KEY_EPRIVACY_SCREEN_ON] = XLAT(KEY_EPRIVACY_SCREEN_ON),
 #define XLAT_VAL_498 ((unsigned) (KEY_EPRIVACY_SCREEN_ON))
 #define XLAT_STR_498 STRINGIFY(KEY_EPRIVACY_SCREEN_ON)
 [KEY_EPRIVACY_SCREEN_OFF] = XLAT(KEY_EPRIVACY_SCREEN_OFF),
 #define XLAT_VAL_499 ((unsigned) (KEY_EPRIVACY_SCREEN_OFF))
 #define XLAT_STR_499 STRINGIFY(KEY_EPRIVACY_SCREEN_OFF)

 [KEY_KBDINPUTASSIST_PREV] = XLAT(KEY_KBDINPUTASSIST_PREV),
 #define XLAT_VAL_500 ((unsigned) (KEY_KBDINPUTASSIST_PREV))
 #define XLAT_STR_500 STRINGIFY(KEY_KBDINPUTASSIST_PREV)
 [KEY_KBDINPUTASSIST_NEXT] = XLAT(KEY_KBDINPUTASSIST_NEXT),
 #define XLAT_VAL_501 ((unsigned) (KEY_KBDINPUTASSIST_NEXT))
 #define XLAT_STR_501 STRINGIFY(KEY_KBDINPUTASSIST_NEXT)
 [KEY_KBDINPUTASSIST_PREVGROUP] = XLAT(KEY_KBDINPUTASSIST_PREVGROUP),
 #define XLAT_VAL_502 ((unsigned) (KEY_KBDINPUTASSIST_PREVGROUP))
 #define XLAT_STR_502 STRINGIFY(KEY_KBDINPUTASSIST_PREVGROUP)
 [KEY_KBDINPUTASSIST_NEXTGROUP] = XLAT(KEY_KBDINPUTASSIST_NEXTGROUP),
 #define XLAT_VAL_503 ((unsigned) (KEY_KBDINPUTASSIST_NEXTGROUP))
 #define XLAT_STR_503 STRINGIFY(KEY_KBDINPUTASSIST_NEXTGROUP)
 [KEY_KBDINPUTASSIST_ACCEPT] = XLAT(KEY_KBDINPUTASSIST_ACCEPT),
 #define XLAT_VAL_504 ((unsigned) (KEY_KBDINPUTASSIST_ACCEPT))
 #define XLAT_STR_504 STRINGIFY(KEY_KBDINPUTASSIST_ACCEPT)
 [KEY_KBDINPUTASSIST_CANCEL] = XLAT(KEY_KBDINPUTASSIST_CANCEL),
 #define XLAT_VAL_505 ((unsigned) (KEY_KBDINPUTASSIST_CANCEL))
 #define XLAT_STR_505 STRINGIFY(KEY_KBDINPUTASSIST_CANCEL)

 [KEY_RIGHT_UP] = XLAT(KEY_RIGHT_UP),
 #define XLAT_VAL_506 ((unsigned) (KEY_RIGHT_UP))
 #define XLAT_STR_506 STRINGIFY(KEY_RIGHT_UP)
 [KEY_RIGHT_DOWN] = XLAT(KEY_RIGHT_DOWN),
 #define XLAT_VAL_507 ((unsigned) (KEY_RIGHT_DOWN))
 #define XLAT_STR_507 STRINGIFY(KEY_RIGHT_DOWN)
 [KEY_LEFT_UP] = XLAT(KEY_LEFT_UP),
 #define XLAT_VAL_508 ((unsigned) (KEY_LEFT_UP))
 #define XLAT_STR_508 STRINGIFY(KEY_LEFT_UP)
 [KEY_LEFT_DOWN] = XLAT(KEY_LEFT_DOWN),
 #define XLAT_VAL_509 ((unsigned) (KEY_LEFT_DOWN))
 #define XLAT_STR_509 STRINGIFY(KEY_LEFT_DOWN)

 [KEY_ROOT_MENU] = XLAT(KEY_ROOT_MENU),
 #define XLAT_VAL_510 ((unsigned) (KEY_ROOT_MENU))
 #define XLAT_STR_510 STRINGIFY(KEY_ROOT_MENU)
 [KEY_MEDIA_TOP_MENU] = XLAT(KEY_MEDIA_TOP_MENU),
 #define XLAT_VAL_511 ((unsigned) (KEY_MEDIA_TOP_MENU))
 #define XLAT_STR_511 STRINGIFY(KEY_MEDIA_TOP_MENU)
 [KEY_NUMERIC_11] = XLAT(KEY_NUMERIC_11),
 #define XLAT_VAL_512 ((unsigned) (KEY_NUMERIC_11))
 #define XLAT_STR_512 STRINGIFY(KEY_NUMERIC_11)
 [KEY_NUMERIC_12] = XLAT(KEY_NUMERIC_12),
 #define XLAT_VAL_513 ((unsigned) (KEY_NUMERIC_12))
 #define XLAT_STR_513 STRINGIFY(KEY_NUMERIC_12)

 [KEY_AUDIO_DESC] = XLAT(KEY_AUDIO_DESC),
 #define XLAT_VAL_514 ((unsigned) (KEY_AUDIO_DESC))
 #define XLAT_STR_514 STRINGIFY(KEY_AUDIO_DESC)
 [KEY_3D_MODE] = XLAT(KEY_3D_MODE),
 #define XLAT_VAL_515 ((unsigned) (KEY_3D_MODE))
 #define XLAT_STR_515 STRINGIFY(KEY_3D_MODE)
 [KEY_NEXT_FAVORITE] = XLAT(KEY_NEXT_FAVORITE),
 #define XLAT_VAL_516 ((unsigned) (KEY_NEXT_FAVORITE))
 #define XLAT_STR_516 STRINGIFY(KEY_NEXT_FAVORITE)
 [KEY_STOP_RECORD] = XLAT(KEY_STOP_RECORD),
 #define XLAT_VAL_517 ((unsigned) (KEY_STOP_RECORD))
 #define XLAT_STR_517 STRINGIFY(KEY_STOP_RECORD)
 [KEY_PAUSE_RECORD] = XLAT(KEY_PAUSE_RECORD),
 #define XLAT_VAL_518 ((unsigned) (KEY_PAUSE_RECORD))
 #define XLAT_STR_518 STRINGIFY(KEY_PAUSE_RECORD)
 [KEY_VOD] = XLAT(KEY_VOD),
 #define XLAT_VAL_519 ((unsigned) (KEY_VOD))
 #define XLAT_STR_519 STRINGIFY(KEY_VOD)
 [KEY_UNMUTE] = XLAT(KEY_UNMUTE),
 #define XLAT_VAL_520 ((unsigned) (KEY_UNMUTE))
 #define XLAT_STR_520 STRINGIFY(KEY_UNMUTE)
 [KEY_FASTREVERSE] = XLAT(KEY_FASTREVERSE),
 #define XLAT_VAL_521 ((unsigned) (KEY_FASTREVERSE))
 #define XLAT_STR_521 STRINGIFY(KEY_FASTREVERSE)
 [KEY_SLOWREVERSE] = XLAT(KEY_SLOWREVERSE),
 #define XLAT_VAL_522 ((unsigned) (KEY_SLOWREVERSE))
 #define XLAT_STR_522 STRINGIFY(KEY_SLOWREVERSE)

 [KEY_DATA] = XLAT(KEY_DATA),
 #define XLAT_VAL_523 ((unsigned) (KEY_DATA))
 #define XLAT_STR_523 STRINGIFY(KEY_DATA)
 [KEY_ONSCREEN_KEYBOARD] = XLAT(KEY_ONSCREEN_KEYBOARD),
 #define XLAT_VAL_524 ((unsigned) (KEY_ONSCREEN_KEYBOARD))
 #define XLAT_STR_524 STRINGIFY(KEY_ONSCREEN_KEYBOARD)
 [KEY_PRIVACY_SCREEN_TOGGLE] = XLAT(KEY_PRIVACY_SCREEN_TOGGLE),
 #define XLAT_VAL_525 ((unsigned) (KEY_PRIVACY_SCREEN_TOGGLE))
 #define XLAT_STR_525 STRINGIFY(KEY_PRIVACY_SCREEN_TOGGLE)

 [KEY_SELECTIVE_SCREENSHOT] = XLAT(KEY_SELECTIVE_SCREENSHOT),
 #define XLAT_VAL_526 ((unsigned) (KEY_SELECTIVE_SCREENSHOT))
 #define XLAT_STR_526 STRINGIFY(KEY_SELECTIVE_SCREENSHOT)

 [KEY_NEXT_ELEMENT] = XLAT(KEY_NEXT_ELEMENT),
 #define XLAT_VAL_527 ((unsigned) (KEY_NEXT_ELEMENT))
 #define XLAT_STR_527 STRINGIFY(KEY_NEXT_ELEMENT)
 [KEY_PREVIOUS_ELEMENT] = XLAT(KEY_PREVIOUS_ELEMENT),
 #define XLAT_VAL_528 ((unsigned) (KEY_PREVIOUS_ELEMENT))
 #define XLAT_STR_528 STRINGIFY(KEY_PREVIOUS_ELEMENT)

 [KEY_AUTOPILOT_ENGAGE_TOGGLE] = XLAT(KEY_AUTOPILOT_ENGAGE_TOGGLE),
 #define XLAT_VAL_529 ((unsigned) (KEY_AUTOPILOT_ENGAGE_TOGGLE))
 #define XLAT_STR_529 STRINGIFY(KEY_AUTOPILOT_ENGAGE_TOGGLE)

 [KEY_MARK_WAYPOINT] = XLAT(KEY_MARK_WAYPOINT),
 #define XLAT_VAL_530 ((unsigned) (KEY_MARK_WAYPOINT))
 #define XLAT_STR_530 STRINGIFY(KEY_MARK_WAYPOINT)
 [KEY_SOS] = XLAT(KEY_SOS),
 #define XLAT_VAL_531 ((unsigned) (KEY_SOS))
 #define XLAT_STR_531 STRINGIFY(KEY_SOS)
 [KEY_NAV_CHART] = XLAT(KEY_NAV_CHART),
 #define XLAT_VAL_532 ((unsigned) (KEY_NAV_CHART))
 #define XLAT_STR_532 STRINGIFY(KEY_NAV_CHART)
 [KEY_FISHING_CHART] = XLAT(KEY_FISHING_CHART),
 #define XLAT_VAL_533 ((unsigned) (KEY_FISHING_CHART))
 #define XLAT_STR_533 STRINGIFY(KEY_FISHING_CHART)
 [KEY_SINGLE_RANGE_RADAR] = XLAT(KEY_SINGLE_RANGE_RADAR),
 #define XLAT_VAL_534 ((unsigned) (KEY_SINGLE_RANGE_RADAR))
 #define XLAT_STR_534 STRINGIFY(KEY_SINGLE_RANGE_RADAR)
 [KEY_DUAL_RANGE_RADAR] = XLAT(KEY_DUAL_RANGE_RADAR),
 #define XLAT_VAL_535 ((unsigned) (KEY_DUAL_RANGE_RADAR))
 #define XLAT_STR_535 STRINGIFY(KEY_DUAL_RANGE_RADAR)
 [KEY_RADAR_OVERLAY] = XLAT(KEY_RADAR_OVERLAY),
 #define XLAT_VAL_536 ((unsigned) (KEY_RADAR_OVERLAY))
 #define XLAT_STR_536 STRINGIFY(KEY_RADAR_OVERLAY)
 [KEY_TRADITIONAL_SONAR] = XLAT(KEY_TRADITIONAL_SONAR),
 #define XLAT_VAL_537 ((unsigned) (KEY_TRADITIONAL_SONAR))
 #define XLAT_STR_537 STRINGIFY(KEY_TRADITIONAL_SONAR)
 [KEY_CLEARVU_SONAR] = XLAT(KEY_CLEARVU_SONAR),
 #define XLAT_VAL_538 ((unsigned) (KEY_CLEARVU_SONAR))
 #define XLAT_STR_538 STRINGIFY(KEY_CLEARVU_SONAR)
 [KEY_SIDEVU_SONAR] = XLAT(KEY_SIDEVU_SONAR),
 #define XLAT_VAL_539 ((unsigned) (KEY_SIDEVU_SONAR))
 #define XLAT_STR_539 STRINGIFY(KEY_SIDEVU_SONAR)
 [KEY_NAV_INFO] = XLAT(KEY_NAV_INFO),
 #define XLAT_VAL_540 ((unsigned) (KEY_NAV_INFO))
 #define XLAT_STR_540 STRINGIFY(KEY_NAV_INFO)
 [KEY_BRIGHTNESS_MENU] = XLAT(KEY_BRIGHTNESS_MENU),
 #define XLAT_VAL_541 ((unsigned) (KEY_BRIGHTNESS_MENU))
 #define XLAT_STR_541 STRINGIFY(KEY_BRIGHTNESS_MENU)

 [KEY_MACRO1] = XLAT(KEY_MACRO1),
 #define XLAT_VAL_542 ((unsigned) (KEY_MACRO1))
 #define XLAT_STR_542 STRINGIFY(KEY_MACRO1)
 [KEY_MACRO2] = XLAT(KEY_MACRO2),
 #define XLAT_VAL_543 ((unsigned) (KEY_MACRO2))
 #define XLAT_STR_543 STRINGIFY(KEY_MACRO2)
 [KEY_MACRO3] = XLAT(KEY_MACRO3),
 #define XLAT_VAL_544 ((unsigned) (KEY_MACRO3))
 #define XLAT_STR_544 STRINGIFY(KEY_MACRO3)
 [KEY_MACRO4] = XLAT(KEY_MACRO4),
 #define XLAT_VAL_545 ((unsigned) (KEY_MACRO4))
 #define XLAT_STR_545 STRINGIFY(KEY_MACRO4)
 [KEY_MACRO5] = XLAT(KEY_MACRO5),
 #define XLAT_VAL_546 ((unsigned) (KEY_MACRO5))
 #define XLAT_STR_546 STRINGIFY(KEY_MACRO5)
 [KEY_MACRO6] = XLAT(KEY_MACRO6),
 #define XLAT_VAL_547 ((unsigned) (KEY_MACRO6))
 #define XLAT_STR_547 STRINGIFY(KEY_MACRO6)
 [KEY_MACRO7] = XLAT(KEY_MACRO7),
 #define XLAT_VAL_548 ((unsigned) (KEY_MACRO7))
 #define XLAT_STR_548 STRINGIFY(KEY_MACRO7)
 [KEY_MACRO8] = XLAT(KEY_MACRO8),
 #define XLAT_VAL_549 ((unsigned) (KEY_MACRO8))
 #define XLAT_STR_549 STRINGIFY(KEY_MACRO8)
 [KEY_MACRO9] = XLAT(KEY_MACRO9),
 #define XLAT_VAL_550 ((unsigned) (KEY_MACRO9))
 #define XLAT_STR_550 STRINGIFY(KEY_MACRO9)
 [KEY_MACRO10] = XLAT(KEY_MACRO10),
 #define XLAT_VAL_551 ((unsigned) (KEY_MACRO10))
 #define XLAT_STR_551 STRINGIFY(KEY_MACRO10)
 [KEY_MACRO11] = XLAT(KEY_MACRO11),
 #define XLAT_VAL_552 ((unsigned) (KEY_MACRO11))
 #define XLAT_STR_552 STRINGIFY(KEY_MACRO11)
 [KEY_MACRO12] = XLAT(KEY_MACRO12),
 #define XLAT_VAL_553 ((unsigned) (KEY_MACRO12))
 #define XLAT_STR_553 STRINGIFY(KEY_MACRO12)
 [KEY_MACRO13] = XLAT(KEY_MACRO13),
 #define XLAT_VAL_554 ((unsigned) (KEY_MACRO13))
 #define XLAT_STR_554 STRINGIFY(KEY_MACRO13)
 [KEY_MACRO14] = XLAT(KEY_MACRO14),
 #define XLAT_VAL_555 ((unsigned) (KEY_MACRO14))
 #define XLAT_STR_555 STRINGIFY(KEY_MACRO14)
 [KEY_MACRO15] = XLAT(KEY_MACRO15),
 #define XLAT_VAL_556 ((unsigned) (KEY_MACRO15))
 #define XLAT_STR_556 STRINGIFY(KEY_MACRO15)
 [KEY_MACRO16] = XLAT(KEY_MACRO16),
 #define XLAT_VAL_557 ((unsigned) (KEY_MACRO16))
 #define XLAT_STR_557 STRINGIFY(KEY_MACRO16)
 [KEY_MACRO17] = XLAT(KEY_MACRO17),
 #define XLAT_VAL_558 ((unsigned) (KEY_MACRO17))
 #define XLAT_STR_558 STRINGIFY(KEY_MACRO17)
 [KEY_MACRO18] = XLAT(KEY_MACRO18),
 #define XLAT_VAL_559 ((unsigned) (KEY_MACRO18))
 #define XLAT_STR_559 STRINGIFY(KEY_MACRO18)
 [KEY_MACRO19] = XLAT(KEY_MACRO19),
 #define XLAT_VAL_560 ((unsigned) (KEY_MACRO19))
 #define XLAT_STR_560 STRINGIFY(KEY_MACRO19)
 [KEY_MACRO20] = XLAT(KEY_MACRO20),
 #define XLAT_VAL_561 ((unsigned) (KEY_MACRO20))
 #define XLAT_STR_561 STRINGIFY(KEY_MACRO20)
 [KEY_MACRO21] = XLAT(KEY_MACRO21),
 #define XLAT_VAL_562 ((unsigned) (KEY_MACRO21))
 #define XLAT_STR_562 STRINGIFY(KEY_MACRO21)
 [KEY_MACRO22] = XLAT(KEY_MACRO22),
 #define XLAT_VAL_563 ((unsigned) (KEY_MACRO22))
 #define XLAT_STR_563 STRINGIFY(KEY_MACRO22)
 [KEY_MACRO23] = XLAT(KEY_MACRO23),
 #define XLAT_VAL_564 ((unsigned) (KEY_MACRO23))
 #define XLAT_STR_564 STRINGIFY(KEY_MACRO23)
 [KEY_MACRO24] = XLAT(KEY_MACRO24),
 #define XLAT_VAL_565 ((unsigned) (KEY_MACRO24))
 #define XLAT_STR_565 STRINGIFY(KEY_MACRO24)
 [KEY_MACRO25] = XLAT(KEY_MACRO25),
 #define XLAT_VAL_566 ((unsigned) (KEY_MACRO25))
 #define XLAT_STR_566 STRINGIFY(KEY_MACRO25)
 [KEY_MACRO26] = XLAT(KEY_MACRO26),
 #define XLAT_VAL_567 ((unsigned) (KEY_MACRO26))
 #define XLAT_STR_567 STRINGIFY(KEY_MACRO26)
 [KEY_MACRO27] = XLAT(KEY_MACRO27),
 #define XLAT_VAL_568 ((unsigned) (KEY_MACRO27))
 #define XLAT_STR_568 STRINGIFY(KEY_MACRO27)
 [KEY_MACRO28] = XLAT(KEY_MACRO28),
 #define XLAT_VAL_569 ((unsigned) (KEY_MACRO28))
 #define XLAT_STR_569 STRINGIFY(KEY_MACRO28)
 [KEY_MACRO29] = XLAT(KEY_MACRO29),
 #define XLAT_VAL_570 ((unsigned) (KEY_MACRO29))
 #define XLAT_STR_570 STRINGIFY(KEY_MACRO29)
 [KEY_MACRO30] = XLAT(KEY_MACRO30),
 #define XLAT_VAL_571 ((unsigned) (KEY_MACRO30))
 #define XLAT_STR_571 STRINGIFY(KEY_MACRO30)

 [KEY_MACRO_RECORD_START] = XLAT(KEY_MACRO_RECORD_START),
 #define XLAT_VAL_572 ((unsigned) (KEY_MACRO_RECORD_START))
 #define XLAT_STR_572 STRINGIFY(KEY_MACRO_RECORD_START)
 [KEY_MACRO_RECORD_STOP] = XLAT(KEY_MACRO_RECORD_STOP),
 #define XLAT_VAL_573 ((unsigned) (KEY_MACRO_RECORD_STOP))
 #define XLAT_STR_573 STRINGIFY(KEY_MACRO_RECORD_STOP)
 [KEY_MACRO_PRESET_CYCLE] = XLAT(KEY_MACRO_PRESET_CYCLE),
 #define XLAT_VAL_574 ((unsigned) (KEY_MACRO_PRESET_CYCLE))
 #define XLAT_STR_574 STRINGIFY(KEY_MACRO_PRESET_CYCLE)
 [KEY_MACRO_PRESET1] = XLAT(KEY_MACRO_PRESET1),
 #define XLAT_VAL_575 ((unsigned) (KEY_MACRO_PRESET1))
 #define XLAT_STR_575 STRINGIFY(KEY_MACRO_PRESET1)
 [KEY_MACRO_PRESET2] = XLAT(KEY_MACRO_PRESET2),
 #define XLAT_VAL_576 ((unsigned) (KEY_MACRO_PRESET2))
 #define XLAT_STR_576 STRINGIFY(KEY_MACRO_PRESET2)
 [KEY_MACRO_PRESET3] = XLAT(KEY_MACRO_PRESET3),
 #define XLAT_VAL_577 ((unsigned) (KEY_MACRO_PRESET3))
 #define XLAT_STR_577 STRINGIFY(KEY_MACRO_PRESET3)

 [KEY_KBD_LCD_MENU1] = XLAT(KEY_KBD_LCD_MENU1),
 #define XLAT_VAL_578 ((unsigned) (KEY_KBD_LCD_MENU1))
 #define XLAT_STR_578 STRINGIFY(KEY_KBD_LCD_MENU1)
 [KEY_KBD_LCD_MENU2] = XLAT(KEY_KBD_LCD_MENU2),
 #define XLAT_VAL_579 ((unsigned) (KEY_KBD_LCD_MENU2))
 #define XLAT_STR_579 STRINGIFY(KEY_KBD_LCD_MENU2)
 [KEY_KBD_LCD_MENU3] = XLAT(KEY_KBD_LCD_MENU3),
 #define XLAT_VAL_580 ((unsigned) (KEY_KBD_LCD_MENU3))
 #define XLAT_STR_580 STRINGIFY(KEY_KBD_LCD_MENU3)
 [KEY_KBD_LCD_MENU4] = XLAT(KEY_KBD_LCD_MENU4),
 #define XLAT_VAL_581 ((unsigned) (KEY_KBD_LCD_MENU4))
 #define XLAT_STR_581 STRINGIFY(KEY_KBD_LCD_MENU4)
 [KEY_KBD_LCD_MENU5] = XLAT(KEY_KBD_LCD_MENU5),
 #define XLAT_VAL_582 ((unsigned) (KEY_KBD_LCD_MENU5))
 #define XLAT_STR_582 STRINGIFY(KEY_KBD_LCD_MENU5)

 [KEY_PERFORMANCE] = XLAT(KEY_PERFORMANCE),
 #define XLAT_VAL_583 ((unsigned) (KEY_PERFORMANCE))
 #define XLAT_STR_583 STRINGIFY(KEY_PERFORMANCE)

 [BTN_TRIGGER_HAPPY1] = XLAT(BTN_TRIGGER_HAPPY1),
 #define XLAT_VAL_584 ((unsigned) (BTN_TRIGGER_HAPPY1))
 #define XLAT_STR_584 STRINGIFY(BTN_TRIGGER_HAPPY1)
 [BTN_TRIGGER_HAPPY2] = XLAT(BTN_TRIGGER_HAPPY2),
 #define XLAT_VAL_585 ((unsigned) (BTN_TRIGGER_HAPPY2))
 #define XLAT_STR_585 STRINGIFY(BTN_TRIGGER_HAPPY2)
 [BTN_TRIGGER_HAPPY3] = XLAT(BTN_TRIGGER_HAPPY3),
 #define XLAT_VAL_586 ((unsigned) (BTN_TRIGGER_HAPPY3))
 #define XLAT_STR_586 STRINGIFY(BTN_TRIGGER_HAPPY3)
 [BTN_TRIGGER_HAPPY4] = XLAT(BTN_TRIGGER_HAPPY4),
 #define XLAT_VAL_587 ((unsigned) (BTN_TRIGGER_HAPPY4))
 #define XLAT_STR_587 STRINGIFY(BTN_TRIGGER_HAPPY4)
 [BTN_TRIGGER_HAPPY5] = XLAT(BTN_TRIGGER_HAPPY5),
 #define XLAT_VAL_588 ((unsigned) (BTN_TRIGGER_HAPPY5))
 #define XLAT_STR_588 STRINGIFY(BTN_TRIGGER_HAPPY5)
 [BTN_TRIGGER_HAPPY6] = XLAT(BTN_TRIGGER_HAPPY6),
 #define XLAT_VAL_589 ((unsigned) (BTN_TRIGGER_HAPPY6))
 #define XLAT_STR_589 STRINGIFY(BTN_TRIGGER_HAPPY6)
 [BTN_TRIGGER_HAPPY7] = XLAT(BTN_TRIGGER_HAPPY7),
 #define XLAT_VAL_590 ((unsigned) (BTN_TRIGGER_HAPPY7))
 #define XLAT_STR_590 STRINGIFY(BTN_TRIGGER_HAPPY7)
 [BTN_TRIGGER_HAPPY8] = XLAT(BTN_TRIGGER_HAPPY8),
 #define XLAT_VAL_591 ((unsigned) (BTN_TRIGGER_HAPPY8))
 #define XLAT_STR_591 STRINGIFY(BTN_TRIGGER_HAPPY8)
 [BTN_TRIGGER_HAPPY9] = XLAT(BTN_TRIGGER_HAPPY9),
 #define XLAT_VAL_592 ((unsigned) (BTN_TRIGGER_HAPPY9))
 #define XLAT_STR_592 STRINGIFY(BTN_TRIGGER_HAPPY9)
 [BTN_TRIGGER_HAPPY10] = XLAT(BTN_TRIGGER_HAPPY10),
 #define XLAT_VAL_593 ((unsigned) (BTN_TRIGGER_HAPPY10))
 #define XLAT_STR_593 STRINGIFY(BTN_TRIGGER_HAPPY10)
 [BTN_TRIGGER_HAPPY11] = XLAT(BTN_TRIGGER_HAPPY11),
 #define XLAT_VAL_594 ((unsigned) (BTN_TRIGGER_HAPPY11))
 #define XLAT_STR_594 STRINGIFY(BTN_TRIGGER_HAPPY11)
 [BTN_TRIGGER_HAPPY12] = XLAT(BTN_TRIGGER_HAPPY12),
 #define XLAT_VAL_595 ((unsigned) (BTN_TRIGGER_HAPPY12))
 #define XLAT_STR_595 STRINGIFY(BTN_TRIGGER_HAPPY12)
 [BTN_TRIGGER_HAPPY13] = XLAT(BTN_TRIGGER_HAPPY13),
 #define XLAT_VAL_596 ((unsigned) (BTN_TRIGGER_HAPPY13))
 #define XLAT_STR_596 STRINGIFY(BTN_TRIGGER_HAPPY13)
 [BTN_TRIGGER_HAPPY14] = XLAT(BTN_TRIGGER_HAPPY14),
 #define XLAT_VAL_597 ((unsigned) (BTN_TRIGGER_HAPPY14))
 #define XLAT_STR_597 STRINGIFY(BTN_TRIGGER_HAPPY14)
 [BTN_TRIGGER_HAPPY15] = XLAT(BTN_TRIGGER_HAPPY15),
 #define XLAT_VAL_598 ((unsigned) (BTN_TRIGGER_HAPPY15))
 #define XLAT_STR_598 STRINGIFY(BTN_TRIGGER_HAPPY15)
 [BTN_TRIGGER_HAPPY16] = XLAT(BTN_TRIGGER_HAPPY16),
 #define XLAT_VAL_599 ((unsigned) (BTN_TRIGGER_HAPPY16))
 #define XLAT_STR_599 STRINGIFY(BTN_TRIGGER_HAPPY16)
 [BTN_TRIGGER_HAPPY17] = XLAT(BTN_TRIGGER_HAPPY17),
 #define XLAT_VAL_600 ((unsigned) (BTN_TRIGGER_HAPPY17))
 #define XLAT_STR_600 STRINGIFY(BTN_TRIGGER_HAPPY17)
 [BTN_TRIGGER_HAPPY18] = XLAT(BTN_TRIGGER_HAPPY18),
 #define XLAT_VAL_601 ((unsigned) (BTN_TRIGGER_HAPPY18))
 #define XLAT_STR_601 STRINGIFY(BTN_TRIGGER_HAPPY18)
 [BTN_TRIGGER_HAPPY19] = XLAT(BTN_TRIGGER_HAPPY19),
 #define XLAT_VAL_602 ((unsigned) (BTN_TRIGGER_HAPPY19))
 #define XLAT_STR_602 STRINGIFY(BTN_TRIGGER_HAPPY19)
 [BTN_TRIGGER_HAPPY20] = XLAT(BTN_TRIGGER_HAPPY20),
 #define XLAT_VAL_603 ((unsigned) (BTN_TRIGGER_HAPPY20))
 #define XLAT_STR_603 STRINGIFY(BTN_TRIGGER_HAPPY20)
 [BTN_TRIGGER_HAPPY21] = XLAT(BTN_TRIGGER_HAPPY21),
 #define XLAT_VAL_604 ((unsigned) (BTN_TRIGGER_HAPPY21))
 #define XLAT_STR_604 STRINGIFY(BTN_TRIGGER_HAPPY21)
 [BTN_TRIGGER_HAPPY22] = XLAT(BTN_TRIGGER_HAPPY22),
 #define XLAT_VAL_605 ((unsigned) (BTN_TRIGGER_HAPPY22))
 #define XLAT_STR_605 STRINGIFY(BTN_TRIGGER_HAPPY22)
 [BTN_TRIGGER_HAPPY23] = XLAT(BTN_TRIGGER_HAPPY23),
 #define XLAT_VAL_606 ((unsigned) (BTN_TRIGGER_HAPPY23))
 #define XLAT_STR_606 STRINGIFY(BTN_TRIGGER_HAPPY23)
 [BTN_TRIGGER_HAPPY24] = XLAT(BTN_TRIGGER_HAPPY24),
 #define XLAT_VAL_607 ((unsigned) (BTN_TRIGGER_HAPPY24))
 #define XLAT_STR_607 STRINGIFY(BTN_TRIGGER_HAPPY24)
 [BTN_TRIGGER_HAPPY25] = XLAT(BTN_TRIGGER_HAPPY25),
 #define XLAT_VAL_608 ((unsigned) (BTN_TRIGGER_HAPPY25))
 #define XLAT_STR_608 STRINGIFY(BTN_TRIGGER_HAPPY25)
 [BTN_TRIGGER_HAPPY26] = XLAT(BTN_TRIGGER_HAPPY26),
 #define XLAT_VAL_609 ((unsigned) (BTN_TRIGGER_HAPPY26))
 #define XLAT_STR_609 STRINGIFY(BTN_TRIGGER_HAPPY26)
 [BTN_TRIGGER_HAPPY27] = XLAT(BTN_TRIGGER_HAPPY27),
 #define XLAT_VAL_610 ((unsigned) (BTN_TRIGGER_HAPPY27))
 #define XLAT_STR_610 STRINGIFY(BTN_TRIGGER_HAPPY27)
 [BTN_TRIGGER_HAPPY28] = XLAT(BTN_TRIGGER_HAPPY28),
 #define XLAT_VAL_611 ((unsigned) (BTN_TRIGGER_HAPPY28))
 #define XLAT_STR_611 STRINGIFY(BTN_TRIGGER_HAPPY28)
 [BTN_TRIGGER_HAPPY29] = XLAT(BTN_TRIGGER_HAPPY29),
 #define XLAT_VAL_612 ((unsigned) (BTN_TRIGGER_HAPPY29))
 #define XLAT_STR_612 STRINGIFY(BTN_TRIGGER_HAPPY29)
 [BTN_TRIGGER_HAPPY30] = XLAT(BTN_TRIGGER_HAPPY30),
 #define XLAT_VAL_613 ((unsigned) (BTN_TRIGGER_HAPPY30))
 #define XLAT_STR_613 STRINGIFY(BTN_TRIGGER_HAPPY30)
 [BTN_TRIGGER_HAPPY31] = XLAT(BTN_TRIGGER_HAPPY31),
 #define XLAT_VAL_614 ((unsigned) (BTN_TRIGGER_HAPPY31))
 #define XLAT_STR_614 STRINGIFY(BTN_TRIGGER_HAPPY31)
 [BTN_TRIGGER_HAPPY32] = XLAT(BTN_TRIGGER_HAPPY32),
 #define XLAT_VAL_615 ((unsigned) (BTN_TRIGGER_HAPPY32))
 #define XLAT_STR_615 STRINGIFY(BTN_TRIGGER_HAPPY32)
 [BTN_TRIGGER_HAPPY33] = XLAT(BTN_TRIGGER_HAPPY33),
 #define XLAT_VAL_616 ((unsigned) (BTN_TRIGGER_HAPPY33))
 #define XLAT_STR_616 STRINGIFY(BTN_TRIGGER_HAPPY33)
 [BTN_TRIGGER_HAPPY34] = XLAT(BTN_TRIGGER_HAPPY34),
 #define XLAT_VAL_617 ((unsigned) (BTN_TRIGGER_HAPPY34))
 #define XLAT_STR_617 STRINGIFY(BTN_TRIGGER_HAPPY34)
 [BTN_TRIGGER_HAPPY35] = XLAT(BTN_TRIGGER_HAPPY35),
 #define XLAT_VAL_618 ((unsigned) (BTN_TRIGGER_HAPPY35))
 #define XLAT_STR_618 STRINGIFY(BTN_TRIGGER_HAPPY35)
 [BTN_TRIGGER_HAPPY36] = XLAT(BTN_TRIGGER_HAPPY36),
 #define XLAT_VAL_619 ((unsigned) (BTN_TRIGGER_HAPPY36))
 #define XLAT_STR_619 STRINGIFY(BTN_TRIGGER_HAPPY36)
 [BTN_TRIGGER_HAPPY37] = XLAT(BTN_TRIGGER_HAPPY37),
 #define XLAT_VAL_620 ((unsigned) (BTN_TRIGGER_HAPPY37))
 #define XLAT_STR_620 STRINGIFY(BTN_TRIGGER_HAPPY37)
 [BTN_TRIGGER_HAPPY38] = XLAT(BTN_TRIGGER_HAPPY38),
 #define XLAT_VAL_621 ((unsigned) (BTN_TRIGGER_HAPPY38))
 #define XLAT_STR_621 STRINGIFY(BTN_TRIGGER_HAPPY38)
 [BTN_TRIGGER_HAPPY39] = XLAT(BTN_TRIGGER_HAPPY39),
 #define XLAT_VAL_622 ((unsigned) (BTN_TRIGGER_HAPPY39))
 #define XLAT_STR_622 STRINGIFY(BTN_TRIGGER_HAPPY39)
 [BTN_TRIGGER_HAPPY40] = XLAT(BTN_TRIGGER_HAPPY40),
 #define XLAT_VAL_623 ((unsigned) (BTN_TRIGGER_HAPPY40))
 #define XLAT_STR_623 STRINGIFY(BTN_TRIGGER_HAPPY40)
};
static
const struct xlat evdev_keycode[1] = { {
 .data = evdev_keycode_xdata,
 .size = ARRAY_SIZE(evdev_keycode_xdata),
 .type = XT_INDEXED,
 .flags_mask = 0
#  ifdef XLAT_VAL_0
  | XLAT_VAL_0
#  endif
#  ifdef XLAT_VAL_1
  | XLAT_VAL_1
#  endif
#  ifdef XLAT_VAL_2
  | XLAT_VAL_2
#  endif
#  ifdef XLAT_VAL_3
  | XLAT_VAL_3
#  endif
#  ifdef XLAT_VAL_4
  | XLAT_VAL_4
#  endif
#  ifdef XLAT_VAL_5
  | XLAT_VAL_5
#  endif
#  ifdef XLAT_VAL_6
  | XLAT_VAL_6
#  endif
#  ifdef XLAT_VAL_7
  | XLAT_VAL_7
#  endif
#  ifdef XLAT_VAL_8
  | XLAT_VAL_8
#  endif
#  ifdef XLAT_VAL_9
  | XLAT_VAL_9
#  endif
#  ifdef XLAT_VAL_10
  | XLAT_VAL_10
#  endif
#  ifdef XLAT_VAL_11
  | XLAT_VAL_11
#  endif
#  ifdef XLAT_VAL_12
  | XLAT_VAL_12
#  endif
#  ifdef XLAT_VAL_13
  | XLAT_VAL_13
#  endif
#  ifdef XLAT_VAL_14
  | XLAT_VAL_14
#  endif
#  ifdef XLAT_VAL_15
  | XLAT_VAL_15
#  endif
#  ifdef XLAT_VAL_16
  | XLAT_VAL_16
#  endif
#  ifdef XLAT_VAL_17
  | XLAT_VAL_17
#  endif
#  ifdef XLAT_VAL_18
  | XLAT_VAL_18
#  endif
#  ifdef XLAT_VAL_19
  | XLAT_VAL_19
#  endif
#  ifdef XLAT_VAL_20
  | XLAT_VAL_20
#  endif
#  ifdef XLAT_VAL_21
  | XLAT_VAL_21
#  endif
#  ifdef XLAT_VAL_22
  | XLAT_VAL_22
#  endif
#  ifdef XLAT_VAL_23
  | XLAT_VAL_23
#  endif
#  ifdef XLAT_VAL_24
  | XLAT_VAL_24
#  endif
#  ifdef XLAT_VAL_25
  | XLAT_VAL_25
#  endif
#  ifdef XLAT_VAL_26
  | XLAT_VAL_26
#  endif
#  ifdef XLAT_VAL_27
  | XLAT_VAL_27
#  endif
#  ifdef XLAT_VAL_28
  | XLAT_VAL_28
#  endif
#  ifdef XLAT_VAL_29
  | XLAT_VAL_29
#  endif
#  ifdef XLAT_VAL_30
  | XLAT_VAL_30
#  endif
#  ifdef XLAT_VAL_31
  | XLAT_VAL_31
#  endif
#  ifdef XLAT_VAL_32
  | XLAT_VAL_32
#  endif
#  ifdef XLAT_VAL_33
  | XLAT_VAL_33
#  endif
#  ifdef XLAT_VAL_34
  | XLAT_VAL_34
#  endif
#  ifdef XLAT_VAL_35
  | XLAT_VAL_35
#  endif
#  ifdef XLAT_VAL_36
  | XLAT_VAL_36
#  endif
#  ifdef XLAT_VAL_37
  | XLAT_VAL_37
#  endif
#  ifdef XLAT_VAL_38
  | XLAT_VAL_38
#  endif
#  ifdef XLAT_VAL_39
  | XLAT_VAL_39
#  endif
#  ifdef XLAT_VAL_40
  | XLAT_VAL_40
#  endif
#  ifdef XLAT_VAL_41
  | XLAT_VAL_41
#  endif
#  ifdef XLAT_VAL_42
  | XLAT_VAL_42
#  endif
#  ifdef XLAT_VAL_43
  | XLAT_VAL_43
#  endif
#  ifdef XLAT_VAL_44
  | XLAT_VAL_44
#  endif
#  ifdef XLAT_VAL_45
  | XLAT_VAL_45
#  endif
#  ifdef XLAT_VAL_46
  | XLAT_VAL_46
#  endif
#  ifdef XLAT_VAL_47
  | XLAT_VAL_47
#  endif
#  ifdef XLAT_VAL_48
  | XLAT_VAL_48
#  endif
#  ifdef XLAT_VAL_49
  | XLAT_VAL_49
#  endif
#  ifdef XLAT_VAL_50
  | XLAT_VAL_50
#  endif
#  ifdef XLAT_VAL_51
  | XLAT_VAL_51
#  endif
#  ifdef XLAT_VAL_52
  | XLAT_VAL_52
#  endif
#  ifdef XLAT_VAL_53
  | XLAT_VAL_53
#  endif
#  ifdef XLAT_VAL_54
  | XLAT_VAL_54
#  endif
#  ifdef XLAT_VAL_55
  | XLAT_VAL_55
#  endif
#  ifdef XLAT_VAL_56
  | XLAT_VAL_56
#  endif
#  ifdef XLAT_VAL_57
  | XLAT_VAL_57
#  endif
#  ifdef XLAT_VAL_58
  | XLAT_VAL_58
#  endif
#  ifdef XLAT_VAL_59
  | XLAT_VAL_59
#  endif
#  ifdef XLAT_VAL_60
  | XLAT_VAL_60
#  endif
#  ifdef XLAT_VAL_61
  | XLAT_VAL_61
#  endif
#  ifdef XLAT_VAL_62
  | XLAT_VAL_62
#  endif
#  ifdef XLAT_VAL_63
  | XLAT_VAL_63
#  endif
#  ifdef XLAT_VAL_64
  | XLAT_VAL_64
#  endif
#  ifdef XLAT_VAL_65
  | XLAT_VAL_65
#  endif
#  ifdef XLAT_VAL_66
  | XLAT_VAL_66
#  endif
#  ifdef XLAT_VAL_67
  | XLAT_VAL_67
#  endif
#  ifdef XLAT_VAL_68
  | XLAT_VAL_68
#  endif
#  ifdef XLAT_VAL_69
  | XLAT_VAL_69
#  endif
#  ifdef XLAT_VAL_70
  | XLAT_VAL_70
#  endif
#  ifdef XLAT_VAL_71
  | XLAT_VAL_71
#  endif
#  ifdef XLAT_VAL_72
  | XLAT_VAL_72
#  endif
#  ifdef XLAT_VAL_73
  | XLAT_VAL_73
#  endif
#  ifdef XLAT_VAL_74
  | XLAT_VAL_74
#  endif
#  ifdef XLAT_VAL_75
  | XLAT_VAL_75
#  endif
#  ifdef XLAT_VAL_76
  | XLAT_VAL_76
#  endif
#  ifdef XLAT_VAL_77
  | XLAT_VAL_77
#  endif
#  ifdef XLAT_VAL_78
  | XLAT_VAL_78
#  endif
#  ifdef XLAT_VAL_79
  | XLAT_VAL_79
#  endif
#  ifdef XLAT_VAL_80
  | XLAT_VAL_80
#  endif
#  ifdef XLAT_VAL_81
  | XLAT_VAL_81
#  endif
#  ifdef XLAT_VAL_82
  | XLAT_VAL_82
#  endif
#  ifdef XLAT_VAL_83
  | XLAT_VAL_83
#  endif
#  ifdef XLAT_VAL_84
  | XLAT_VAL_84
#  endif
#  ifdef XLAT_VAL_85
  | XLAT_VAL_85
#  endif
#  ifdef XLAT_VAL_86
  | XLAT_VAL_86
#  endif
#  ifdef XLAT_VAL_87
  | XLAT_VAL_87
#  endif
#  ifdef XLAT_VAL_88
  | XLAT_VAL_88
#  endif
#  ifdef XLAT_VAL_89
  | XLAT_VAL_89
#  endif
#  ifdef XLAT_VAL_90
  | XLAT_VAL_90
#  endif
#  ifdef XLAT_VAL_91
  | XLAT_VAL_91
#  endif
#  ifdef XLAT_VAL_92
  | XLAT_VAL_92
#  endif
#  ifdef XLAT_VAL_93
  | XLAT_VAL_93
#  endif
#  ifdef XLAT_VAL_94
  | XLAT_VAL_94
#  endif
#  ifdef XLAT_VAL_95
  | XLAT_VAL_95
#  endif
#  ifdef XLAT_VAL_96
  | XLAT_VAL_96
#  endif
#  ifdef XLAT_VAL_97
  | XLAT_VAL_97
#  endif
#  ifdef XLAT_VAL_98
  | XLAT_VAL_98
#  endif
#  ifdef XLAT_VAL_99
  | XLAT_VAL_99
#  endif
#  ifdef XLAT_VAL_100
  | XLAT_VAL_100
#  endif
#  ifdef XLAT_VAL_101
  | XLAT_VAL_101
#  endif
#  ifdef XLAT_VAL_102
  | XLAT_VAL_102
#  endif
#  ifdef XLAT_VAL_103
  | XLAT_VAL_103
#  endif
#  ifdef XLAT_VAL_104
  | XLAT_VAL_104
#  endif
#  ifdef XLAT_VAL_105
  | XLAT_VAL_105
#  endif
#  ifdef XLAT_VAL_106
  | XLAT_VAL_106
#  endif
#  ifdef XLAT_VAL_107
  | XLAT_VAL_107
#  endif
#  ifdef XLAT_VAL_108
  | XLAT_VAL_108
#  endif
#  ifdef XLAT_VAL_109
  | XLAT_VAL_109
#  endif
#  ifdef XLAT_VAL_110
  | XLAT_VAL_110
#  endif
#  ifdef XLAT_VAL_111
  | XLAT_VAL_111
#  endif
#  ifdef XLAT_VAL_112
  | XLAT_VAL_112
#  endif
#  ifdef XLAT_VAL_113
  | XLAT_VAL_113
#  endif
#  ifdef XLAT_VAL_114
  | XLAT_VAL_114
#  endif
#  ifdef XLAT_VAL_115
  | XLAT_VAL_115
#  endif
#  ifdef XLAT_VAL_116
  | XLAT_VAL_116
#  endif
#  ifdef XLAT_VAL_117
  | XLAT_VAL_117
#  endif
#  ifdef XLAT_VAL_118
  | XLAT_VAL_118
#  endif
#  ifdef XLAT_VAL_119
  | XLAT_VAL_119
#  endif
#  ifdef XLAT_VAL_120
  | XLAT_VAL_120
#  endif
#  ifdef XLAT_VAL_121
  | XLAT_VAL_121
#  endif
#  ifdef XLAT_VAL_122
  | XLAT_VAL_122
#  endif
#  ifdef XLAT_VAL_123
  | XLAT_VAL_123
#  endif
#  ifdef XLAT_VAL_124
  | XLAT_VAL_124
#  endif
#  ifdef XLAT_VAL_125
  | XLAT_VAL_125
#  endif
#  ifdef XLAT_VAL_126
  | XLAT_VAL_126
#  endif
#  ifdef XLAT_VAL_127
  | XLAT_VAL_127
#  endif
#  ifdef XLAT_VAL_128
  | XLAT_VAL_128
#  endif
#  ifdef XLAT_VAL_129
  | XLAT_VAL_129
#  endif
#  ifdef XLAT_VAL_130
  | XLAT_VAL_130
#  endif
#  ifdef XLAT_VAL_131
  | XLAT_VAL_131
#  endif
#  ifdef XLAT_VAL_132
  | XLAT_VAL_132
#  endif
#  ifdef XLAT_VAL_133
  | XLAT_VAL_133
#  endif
#  ifdef XLAT_VAL_134
  | XLAT_VAL_134
#  endif
#  ifdef XLAT_VAL_135
  | XLAT_VAL_135
#  endif
#  ifdef XLAT_VAL_136
  | XLAT_VAL_136
#  endif
#  ifdef XLAT_VAL_137
  | XLAT_VAL_137
#  endif
#  ifdef XLAT_VAL_138
  | XLAT_VAL_138
#  endif
#  ifdef XLAT_VAL_139
  | XLAT_VAL_139
#  endif
#  ifdef XLAT_VAL_140
  | XLAT_VAL_140
#  endif
#  ifdef XLAT_VAL_141
  | XLAT_VAL_141
#  endif
#  ifdef XLAT_VAL_142
  | XLAT_VAL_142
#  endif
#  ifdef XLAT_VAL_143
  | XLAT_VAL_143
#  endif
#  ifdef XLAT_VAL_144
  | XLAT_VAL_144
#  endif
#  ifdef XLAT_VAL_145
  | XLAT_VAL_145
#  endif
#  ifdef XLAT_VAL_146
  | XLAT_VAL_146
#  endif
#  ifdef XLAT_VAL_147
  | XLAT_VAL_147
#  endif
#  ifdef XLAT_VAL_148
  | XLAT_VAL_148
#  endif
#  ifdef XLAT_VAL_149
  | XLAT_VAL_149
#  endif
#  ifdef XLAT_VAL_150
  | XLAT_VAL_150
#  endif
#  ifdef XLAT_VAL_151
  | XLAT_VAL_151
#  endif
#  ifdef XLAT_VAL_152
  | XLAT_VAL_152
#  endif
#  ifdef XLAT_VAL_153
  | XLAT_VAL_153
#  endif
#  ifdef XLAT_VAL_154
  | XLAT_VAL_154
#  endif
#  ifdef XLAT_VAL_155
  | XLAT_VAL_155
#  endif
#  ifdef XLAT_VAL_156
  | XLAT_VAL_156
#  endif
#  ifdef XLAT_VAL_157
  | XLAT_VAL_157
#  endif
#  ifdef XLAT_VAL_158
  | XLAT_VAL_158
#  endif
#  ifdef XLAT_VAL_159
  | XLAT_VAL_159
#  endif
#  ifdef XLAT_VAL_160
  | XLAT_VAL_160
#  endif
#  ifdef XLAT_VAL_161
  | XLAT_VAL_161
#  endif
#  ifdef XLAT_VAL_162
  | XLAT_VAL_162
#  endif
#  ifdef XLAT_VAL_163
  | XLAT_VAL_163
#  endif
#  ifdef XLAT_VAL_164
  | XLAT_VAL_164
#  endif
#  ifdef XLAT_VAL_165
  | XLAT_VAL_165
#  endif
#  ifdef XLAT_VAL_166
  | XLAT_VAL_166
#  endif
#  ifdef XLAT_VAL_167
  | XLAT_VAL_167
#  endif
#  ifdef XLAT_VAL_168
  | XLAT_VAL_168
#  endif
#  ifdef XLAT_VAL_169
  | XLAT_VAL_169
#  endif
#  ifdef XLAT_VAL_170
  | XLAT_VAL_170
#  endif
#  ifdef XLAT_VAL_171
  | XLAT_VAL_171
#  endif
#  ifdef XLAT_VAL_172
  | XLAT_VAL_172
#  endif
#  ifdef XLAT_VAL_173
  | XLAT_VAL_173
#  endif
#  ifdef XLAT_VAL_174
  | XLAT_VAL_174
#  endif
#  ifdef XLAT_VAL_175
  | XLAT_VAL_175
#  endif
#  ifdef XLAT_VAL_176
  | XLAT_VAL_176
#  endif
#  ifdef XLAT_VAL_177
  | XLAT_VAL_177
#  endif
#  ifdef XLAT_VAL_178
  | XLAT_VAL_178
#  endif
#  ifdef XLAT_VAL_179
  | XLAT_VAL_179
#  endif
#  ifdef XLAT_VAL_180
  | XLAT_VAL_180
#  endif
#  ifdef XLAT_VAL_181
  | XLAT_VAL_181
#  endif
#  ifdef XLAT_VAL_182
  | XLAT_VAL_182
#  endif
#  ifdef XLAT_VAL_183
  | XLAT_VAL_183
#  endif
#  ifdef XLAT_VAL_184
  | XLAT_VAL_184
#  endif
#  ifdef XLAT_VAL_185
  | XLAT_VAL_185
#  endif
#  ifdef XLAT_VAL_186
  | XLAT_VAL_186
#  endif
#  ifdef XLAT_VAL_187
  | XLAT_VAL_187
#  endif
#  ifdef XLAT_VAL_188
  | XLAT_VAL_188
#  endif
#  ifdef XLAT_VAL_189
  | XLAT_VAL_189
#  endif
#  ifdef XLAT_VAL_190
  | XLAT_VAL_190
#  endif
#  ifdef XLAT_VAL_191
  | XLAT_VAL_191
#  endif
#  ifdef XLAT_VAL_192
  | XLAT_VAL_192
#  endif
#  ifdef XLAT_VAL_193
  | XLAT_VAL_193
#  endif
#  ifdef XLAT_VAL_194
  | XLAT_VAL_194
#  endif
#  ifdef XLAT_VAL_195
  | XLAT_VAL_195
#  endif
#  ifdef XLAT_VAL_196
  | XLAT_VAL_196
#  endif
#  ifdef XLAT_VAL_197
  | XLAT_VAL_197
#  endif
#  ifdef XLAT_VAL_198
  | XLAT_VAL_198
#  endif
#  ifdef XLAT_VAL_199
  | XLAT_VAL_199
#  endif
#  ifdef XLAT_VAL_200
  | XLAT_VAL_200
#  endif
#  ifdef XLAT_VAL_201
  | XLAT_VAL_201
#  endif
#  ifdef XLAT_VAL_202
  | XLAT_VAL_202
#  endif
#  ifdef XLAT_VAL_203
  | XLAT_VAL_203
#  endif
#  ifdef XLAT_VAL_204
  | XLAT_VAL_204
#  endif
#  ifdef XLAT_VAL_205
  | XLAT_VAL_205
#  endif
#  ifdef XLAT_VAL_206
  | XLAT_VAL_206
#  endif
#  ifdef XLAT_VAL_207
  | XLAT_VAL_207
#  endif
#  ifdef XLAT_VAL_208
  | XLAT_VAL_208
#  endif
#  ifdef XLAT_VAL_209
  | XLAT_VAL_209
#  endif
#  ifdef XLAT_VAL_210
  | XLAT_VAL_210
#  endif
#  ifdef XLAT_VAL_211
  | XLAT_VAL_211
#  endif
#  ifdef XLAT_VAL_212
  | XLAT_VAL_212
#  endif
#  ifdef XLAT_VAL_213
  | XLAT_VAL_213
#  endif
#  ifdef XLAT_VAL_214
  | XLAT_VAL_214
#  endif
#  ifdef XLAT_VAL_215
  | XLAT_VAL_215
#  endif
#  ifdef XLAT_VAL_216
  | XLAT_VAL_216
#  endif
#  ifdef XLAT_VAL_217
  | XLAT_VAL_217
#  endif
#  ifdef XLAT_VAL_218
  | XLAT_VAL_218
#  endif
#  ifdef XLAT_VAL_219
  | XLAT_VAL_219
#  endif
#  ifdef XLAT_VAL_220
  | XLAT_VAL_220
#  endif
#  ifdef XLAT_VAL_221
  | XLAT_VAL_221
#  endif
#  ifdef XLAT_VAL_222
  | XLAT_VAL_222
#  endif
#  ifdef XLAT_VAL_223
  | XLAT_VAL_223
#  endif
#  ifdef XLAT_VAL_224
  | XLAT_VAL_224
#  endif
#  ifdef XLAT_VAL_225
  | XLAT_VAL_225
#  endif
#  ifdef XLAT_VAL_226
  | XLAT_VAL_226
#  endif
#  ifdef XLAT_VAL_227
  | XLAT_VAL_227
#  endif
#  ifdef XLAT_VAL_228
  | XLAT_VAL_228
#  endif
#  ifdef XLAT_VAL_229
  | XLAT_VAL_229
#  endif
#  ifdef XLAT_VAL_230
  | XLAT_VAL_230
#  endif
#  ifdef XLAT_VAL_231
  | XLAT_VAL_231
#  endif
#  ifdef XLAT_VAL_232
  | XLAT_VAL_232
#  endif
#  ifdef XLAT_VAL_233
  | XLAT_VAL_233
#  endif
#  ifdef XLAT_VAL_234
  | XLAT_VAL_234
#  endif
#  ifdef XLAT_VAL_235
  | XLAT_VAL_235
#  endif
#  ifdef XLAT_VAL_236
  | XLAT_VAL_236
#  endif
#  ifdef XLAT_VAL_237
  | XLAT_VAL_237
#  endif
#  ifdef XLAT_VAL_238
  | XLAT_VAL_238
#  endif
#  ifdef XLAT_VAL_239
  | XLAT_VAL_239
#  endif
#  ifdef XLAT_VAL_240
  | XLAT_VAL_240
#  endif
#  ifdef XLAT_VAL_241
  | XLAT_VAL_241
#  endif
#  ifdef XLAT_VAL_242
  | XLAT_VAL_242
#  endif
#  ifdef XLAT_VAL_243
  | XLAT_VAL_243
#  endif
#  ifdef XLAT_VAL_244
  | XLAT_VAL_244
#  endif
#  ifdef XLAT_VAL_245
  | XLAT_VAL_245
#  endif
#  ifdef XLAT_VAL_246
  | XLAT_VAL_246
#  endif
#  ifdef XLAT_VAL_247
  | XLAT_VAL_247
#  endif
#  ifdef XLAT_VAL_248
  | XLAT_VAL_248
#  endif
#  ifdef XLAT_VAL_249
  | XLAT_VAL_249
#  endif
#  ifdef XLAT_VAL_250
  | XLAT_VAL_250
#  endif
#  ifdef XLAT_VAL_251
  | XLAT_VAL_251
#  endif
#  ifdef XLAT_VAL_252
  | XLAT_VAL_252
#  endif
#  ifdef XLAT_VAL_253
  | XLAT_VAL_253
#  endif
#  ifdef XLAT_VAL_254
  | XLAT_VAL_254
#  endif
#  ifdef XLAT_VAL_255
  | XLAT_VAL_255
#  endif
#  ifdef XLAT_VAL_256
  | XLAT_VAL_256
#  endif
#  ifdef XLAT_VAL_257
  | XLAT_VAL_257
#  endif
#  ifdef XLAT_VAL_258
  | XLAT_VAL_258
#  endif
#  ifdef XLAT_VAL_259
  | XLAT_VAL_259
#  endif
#  ifdef XLAT_VAL_260
  | XLAT_VAL_260
#  endif
#  ifdef XLAT_VAL_261
  | XLAT_VAL_261
#  endif
#  ifdef XLAT_VAL_262
  | XLAT_VAL_262
#  endif
#  ifdef XLAT_VAL_263
  | XLAT_VAL_263
#  endif
#  ifdef XLAT_VAL_264
  | XLAT_VAL_264
#  endif
#  ifdef XLAT_VAL_265
  | XLAT_VAL_265
#  endif
#  ifdef XLAT_VAL_266
  | XLAT_VAL_266
#  endif
#  ifdef XLAT_VAL_267
  | XLAT_VAL_267
#  endif
#  ifdef XLAT_VAL_268
  | XLAT_VAL_268
#  endif
#  ifdef XLAT_VAL_269
  | XLAT_VAL_269
#  endif
#  ifdef XLAT_VAL_270
  | XLAT_VAL_270
#  endif
#  ifdef XLAT_VAL_271
  | XLAT_VAL_271
#  endif
#  ifdef XLAT_VAL_272
  | XLAT_VAL_272
#  endif
#  ifdef XLAT_VAL_273
  | XLAT_VAL_273
#  endif
#  ifdef XLAT_VAL_274
  | XLAT_VAL_274
#  endif
#  ifdef XLAT_VAL_275
  | XLAT_VAL_275
#  endif
#  ifdef XLAT_VAL_276
  | XLAT_VAL_276
#  endif
#  ifdef XLAT_VAL_277
  | XLAT_VAL_277
#  endif
#  ifdef XLAT_VAL_278
  | XLAT_VAL_278
#  endif
#  ifdef XLAT_VAL_279
  | XLAT_VAL_279
#  endif
#  ifdef XLAT_VAL_280
  | XLAT_VAL_280
#  endif
#  ifdef XLAT_VAL_281
  | XLAT_VAL_281
#  endif
#  ifdef XLAT_VAL_282
  | XLAT_VAL_282
#  endif
#  ifdef XLAT_VAL_283
  | XLAT_VAL_283
#  endif
#  ifdef XLAT_VAL_284
  | XLAT_VAL_284
#  endif
#  ifdef XLAT_VAL_285
  | XLAT_VAL_285
#  endif
#  ifdef XLAT_VAL_286
  | XLAT_VAL_286
#  endif
#  ifdef XLAT_VAL_287
  | XLAT_VAL_287
#  endif
#  ifdef XLAT_VAL_288
  | XLAT_VAL_288
#  endif
#  ifdef XLAT_VAL_289
  | XLAT_VAL_289
#  endif
#  ifdef XLAT_VAL_290
  | XLAT_VAL_290
#  endif
#  ifdef XLAT_VAL_291
  | XLAT_VAL_291
#  endif
#  ifdef XLAT_VAL_292
  | XLAT_VAL_292
#  endif
#  ifdef XLAT_VAL_293
  | XLAT_VAL_293
#  endif
#  ifdef XLAT_VAL_294
  | XLAT_VAL_294
#  endif
#  ifdef XLAT_VAL_295
  | XLAT_VAL_295
#  endif
#  ifdef XLAT_VAL_296
  | XLAT_VAL_296
#  endif
#  ifdef XLAT_VAL_297
  | XLAT_VAL_297
#  endif
#  ifdef XLAT_VAL_298
  | XLAT_VAL_298
#  endif
#  ifdef XLAT_VAL_299
  | XLAT_VAL_299
#  endif
#  ifdef XLAT_VAL_300
  | XLAT_VAL_300
#  endif
#  ifdef XLAT_VAL_301
  | XLAT_VAL_301
#  endif
#  ifdef XLAT_VAL_302
  | XLAT_VAL_302
#  endif
#  ifdef XLAT_VAL_303
  | XLAT_VAL_303
#  endif
#  ifdef XLAT_VAL_304
  | XLAT_VAL_304
#  endif
#  ifdef XLAT_VAL_305
  | XLAT_VAL_305
#  endif
#  ifdef XLAT_VAL_306
  | XLAT_VAL_306
#  endif
#  ifdef XLAT_VAL_307
  | XLAT_VAL_307
#  endif
#  ifdef XLAT_VAL_308
  | XLAT_VAL_308
#  endif
#  ifdef XLAT_VAL_309
  | XLAT_VAL_309
#  endif
#  ifdef XLAT_VAL_310
  | XLAT_VAL_310
#  endif
#  ifdef XLAT_VAL_311
  | XLAT_VAL_311
#  endif
#  ifdef XLAT_VAL_312
  | XLAT_VAL_312
#  endif
#  ifdef XLAT_VAL_313
  | XLAT_VAL_313
#  endif
#  ifdef XLAT_VAL_314
  | XLAT_VAL_314
#  endif
#  ifdef XLAT_VAL_315
  | XLAT_VAL_315
#  endif
#  ifdef XLAT_VAL_316
  | XLAT_VAL_316
#  endif
#  ifdef XLAT_VAL_317
  | XLAT_VAL_317
#  endif
#  ifdef XLAT_VAL_318
  | XLAT_VAL_318
#  endif
#  ifdef XLAT_VAL_319
  | XLAT_VAL_319
#  endif
#  ifdef XLAT_VAL_320
  | XLAT_VAL_320
#  endif
#  ifdef XLAT_VAL_321
  | XLAT_VAL_321
#  endif
#  ifdef XLAT_VAL_322
  | XLAT_VAL_322
#  endif
#  ifdef XLAT_VAL_323
  | XLAT_VAL_323
#  endif
#  ifdef XLAT_VAL_324
  | XLAT_VAL_324
#  endif
#  ifdef XLAT_VAL_325
  | XLAT_VAL_325
#  endif
#  ifdef XLAT_VAL_326
  | XLAT_VAL_326
#  endif
#  ifdef XLAT_VAL_327
  | XLAT_VAL_327
#  endif
#  ifdef XLAT_VAL_328
  | XLAT_VAL_328
#  endif
#  ifdef XLAT_VAL_329
  | XLAT_VAL_329
#  endif
#  ifdef XLAT_VAL_330
  | XLAT_VAL_330
#  endif
#  ifdef XLAT_VAL_331
  | XLAT_VAL_331
#  endif
#  ifdef XLAT_VAL_332
  | XLAT_VAL_332
#  endif
#  ifdef XLAT_VAL_333
  | XLAT_VAL_333
#  endif
#  ifdef XLAT_VAL_334
  | XLAT_VAL_334
#  endif
#  ifdef XLAT_VAL_335
  | XLAT_VAL_335
#  endif
#  ifdef XLAT_VAL_336
  | XLAT_VAL_336
#  endif
#  ifdef XLAT_VAL_337
  | XLAT_VAL_337
#  endif
#  ifdef XLAT_VAL_338
  | XLAT_VAL_338
#  endif
#  ifdef XLAT_VAL_339
  | XLAT_VAL_339
#  endif
#  ifdef XLAT_VAL_340
  | XLAT_VAL_340
#  endif
#  ifdef XLAT_VAL_341
  | XLAT_VAL_341
#  endif
#  ifdef XLAT_VAL_342
  | XLAT_VAL_342
#  endif
#  ifdef XLAT_VAL_343
  | XLAT_VAL_343
#  endif
#  ifdef XLAT_VAL_344
  | XLAT_VAL_344
#  endif
#  ifdef XLAT_VAL_345
  | XLAT_VAL_345
#  endif
#  ifdef XLAT_VAL_346
  | XLAT_VAL_346
#  endif
#  ifdef XLAT_VAL_347
  | XLAT_VAL_347
#  endif
#  ifdef XLAT_VAL_348
  | XLAT_VAL_348
#  endif
#  ifdef XLAT_VAL_349
  | XLAT_VAL_349
#  endif
#  ifdef XLAT_VAL_350
  | XLAT_VAL_350
#  endif
#  ifdef XLAT_VAL_351
  | XLAT_VAL_351
#  endif
#  ifdef XLAT_VAL_352
  | XLAT_VAL_352
#  endif
#  ifdef XLAT_VAL_353
  | XLAT_VAL_353
#  endif
#  ifdef XLAT_VAL_354
  | XLAT_VAL_354
#  endif
#  ifdef XLAT_VAL_355
  | XLAT_VAL_355
#  endif
#  ifdef XLAT_VAL_356
  | XLAT_VAL_356
#  endif
#  ifdef XLAT_VAL_357
  | XLAT_VAL_357
#  endif
#  ifdef XLAT_VAL_358
  | XLAT_VAL_358
#  endif
#  ifdef XLAT_VAL_359
  | XLAT_VAL_359
#  endif
#  ifdef XLAT_VAL_360
  | XLAT_VAL_360
#  endif
#  ifdef XLAT_VAL_361
  | XLAT_VAL_361
#  endif
#  ifdef XLAT_VAL_362
  | XLAT_VAL_362
#  endif
#  ifdef XLAT_VAL_363
  | XLAT_VAL_363
#  endif
#  ifdef XLAT_VAL_364
  | XLAT_VAL_364
#  endif
#  ifdef XLAT_VAL_365
  | XLAT_VAL_365
#  endif
#  ifdef XLAT_VAL_366
  | XLAT_VAL_366
#  endif
#  ifdef XLAT_VAL_367
  | XLAT_VAL_367
#  endif
#  ifdef XLAT_VAL_368
  | XLAT_VAL_368
#  endif
#  ifdef XLAT_VAL_369
  | XLAT_VAL_369
#  endif
#  ifdef XLAT_VAL_370
  | XLAT_VAL_370
#  endif
#  ifdef XLAT_VAL_371
  | XLAT_VAL_371
#  endif
#  ifdef XLAT_VAL_372
  | XLAT_VAL_372
#  endif
#  ifdef XLAT_VAL_373
  | XLAT_VAL_373
#  endif
#  ifdef XLAT_VAL_374
  | XLAT_VAL_374
#  endif
#  ifdef XLAT_VAL_375
  | XLAT_VAL_375
#  endif
#  ifdef XLAT_VAL_376
  | XLAT_VAL_376
#  endif
#  ifdef XLAT_VAL_377
  | XLAT_VAL_377
#  endif
#  ifdef XLAT_VAL_378
  | XLAT_VAL_378
#  endif
#  ifdef XLAT_VAL_379
  | XLAT_VAL_379
#  endif
#  ifdef XLAT_VAL_380
  | XLAT_VAL_380
#  endif
#  ifdef XLAT_VAL_381
  | XLAT_VAL_381
#  endif
#  ifdef XLAT_VAL_382
  | XLAT_VAL_382
#  endif
#  ifdef XLAT_VAL_383
  | XLAT_VAL_383
#  endif
#  ifdef XLAT_VAL_384
  | XLAT_VAL_384
#  endif
#  ifdef XLAT_VAL_385
  | XLAT_VAL_385
#  endif
#  ifdef XLAT_VAL_386
  | XLAT_VAL_386
#  endif
#  ifdef XLAT_VAL_387
  | XLAT_VAL_387
#  endif
#  ifdef XLAT_VAL_388
  | XLAT_VAL_388
#  endif
#  ifdef XLAT_VAL_389
  | XLAT_VAL_389
#  endif
#  ifdef XLAT_VAL_390
  | XLAT_VAL_390
#  endif
#  ifdef XLAT_VAL_391
  | XLAT_VAL_391
#  endif
#  ifdef XLAT_VAL_392
  | XLAT_VAL_392
#  endif
#  ifdef XLAT_VAL_393
  | XLAT_VAL_393
#  endif
#  ifdef XLAT_VAL_394
  | XLAT_VAL_394
#  endif
#  ifdef XLAT_VAL_395
  | XLAT_VAL_395
#  endif
#  ifdef XLAT_VAL_396
  | XLAT_VAL_396
#  endif
#  ifdef XLAT_VAL_397
  | XLAT_VAL_397
#  endif
#  ifdef XLAT_VAL_398
  | XLAT_VAL_398
#  endif
#  ifdef XLAT_VAL_399
  | XLAT_VAL_399
#  endif
#  ifdef XLAT_VAL_400
  | XLAT_VAL_400
#  endif
#  ifdef XLAT_VAL_401
  | XLAT_VAL_401
#  endif
#  ifdef XLAT_VAL_402
  | XLAT_VAL_402
#  endif
#  ifdef XLAT_VAL_403
  | XLAT_VAL_403
#  endif
#  ifdef XLAT_VAL_404
  | XLAT_VAL_404
#  endif
#  ifdef XLAT_VAL_405
  | XLAT_VAL_405
#  endif
#  ifdef XLAT_VAL_406
  | XLAT_VAL_406
#  endif
#  ifdef XLAT_VAL_407
  | XLAT_VAL_407
#  endif
#  ifdef XLAT_VAL_408
  | XLAT_VAL_408
#  endif
#  ifdef XLAT_VAL_409
  | XLAT_VAL_409
#  endif
#  ifdef XLAT_VAL_410
  | XLAT_VAL_410
#  endif
#  ifdef XLAT_VAL_411
  | XLAT_VAL_411
#  endif
#  ifdef XLAT_VAL_412
  | XLAT_VAL_412
#  endif
#  ifdef XLAT_VAL_413
  | XLAT_VAL_413
#  endif
#  ifdef XLAT_VAL_414
  | XLAT_VAL_414
#  endif
#  ifdef XLAT_VAL_415
  | XLAT_VAL_415
#  endif
#  ifdef XLAT_VAL_416
  | XLAT_VAL_416
#  endif
#  ifdef XLAT_VAL_417
  | XLAT_VAL_417
#  endif
#  ifdef XLAT_VAL_418
  | XLAT_VAL_418
#  endif
#  ifdef XLAT_VAL_419
  | XLAT_VAL_419
#  endif
#  ifdef XLAT_VAL_420
  | XLAT_VAL_420
#  endif
#  ifdef XLAT_VAL_421
  | XLAT_VAL_421
#  endif
#  ifdef XLAT_VAL_422
  | XLAT_VAL_422
#  endif
#  ifdef XLAT_VAL_423
  | XLAT_VAL_423
#  endif
#  ifdef XLAT_VAL_424
  | XLAT_VAL_424
#  endif
#  ifdef XLAT_VAL_425
  | XLAT_VAL_425
#  endif
#  ifdef XLAT_VAL_426
  | XLAT_VAL_426
#  endif
#  ifdef XLAT_VAL_427
  | XLAT_VAL_427
#  endif
#  ifdef XLAT_VAL_428
  | XLAT_VAL_428
#  endif
#  ifdef XLAT_VAL_429
  | XLAT_VAL_429
#  endif
#  ifdef XLAT_VAL_430
  | XLAT_VAL_430
#  endif
#  ifdef XLAT_VAL_431
  | XLAT_VAL_431
#  endif
#  ifdef XLAT_VAL_432
  | XLAT_VAL_432
#  endif
#  ifdef XLAT_VAL_433
  | XLAT_VAL_433
#  endif
#  ifdef XLAT_VAL_434
  | XLAT_VAL_434
#  endif
#  ifdef XLAT_VAL_435
  | XLAT_VAL_435
#  endif
#  ifdef XLAT_VAL_436
  | XLAT_VAL_436
#  endif
#  ifdef XLAT_VAL_437
  | XLAT_VAL_437
#  endif
#  ifdef XLAT_VAL_438
  | XLAT_VAL_438
#  endif
#  ifdef XLAT_VAL_439
  | XLAT_VAL_439
#  endif
#  ifdef XLAT_VAL_440
  | XLAT_VAL_440
#  endif
#  ifdef XLAT_VAL_441
  | XLAT_VAL_441
#  endif
#  ifdef XLAT_VAL_442
  | XLAT_VAL_442
#  endif
#  ifdef XLAT_VAL_443
  | XLAT_VAL_443
#  endif
#  ifdef XLAT_VAL_444
  | XLAT_VAL_444
#  endif
#  ifdef XLAT_VAL_445
  | XLAT_VAL_445
#  endif
#  ifdef XLAT_VAL_446
  | XLAT_VAL_446
#  endif
#  ifdef XLAT_VAL_447
  | XLAT_VAL_447
#  endif
#  ifdef XLAT_VAL_448
  | XLAT_VAL_448
#  endif
#  ifdef XLAT_VAL_449
  | XLAT_VAL_449
#  endif
#  ifdef XLAT_VAL_450
  | XLAT_VAL_450
#  endif
#  ifdef XLAT_VAL_451
  | XLAT_VAL_451
#  endif
#  ifdef XLAT_VAL_452
  | XLAT_VAL_452
#  endif
#  ifdef XLAT_VAL_453
  | XLAT_VAL_453
#  endif
#  ifdef XLAT_VAL_454
  | XLAT_VAL_454
#  endif
#  ifdef XLAT_VAL_455
  | XLAT_VAL_455
#  endif
#  ifdef XLAT_VAL_456
  | XLAT_VAL_456
#  endif
#  ifdef XLAT_VAL_457
  | XLAT_VAL_457
#  endif
#  ifdef XLAT_VAL_458
  | XLAT_VAL_458
#  endif
#  ifdef XLAT_VAL_459
  | XLAT_VAL_459
#  endif
#  ifdef XLAT_VAL_460
  | XLAT_VAL_460
#  endif
#  ifdef XLAT_VAL_461
  | XLAT_VAL_461
#  endif
#  ifdef XLAT_VAL_462
  | XLAT_VAL_462
#  endif
#  ifdef XLAT_VAL_463
  | XLAT_VAL_463
#  endif
#  ifdef XLAT_VAL_464
  | XLAT_VAL_464
#  endif
#  ifdef XLAT_VAL_465
  | XLAT_VAL_465
#  endif
#  ifdef XLAT_VAL_466
  | XLAT_VAL_466
#  endif
#  ifdef XLAT_VAL_467
  | XLAT_VAL_467
#  endif
#  ifdef XLAT_VAL_468
  | XLAT_VAL_468
#  endif
#  ifdef XLAT_VAL_469
  | XLAT_VAL_469
#  endif
#  ifdef XLAT_VAL_470
  | XLAT_VAL_470
#  endif
#  ifdef XLAT_VAL_471
  | XLAT_VAL_471
#  endif
#  ifdef XLAT_VAL_472
  | XLAT_VAL_472
#  endif
#  ifdef XLAT_VAL_473
  | XLAT_VAL_473
#  endif
#  ifdef XLAT_VAL_474
  | XLAT_VAL_474
#  endif
#  ifdef XLAT_VAL_475
  | XLAT_VAL_475
#  endif
#  ifdef XLAT_VAL_476
  | XLAT_VAL_476
#  endif
#  ifdef XLAT_VAL_477
  | XLAT_VAL_477
#  endif
#  ifdef XLAT_VAL_478
  | XLAT_VAL_478
#  endif
#  ifdef XLAT_VAL_479
  | XLAT_VAL_479
#  endif
#  ifdef XLAT_VAL_480
  | XLAT_VAL_480
#  endif
#  ifdef XLAT_VAL_481
  | XLAT_VAL_481
#  endif
#  ifdef XLAT_VAL_482
  | XLAT_VAL_482
#  endif
#  ifdef XLAT_VAL_483
  | XLAT_VAL_483
#  endif
#  ifdef XLAT_VAL_484
  | XLAT_VAL_484
#  endif
#  ifdef XLAT_VAL_485
  | XLAT_VAL_485
#  endif
#  ifdef XLAT_VAL_486
  | XLAT_VAL_486
#  endif
#  ifdef XLAT_VAL_487
  | XLAT_VAL_487
#  endif
#  ifdef XLAT_VAL_488
  | XLAT_VAL_488
#  endif
#  ifdef XLAT_VAL_489
  | XLAT_VAL_489
#  endif
#  ifdef XLAT_VAL_490
  | XLAT_VAL_490
#  endif
#  ifdef XLAT_VAL_491
  | XLAT_VAL_491
#  endif
#  ifdef XLAT_VAL_492
  | XLAT_VAL_492
#  endif
#  ifdef XLAT_VAL_493
  | XLAT_VAL_493
#  endif
#  ifdef XLAT_VAL_494
  | XLAT_VAL_494
#  endif
#  ifdef XLAT_VAL_495
  | XLAT_VAL_495
#  endif
#  ifdef XLAT_VAL_496
  | XLAT_VAL_496
#  endif
#  ifdef XLAT_VAL_497
  | XLAT_VAL_497
#  endif
#  ifdef XLAT_VAL_498
  | XLAT_VAL_498
#  endif
#  ifdef XLAT_VAL_499
  | XLAT_VAL_499
#  endif
#  ifdef XLAT_VAL_500
  | XLAT_VAL_500
#  endif
#  ifdef XLAT_VAL_501
  | XLAT_VAL_501
#  endif
#  ifdef XLAT_VAL_502
  | XLAT_VAL_502
#  endif
#  ifdef XLAT_VAL_503
  | XLAT_VAL_503
#  endif
#  ifdef XLAT_VAL_504
  | XLAT_VAL_504
#  endif
#  ifdef XLAT_VAL_505
  | XLAT_VAL_505
#  endif
#  ifdef XLAT_VAL_506
  | XLAT_VAL_506
#  endif
#  ifdef XLAT_VAL_507
  | XLAT_VAL_507
#  endif
#  ifdef XLAT_VAL_508
  | XLAT_VAL_508
#  endif
#  ifdef XLAT_VAL_509
  | XLAT_VAL_509
#  endif
#  ifdef XLAT_VAL_510
  | XLAT_VAL_510
#  endif
#  ifdef XLAT_VAL_511
  | XLAT_VAL_511
#  endif
#  ifdef XLAT_VAL_512
  | XLAT_VAL_512
#  endif
#  ifdef XLAT_VAL_513
  | XLAT_VAL_513
#  endif
#  ifdef XLAT_VAL_514
  | XLAT_VAL_514
#  endif
#  ifdef XLAT_VAL_515
  | XLAT_VAL_515
#  endif
#  ifdef XLAT_VAL_516
  | XLAT_VAL_516
#  endif
#  ifdef XLAT_VAL_517
  | XLAT_VAL_517
#  endif
#  ifdef XLAT_VAL_518
  | XLAT_VAL_518
#  endif
#  ifdef XLAT_VAL_519
  | XLAT_VAL_519
#  endif
#  ifdef XLAT_VAL_520
  | XLAT_VAL_520
#  endif
#  ifdef XLAT_VAL_521
  | XLAT_VAL_521
#  endif
#  ifdef XLAT_VAL_522
  | XLAT_VAL_522
#  endif
#  ifdef XLAT_VAL_523
  | XLAT_VAL_523
#  endif
#  ifdef XLAT_VAL_524
  | XLAT_VAL_524
#  endif
#  ifdef XLAT_VAL_525
  | XLAT_VAL_525
#  endif
#  ifdef XLAT_VAL_526
  | XLAT_VAL_526
#  endif
#  ifdef XLAT_VAL_527
  | XLAT_VAL_527
#  endif
#  ifdef XLAT_VAL_528
  | XLAT_VAL_528
#  endif
#  ifdef XLAT_VAL_529
  | XLAT_VAL_529
#  endif
#  ifdef XLAT_VAL_530
  | XLAT_VAL_530
#  endif
#  ifdef XLAT_VAL_531
  | XLAT_VAL_531
#  endif
#  ifdef XLAT_VAL_532
  | XLAT_VAL_532
#  endif
#  ifdef XLAT_VAL_533
  | XLAT_VAL_533
#  endif
#  ifdef XLAT_VAL_534
  | XLAT_VAL_534
#  endif
#  ifdef XLAT_VAL_535
  | XLAT_VAL_535
#  endif
#  ifdef XLAT_VAL_536
  | XLAT_VAL_536
#  endif
#  ifdef XLAT_VAL_537
  | XLAT_VAL_537
#  endif
#  ifdef XLAT_VAL_538
  | XLAT_VAL_538
#  endif
#  ifdef XLAT_VAL_539
  | XLAT_VAL_539
#  endif
#  ifdef XLAT_VAL_540
  | XLAT_VAL_540
#  endif
#  ifdef XLAT_VAL_541
  | XLAT_VAL_541
#  endif
#  ifdef XLAT_VAL_542
  | XLAT_VAL_542
#  endif
#  ifdef XLAT_VAL_543
  | XLAT_VAL_543
#  endif
#  ifdef XLAT_VAL_544
  | XLAT_VAL_544
#  endif
#  ifdef XLAT_VAL_545
  | XLAT_VAL_545
#  endif
#  ifdef XLAT_VAL_546
  | XLAT_VAL_546
#  endif
#  ifdef XLAT_VAL_547
  | XLAT_VAL_547
#  endif
#  ifdef XLAT_VAL_548
  | XLAT_VAL_548
#  endif
#  ifdef XLAT_VAL_549
  | XLAT_VAL_549
#  endif
#  ifdef XLAT_VAL_550
  | XLAT_VAL_550
#  endif
#  ifdef XLAT_VAL_551
  | XLAT_VAL_551
#  endif
#  ifdef XLAT_VAL_552
  | XLAT_VAL_552
#  endif
#  ifdef XLAT_VAL_553
  | XLAT_VAL_553
#  endif
#  ifdef XLAT_VAL_554
  | XLAT_VAL_554
#  endif
#  ifdef XLAT_VAL_555
  | XLAT_VAL_555
#  endif
#  ifdef XLAT_VAL_556
  | XLAT_VAL_556
#  endif
#  ifdef XLAT_VAL_557
  | XLAT_VAL_557
#  endif
#  ifdef XLAT_VAL_558
  | XLAT_VAL_558
#  endif
#  ifdef XLAT_VAL_559
  | XLAT_VAL_559
#  endif
#  ifdef XLAT_VAL_560
  | XLAT_VAL_560
#  endif
#  ifdef XLAT_VAL_561
  | XLAT_VAL_561
#  endif
#  ifdef XLAT_VAL_562
  | XLAT_VAL_562
#  endif
#  ifdef XLAT_VAL_563
  | XLAT_VAL_563
#  endif
#  ifdef XLAT_VAL_564
  | XLAT_VAL_564
#  endif
#  ifdef XLAT_VAL_565
  | XLAT_VAL_565
#  endif
#  ifdef XLAT_VAL_566
  | XLAT_VAL_566
#  endif
#  ifdef XLAT_VAL_567
  | XLAT_VAL_567
#  endif
#  ifdef XLAT_VAL_568
  | XLAT_VAL_568
#  endif
#  ifdef XLAT_VAL_569
  | XLAT_VAL_569
#  endif
#  ifdef XLAT_VAL_570
  | XLAT_VAL_570
#  endif
#  ifdef XLAT_VAL_571
  | XLAT_VAL_571
#  endif
#  ifdef XLAT_VAL_572
  | XLAT_VAL_572
#  endif
#  ifdef XLAT_VAL_573
  | XLAT_VAL_573
#  endif
#  ifdef XLAT_VAL_574
  | XLAT_VAL_574
#  endif
#  ifdef XLAT_VAL_575
  | XLAT_VAL_575
#  endif
#  ifdef XLAT_VAL_576
  | XLAT_VAL_576
#  endif
#  ifdef XLAT_VAL_577
  | XLAT_VAL_577
#  endif
#  ifdef XLAT_VAL_578
  | XLAT_VAL_578
#  endif
#  ifdef XLAT_VAL_579
  | XLAT_VAL_579
#  endif
#  ifdef XLAT_VAL_580
  | XLAT_VAL_580
#  endif
#  ifdef XLAT_VAL_581
  | XLAT_VAL_581
#  endif
#  ifdef XLAT_VAL_582
  | XLAT_VAL_582
#  endif
#  ifdef XLAT_VAL_583
  | XLAT_VAL_583
#  endif
#  ifdef XLAT_VAL_584
  | XLAT_VAL_584
#  endif
#  ifdef XLAT_VAL_585
  | XLAT_VAL_585
#  endif
#  ifdef XLAT_VAL_586
  | XLAT_VAL_586
#  endif
#  ifdef XLAT_VAL_587
  | XLAT_VAL_587
#  endif
#  ifdef XLAT_VAL_588
  | XLAT_VAL_588
#  endif
#  ifdef XLAT_VAL_589
  | XLAT_VAL_589
#  endif
#  ifdef XLAT_VAL_590
  | XLAT_VAL_590
#  endif
#  ifdef XLAT_VAL_591
  | XLAT_VAL_591
#  endif
#  ifdef XLAT_VAL_592
  | XLAT_VAL_592
#  endif
#  ifdef XLAT_VAL_593
  | XLAT_VAL_593
#  endif
#  ifdef XLAT_VAL_594
  | XLAT_VAL_594
#  endif
#  ifdef XLAT_VAL_595
  | XLAT_VAL_595
#  endif
#  ifdef XLAT_VAL_596
  | XLAT_VAL_596
#  endif
#  ifdef XLAT_VAL_597
  | XLAT_VAL_597
#  endif
#  ifdef XLAT_VAL_598
  | XLAT_VAL_598
#  endif
#  ifdef XLAT_VAL_599
  | XLAT_VAL_599
#  endif
#  ifdef XLAT_VAL_600
  | XLAT_VAL_600
#  endif
#  ifdef XLAT_VAL_601
  | XLAT_VAL_601
#  endif
#  ifdef XLAT_VAL_602
  | XLAT_VAL_602
#  endif
#  ifdef XLAT_VAL_603
  | XLAT_VAL_603
#  endif
#  ifdef XLAT_VAL_604
  | XLAT_VAL_604
#  endif
#  ifdef XLAT_VAL_605
  | XLAT_VAL_605
#  endif
#  ifdef XLAT_VAL_606
  | XLAT_VAL_606
#  endif
#  ifdef XLAT_VAL_607
  | XLAT_VAL_607
#  endif
#  ifdef XLAT_VAL_608
  | XLAT_VAL_608
#  endif
#  ifdef XLAT_VAL_609
  | XLAT_VAL_609
#  endif
#  ifdef XLAT_VAL_610
  | XLAT_VAL_610
#  endif
#  ifdef XLAT_VAL_611
  | XLAT_VAL_611
#  endif
#  ifdef XLAT_VAL_612
  | XLAT_VAL_612
#  endif
#  ifdef XLAT_VAL_613
  | XLAT_VAL_613
#  endif
#  ifdef XLAT_VAL_614
  | XLAT_VAL_614
#  endif
#  ifdef XLAT_VAL_615
  | XLAT_VAL_615
#  endif
#  ifdef XLAT_VAL_616
  | XLAT_VAL_616
#  endif
#  ifdef XLAT_VAL_617
  | XLAT_VAL_617
#  endif
#  ifdef XLAT_VAL_618
  | XLAT_VAL_618
#  endif
#  ifdef XLAT_VAL_619
  | XLAT_VAL_619
#  endif
#  ifdef XLAT_VAL_620
  | XLAT_VAL_620
#  endif
#  ifdef XLAT_VAL_621
  | XLAT_VAL_621
#  endif
#  ifdef XLAT_VAL_622
  | XLAT_VAL_622
#  endif
#  ifdef XLAT_VAL_623
  | XLAT_VAL_623
#  endif
  ,
 .flags_strsz = 0
#  ifdef XLAT_STR_0
  + sizeof(XLAT_STR_0)
#  endif
#  ifdef XLAT_STR_1
  + sizeof(XLAT_STR_1)
#  endif
#  ifdef XLAT_STR_2
  + sizeof(XLAT_STR_2)
#  endif
#  ifdef XLAT_STR_3
  + sizeof(XLAT_STR_3)
#  endif
#  ifdef XLAT_STR_4
  + sizeof(XLAT_STR_4)
#  endif
#  ifdef XLAT_STR_5
  + sizeof(XLAT_STR_5)
#  endif
#  ifdef XLAT_STR_6
  + sizeof(XLAT_STR_6)
#  endif
#  ifdef XLAT_STR_7
  + sizeof(XLAT_STR_7)
#  endif
#  ifdef XLAT_STR_8
  + sizeof(XLAT_STR_8)
#  endif
#  ifdef XLAT_STR_9
  + sizeof(XLAT_STR_9)
#  endif
#  ifdef XLAT_STR_10
  + sizeof(XLAT_STR_10)
#  endif
#  ifdef XLAT_STR_11
  + sizeof(XLAT_STR_11)
#  endif
#  ifdef XLAT_STR_12
  + sizeof(XLAT_STR_12)
#  endif
#  ifdef XLAT_STR_13
  + sizeof(XLAT_STR_13)
#  endif
#  ifdef XLAT_STR_14
  + sizeof(XLAT_STR_14)
#  endif
#  ifdef XLAT_STR_15
  + sizeof(XLAT_STR_15)
#  endif
#  ifdef XLAT_STR_16
  + sizeof(XLAT_STR_16)
#  endif
#  ifdef XLAT_STR_17
  + sizeof(XLAT_STR_17)
#  endif
#  ifdef XLAT_STR_18
  + sizeof(XLAT_STR_18)
#  endif
#  ifdef XLAT_STR_19
  + sizeof(XLAT_STR_19)
#  endif
#  ifdef XLAT_STR_20
  + sizeof(XLAT_STR_20)
#  endif
#  ifdef XLAT_STR_21
  + sizeof(XLAT_STR_21)
#  endif
#  ifdef XLAT_STR_22
  + sizeof(XLAT_STR_22)
#  endif
#  ifdef XLAT_STR_23
  + sizeof(XLAT_STR_23)
#  endif
#  ifdef XLAT_STR_24
  + sizeof(XLAT_STR_24)
#  endif
#  ifdef XLAT_STR_25
  + sizeof(XLAT_STR_25)
#  endif
#  ifdef XLAT_STR_26
  + sizeof(XLAT_STR_26)
#  endif
#  ifdef XLAT_STR_27
  + sizeof(XLAT_STR_27)
#  endif
#  ifdef XLAT_STR_28
  + sizeof(XLAT_STR_28)
#  endif
#  ifdef XLAT_STR_29
  + sizeof(XLAT_STR_29)
#  endif
#  ifdef XLAT_STR_30
  + sizeof(XLAT_STR_30)
#  endif
#  ifdef XLAT_STR_31
  + sizeof(XLAT_STR_31)
#  endif
#  ifdef XLAT_STR_32
  + sizeof(XLAT_STR_32)
#  endif
#  ifdef XLAT_STR_33
  + sizeof(XLAT_STR_33)
#  endif
#  ifdef XLAT_STR_34
  + sizeof(XLAT_STR_34)
#  endif
#  ifdef XLAT_STR_35
  + sizeof(XLAT_STR_35)
#  endif
#  ifdef XLAT_STR_36
  + sizeof(XLAT_STR_36)
#  endif
#  ifdef XLAT_STR_37
  + sizeof(XLAT_STR_37)
#  endif
#  ifdef XLAT_STR_38
  + sizeof(XLAT_STR_38)
#  endif
#  ifdef XLAT_STR_39
  + sizeof(XLAT_STR_39)
#  endif
#  ifdef XLAT_STR_40
  + sizeof(XLAT_STR_40)
#  endif
#  ifdef XLAT_STR_41
  + sizeof(XLAT_STR_41)
#  endif
#  ifdef XLAT_STR_42
  + sizeof(XLAT_STR_42)
#  endif
#  ifdef XLAT_STR_43
  + sizeof(XLAT_STR_43)
#  endif
#  ifdef XLAT_STR_44
  + sizeof(XLAT_STR_44)
#  endif
#  ifdef XLAT_STR_45
  + sizeof(XLAT_STR_45)
#  endif
#  ifdef XLAT_STR_46
  + sizeof(XLAT_STR_46)
#  endif
#  ifdef XLAT_STR_47
  + sizeof(XLAT_STR_47)
#  endif
#  ifdef XLAT_STR_48
  + sizeof(XLAT_STR_48)
#  endif
#  ifdef XLAT_STR_49
  + sizeof(XLAT_STR_49)
#  endif
#  ifdef XLAT_STR_50
  + sizeof(XLAT_STR_50)
#  endif
#  ifdef XLAT_STR_51
  + sizeof(XLAT_STR_51)
#  endif
#  ifdef XLAT_STR_52
  + sizeof(XLAT_STR_52)
#  endif
#  ifdef XLAT_STR_53
  + sizeof(XLAT_STR_53)
#  endif
#  ifdef XLAT_STR_54
  + sizeof(XLAT_STR_54)
#  endif
#  ifdef XLAT_STR_55
  + sizeof(XLAT_STR_55)
#  endif
#  ifdef XLAT_STR_56
  + sizeof(XLAT_STR_56)
#  endif
#  ifdef XLAT_STR_57
  + sizeof(XLAT_STR_57)
#  endif
#  ifdef XLAT_STR_58
  + sizeof(XLAT_STR_58)
#  endif
#  ifdef XLAT_STR_59
  + sizeof(XLAT_STR_59)
#  endif
#  ifdef XLAT_STR_60
  + sizeof(XLAT_STR_60)
#  endif
#  ifdef XLAT_STR_61
  + sizeof(XLAT_STR_61)
#  endif
#  ifdef XLAT_STR_62
  + sizeof(XLAT_STR_62)
#  endif
#  ifdef XLAT_STR_63
  + sizeof(XLAT_STR_63)
#  endif
#  ifdef XLAT_STR_64
  + sizeof(XLAT_STR_64)
#  endif
#  ifdef XLAT_STR_65
  + sizeof(XLAT_STR_65)
#  endif
#  ifdef XLAT_STR_66
  + sizeof(XLAT_STR_66)
#  endif
#  ifdef XLAT_STR_67
  + sizeof(XLAT_STR_67)
#  endif
#  ifdef XLAT_STR_68
  + sizeof(XLAT_STR_68)
#  endif
#  ifdef XLAT_STR_69
  + sizeof(XLAT_STR_69)
#  endif
#  ifdef XLAT_STR_70
  + sizeof(XLAT_STR_70)
#  endif
#  ifdef XLAT_STR_71
  + sizeof(XLAT_STR_71)
#  endif
#  ifdef XLAT_STR_72
  + sizeof(XLAT_STR_72)
#  endif
#  ifdef XLAT_STR_73
  + sizeof(XLAT_STR_73)
#  endif
#  ifdef XLAT_STR_74
  + sizeof(XLAT_STR_74)
#  endif
#  ifdef XLAT_STR_75
  + sizeof(XLAT_STR_75)
#  endif
#  ifdef XLAT_STR_76
  + sizeof(XLAT_STR_76)
#  endif
#  ifdef XLAT_STR_77
  + sizeof(XLAT_STR_77)
#  endif
#  ifdef XLAT_STR_78
  + sizeof(XLAT_STR_78)
#  endif
#  ifdef XLAT_STR_79
  + sizeof(XLAT_STR_79)
#  endif
#  ifdef XLAT_STR_80
  + sizeof(XLAT_STR_80)
#  endif
#  ifdef XLAT_STR_81
  + sizeof(XLAT_STR_81)
#  endif
#  ifdef XLAT_STR_82
  + sizeof(XLAT_STR_82)
#  endif
#  ifdef XLAT_STR_83
  + sizeof(XLAT_STR_83)
#  endif
#  ifdef XLAT_STR_84
  + sizeof(XLAT_STR_84)
#  endif
#  ifdef XLAT_STR_85
  + sizeof(XLAT_STR_85)
#  endif
#  ifdef XLAT_STR_86
  + sizeof(XLAT_STR_86)
#  endif
#  ifdef XLAT_STR_87
  + sizeof(XLAT_STR_87)
#  endif
#  ifdef XLAT_STR_88
  + sizeof(XLAT_STR_88)
#  endif
#  ifdef XLAT_STR_89
  + sizeof(XLAT_STR_89)
#  endif
#  ifdef XLAT_STR_90
  + sizeof(XLAT_STR_90)
#  endif
#  ifdef XLAT_STR_91
  + sizeof(XLAT_STR_91)
#  endif
#  ifdef XLAT_STR_92
  + sizeof(XLAT_STR_92)
#  endif
#  ifdef XLAT_STR_93
  + sizeof(XLAT_STR_93)
#  endif
#  ifdef XLAT_STR_94
  + sizeof(XLAT_STR_94)
#  endif
#  ifdef XLAT_STR_95
  + sizeof(XLAT_STR_95)
#  endif
#  ifdef XLAT_STR_96
  + sizeof(XLAT_STR_96)
#  endif
#  ifdef XLAT_STR_97
  + sizeof(XLAT_STR_97)
#  endif
#  ifdef XLAT_STR_98
  + sizeof(XLAT_STR_98)
#  endif
#  ifdef XLAT_STR_99
  + sizeof(XLAT_STR_99)
#  endif
#  ifdef XLAT_STR_100
  + sizeof(XLAT_STR_100)
#  endif
#  ifdef XLAT_STR_101
  + sizeof(XLAT_STR_101)
#  endif
#  ifdef XLAT_STR_102
  + sizeof(XLAT_STR_102)
#  endif
#  ifdef XLAT_STR_103
  + sizeof(XLAT_STR_103)
#  endif
#  ifdef XLAT_STR_104
  + sizeof(XLAT_STR_104)
#  endif
#  ifdef XLAT_STR_105
  + sizeof(XLAT_STR_105)
#  endif
#  ifdef XLAT_STR_106
  + sizeof(XLAT_STR_106)
#  endif
#  ifdef XLAT_STR_107
  + sizeof(XLAT_STR_107)
#  endif
#  ifdef XLAT_STR_108
  + sizeof(XLAT_STR_108)
#  endif
#  ifdef XLAT_STR_109
  + sizeof(XLAT_STR_109)
#  endif
#  ifdef XLAT_STR_110
  + sizeof(XLAT_STR_110)
#  endif
#  ifdef XLAT_STR_111
  + sizeof(XLAT_STR_111)
#  endif
#  ifdef XLAT_STR_112
  + sizeof(XLAT_STR_112)
#  endif
#  ifdef XLAT_STR_113
  + sizeof(XLAT_STR_113)
#  endif
#  ifdef XLAT_STR_114
  + sizeof(XLAT_STR_114)
#  endif
#  ifdef XLAT_STR_115
  + sizeof(XLAT_STR_115)
#  endif
#  ifdef XLAT_STR_116
  + sizeof(XLAT_STR_116)
#  endif
#  ifdef XLAT_STR_117
  + sizeof(XLAT_STR_117)
#  endif
#  ifdef XLAT_STR_118
  + sizeof(XLAT_STR_118)
#  endif
#  ifdef XLAT_STR_119
  + sizeof(XLAT_STR_119)
#  endif
#  ifdef XLAT_STR_120
  + sizeof(XLAT_STR_120)
#  endif
#  ifdef XLAT_STR_121
  + sizeof(XLAT_STR_121)
#  endif
#  ifdef XLAT_STR_122
  + sizeof(XLAT_STR_122)
#  endif
#  ifdef XLAT_STR_123
  + sizeof(XLAT_STR_123)
#  endif
#  ifdef XLAT_STR_124
  + sizeof(XLAT_STR_124)
#  endif
#  ifdef XLAT_STR_125
  + sizeof(XLAT_STR_125)
#  endif
#  ifdef XLAT_STR_126
  + sizeof(XLAT_STR_126)
#  endif
#  ifdef XLAT_STR_127
  + sizeof(XLAT_STR_127)
#  endif
#  ifdef XLAT_STR_128
  + sizeof(XLAT_STR_128)
#  endif
#  ifdef XLAT_STR_129
  + sizeof(XLAT_STR_129)
#  endif
#  ifdef XLAT_STR_130
  + sizeof(XLAT_STR_130)
#  endif
#  ifdef XLAT_STR_131
  + sizeof(XLAT_STR_131)
#  endif
#  ifdef XLAT_STR_132
  + sizeof(XLAT_STR_132)
#  endif
#  ifdef XLAT_STR_133
  + sizeof(XLAT_STR_133)
#  endif
#  ifdef XLAT_STR_134
  + sizeof(XLAT_STR_134)
#  endif
#  ifdef XLAT_STR_135
  + sizeof(XLAT_STR_135)
#  endif
#  ifdef XLAT_STR_136
  + sizeof(XLAT_STR_136)
#  endif
#  ifdef XLAT_STR_137
  + sizeof(XLAT_STR_137)
#  endif
#  ifdef XLAT_STR_138
  + sizeof(XLAT_STR_138)
#  endif
#  ifdef XLAT_STR_139
  + sizeof(XLAT_STR_139)
#  endif
#  ifdef XLAT_STR_140
  + sizeof(XLAT_STR_140)
#  endif
#  ifdef XLAT_STR_141
  + sizeof(XLAT_STR_141)
#  endif
#  ifdef XLAT_STR_142
  + sizeof(XLAT_STR_142)
#  endif
#  ifdef XLAT_STR_143
  + sizeof(XLAT_STR_143)
#  endif
#  ifdef XLAT_STR_144
  + sizeof(XLAT_STR_144)
#  endif
#  ifdef XLAT_STR_145
  + sizeof(XLAT_STR_145)
#  endif
#  ifdef XLAT_STR_146
  + sizeof(XLAT_STR_146)
#  endif
#  ifdef XLAT_STR_147
  + sizeof(XLAT_STR_147)
#  endif
#  ifdef XLAT_STR_148
  + sizeof(XLAT_STR_148)
#  endif
#  ifdef XLAT_STR_149
  + sizeof(XLAT_STR_149)
#  endif
#  ifdef XLAT_STR_150
  + sizeof(XLAT_STR_150)
#  endif
#  ifdef XLAT_STR_151
  + sizeof(XLAT_STR_151)
#  endif
#  ifdef XLAT_STR_152
  + sizeof(XLAT_STR_152)
#  endif
#  ifdef XLAT_STR_153
  + sizeof(XLAT_STR_153)
#  endif
#  ifdef XLAT_STR_154
  + sizeof(XLAT_STR_154)
#  endif
#  ifdef XLAT_STR_155
  + sizeof(XLAT_STR_155)
#  endif
#  ifdef XLAT_STR_156
  + sizeof(XLAT_STR_156)
#  endif
#  ifdef XLAT_STR_157
  + sizeof(XLAT_STR_157)
#  endif
#  ifdef XLAT_STR_158
  + sizeof(XLAT_STR_158)
#  endif
#  ifdef XLAT_STR_159
  + sizeof(XLAT_STR_159)
#  endif
#  ifdef XLAT_STR_160
  + sizeof(XLAT_STR_160)
#  endif
#  ifdef XLAT_STR_161
  + sizeof(XLAT_STR_161)
#  endif
#  ifdef XLAT_STR_162
  + sizeof(XLAT_STR_162)
#  endif
#  ifdef XLAT_STR_163
  + sizeof(XLAT_STR_163)
#  endif
#  ifdef XLAT_STR_164
  + sizeof(XLAT_STR_164)
#  endif
#  ifdef XLAT_STR_165
  + sizeof(XLAT_STR_165)
#  endif
#  ifdef XLAT_STR_166
  + sizeof(XLAT_STR_166)
#  endif
#  ifdef XLAT_STR_167
  + sizeof(XLAT_STR_167)
#  endif
#  ifdef XLAT_STR_168
  + sizeof(XLAT_STR_168)
#  endif
#  ifdef XLAT_STR_169
  + sizeof(XLAT_STR_169)
#  endif
#  ifdef XLAT_STR_170
  + sizeof(XLAT_STR_170)
#  endif
#  ifdef XLAT_STR_171
  + sizeof(XLAT_STR_171)
#  endif
#  ifdef XLAT_STR_172
  + sizeof(XLAT_STR_172)
#  endif
#  ifdef XLAT_STR_173
  + sizeof(XLAT_STR_173)
#  endif
#  ifdef XLAT_STR_174
  + sizeof(XLAT_STR_174)
#  endif
#  ifdef XLAT_STR_175
  + sizeof(XLAT_STR_175)
#  endif
#  ifdef XLAT_STR_176
  + sizeof(XLAT_STR_176)
#  endif
#  ifdef XLAT_STR_177
  + sizeof(XLAT_STR_177)
#  endif
#  ifdef XLAT_STR_178
  + sizeof(XLAT_STR_178)
#  endif
#  ifdef XLAT_STR_179
  + sizeof(XLAT_STR_179)
#  endif
#  ifdef XLAT_STR_180
  + sizeof(XLAT_STR_180)
#  endif
#  ifdef XLAT_STR_181
  + sizeof(XLAT_STR_181)
#  endif
#  ifdef XLAT_STR_182
  + sizeof(XLAT_STR_182)
#  endif
#  ifdef XLAT_STR_183
  + sizeof(XLAT_STR_183)
#  endif
#  ifdef XLAT_STR_184
  + sizeof(XLAT_STR_184)
#  endif
#  ifdef XLAT_STR_185
  + sizeof(XLAT_STR_185)
#  endif
#  ifdef XLAT_STR_186
  + sizeof(XLAT_STR_186)
#  endif
#  ifdef XLAT_STR_187
  + sizeof(XLAT_STR_187)
#  endif
#  ifdef XLAT_STR_188
  + sizeof(XLAT_STR_188)
#  endif
#  ifdef XLAT_STR_189
  + sizeof(XLAT_STR_189)
#  endif
#  ifdef XLAT_STR_190
  + sizeof(XLAT_STR_190)
#  endif
#  ifdef XLAT_STR_191
  + sizeof(XLAT_STR_191)
#  endif
#  ifdef XLAT_STR_192
  + sizeof(XLAT_STR_192)
#  endif
#  ifdef XLAT_STR_193
  + sizeof(XLAT_STR_193)
#  endif
#  ifdef XLAT_STR_194
  + sizeof(XLAT_STR_194)
#  endif
#  ifdef XLAT_STR_195
  + sizeof(XLAT_STR_195)
#  endif
#  ifdef XLAT_STR_196
  + sizeof(XLAT_STR_196)
#  endif
#  ifdef XLAT_STR_197
  + sizeof(XLAT_STR_197)
#  endif
#  ifdef XLAT_STR_198
  + sizeof(XLAT_STR_198)
#  endif
#  ifdef XLAT_STR_199
  + sizeof(XLAT_STR_199)
#  endif
#  ifdef XLAT_STR_200
  + sizeof(XLAT_STR_200)
#  endif
#  ifdef XLAT_STR_201
  + sizeof(XLAT_STR_201)
#  endif
#  ifdef XLAT_STR_202
  + sizeof(XLAT_STR_202)
#  endif
#  ifdef XLAT_STR_203
  + sizeof(XLAT_STR_203)
#  endif
#  ifdef XLAT_STR_204
  + sizeof(XLAT_STR_204)
#  endif
#  ifdef XLAT_STR_205
  + sizeof(XLAT_STR_205)
#  endif
#  ifdef XLAT_STR_206
  + sizeof(XLAT_STR_206)
#  endif
#  ifdef XLAT_STR_207
  + sizeof(XLAT_STR_207)
#  endif
#  ifdef XLAT_STR_208
  + sizeof(XLAT_STR_208)
#  endif
#  ifdef XLAT_STR_209
  + sizeof(XLAT_STR_209)
#  endif
#  ifdef XLAT_STR_210
  + sizeof(XLAT_STR_210)
#  endif
#  ifdef XLAT_STR_211
  + sizeof(XLAT_STR_211)
#  endif
#  ifdef XLAT_STR_212
  + sizeof(XLAT_STR_212)
#  endif
#  ifdef XLAT_STR_213
  + sizeof(XLAT_STR_213)
#  endif
#  ifdef XLAT_STR_214
  + sizeof(XLAT_STR_214)
#  endif
#  ifdef XLAT_STR_215
  + sizeof(XLAT_STR_215)
#  endif
#  ifdef XLAT_STR_216
  + sizeof(XLAT_STR_216)
#  endif
#  ifdef XLAT_STR_217
  + sizeof(XLAT_STR_217)
#  endif
#  ifdef XLAT_STR_218
  + sizeof(XLAT_STR_218)
#  endif
#  ifdef XLAT_STR_219
  + sizeof(XLAT_STR_219)
#  endif
#  ifdef XLAT_STR_220
  + sizeof(XLAT_STR_220)
#  endif
#  ifdef XLAT_STR_221
  + sizeof(XLAT_STR_221)
#  endif
#  ifdef XLAT_STR_222
  + sizeof(XLAT_STR_222)
#  endif
#  ifdef XLAT_STR_223
  + sizeof(XLAT_STR_223)
#  endif
#  ifdef XLAT_STR_224
  + sizeof(XLAT_STR_224)
#  endif
#  ifdef XLAT_STR_225
  + sizeof(XLAT_STR_225)
#  endif
#  ifdef XLAT_STR_226
  + sizeof(XLAT_STR_226)
#  endif
#  ifdef XLAT_STR_227
  + sizeof(XLAT_STR_227)
#  endif
#  ifdef XLAT_STR_228
  + sizeof(XLAT_STR_228)
#  endif
#  ifdef XLAT_STR_229
  + sizeof(XLAT_STR_229)
#  endif
#  ifdef XLAT_STR_230
  + sizeof(XLAT_STR_230)
#  endif
#  ifdef XLAT_STR_231
  + sizeof(XLAT_STR_231)
#  endif
#  ifdef XLAT_STR_232
  + sizeof(XLAT_STR_232)
#  endif
#  ifdef XLAT_STR_233
  + sizeof(XLAT_STR_233)
#  endif
#  ifdef XLAT_STR_234
  + sizeof(XLAT_STR_234)
#  endif
#  ifdef XLAT_STR_235
  + sizeof(XLAT_STR_235)
#  endif
#  ifdef XLAT_STR_236
  + sizeof(XLAT_STR_236)
#  endif
#  ifdef XLAT_STR_237
  + sizeof(XLAT_STR_237)
#  endif
#  ifdef XLAT_STR_238
  + sizeof(XLAT_STR_238)
#  endif
#  ifdef XLAT_STR_239
  + sizeof(XLAT_STR_239)
#  endif
#  ifdef XLAT_STR_240
  + sizeof(XLAT_STR_240)
#  endif
#  ifdef XLAT_STR_241
  + sizeof(XLAT_STR_241)
#  endif
#  ifdef XLAT_STR_242
  + sizeof(XLAT_STR_242)
#  endif
#  ifdef XLAT_STR_243
  + sizeof(XLAT_STR_243)
#  endif
#  ifdef XLAT_STR_244
  + sizeof(XLAT_STR_244)
#  endif
#  ifdef XLAT_STR_245
  + sizeof(XLAT_STR_245)
#  endif
#  ifdef XLAT_STR_246
  + sizeof(XLAT_STR_246)
#  endif
#  ifdef XLAT_STR_247
  + sizeof(XLAT_STR_247)
#  endif
#  ifdef XLAT_STR_248
  + sizeof(XLAT_STR_248)
#  endif
#  ifdef XLAT_STR_249
  + sizeof(XLAT_STR_249)
#  endif
#  ifdef XLAT_STR_250
  + sizeof(XLAT_STR_250)
#  endif
#  ifdef XLAT_STR_251
  + sizeof(XLAT_STR_251)
#  endif
#  ifdef XLAT_STR_252
  + sizeof(XLAT_STR_252)
#  endif
#  ifdef XLAT_STR_253
  + sizeof(XLAT_STR_253)
#  endif
#  ifdef XLAT_STR_254
  + sizeof(XLAT_STR_254)
#  endif
#  ifdef XLAT_STR_255
  + sizeof(XLAT_STR_255)
#  endif
#  ifdef XLAT_STR_256
  + sizeof(XLAT_STR_256)
#  endif
#  ifdef XLAT_STR_257
  + sizeof(XLAT_STR_257)
#  endif
#  ifdef XLAT_STR_258
  + sizeof(XLAT_STR_258)
#  endif
#  ifdef XLAT_STR_259
  + sizeof(XLAT_STR_259)
#  endif
#  ifdef XLAT_STR_260
  + sizeof(XLAT_STR_260)
#  endif
#  ifdef XLAT_STR_261
  + sizeof(XLAT_STR_261)
#  endif
#  ifdef XLAT_STR_262
  + sizeof(XLAT_STR_262)
#  endif
#  ifdef XLAT_STR_263
  + sizeof(XLAT_STR_263)
#  endif
#  ifdef XLAT_STR_264
  + sizeof(XLAT_STR_264)
#  endif
#  ifdef XLAT_STR_265
  + sizeof(XLAT_STR_265)
#  endif
#  ifdef XLAT_STR_266
  + sizeof(XLAT_STR_266)
#  endif
#  ifdef XLAT_STR_267
  + sizeof(XLAT_STR_267)
#  endif
#  ifdef XLAT_STR_268
  + sizeof(XLAT_STR_268)
#  endif
#  ifdef XLAT_STR_269
  + sizeof(XLAT_STR_269)
#  endif
#  ifdef XLAT_STR_270
  + sizeof(XLAT_STR_270)
#  endif
#  ifdef XLAT_STR_271
  + sizeof(XLAT_STR_271)
#  endif
#  ifdef XLAT_STR_272
  + sizeof(XLAT_STR_272)
#  endif
#  ifdef XLAT_STR_273
  + sizeof(XLAT_STR_273)
#  endif
#  ifdef XLAT_STR_274
  + sizeof(XLAT_STR_274)
#  endif
#  ifdef XLAT_STR_275
  + sizeof(XLAT_STR_275)
#  endif
#  ifdef XLAT_STR_276
  + sizeof(XLAT_STR_276)
#  endif
#  ifdef XLAT_STR_277
  + sizeof(XLAT_STR_277)
#  endif
#  ifdef XLAT_STR_278
  + sizeof(XLAT_STR_278)
#  endif
#  ifdef XLAT_STR_279
  + sizeof(XLAT_STR_279)
#  endif
#  ifdef XLAT_STR_280
  + sizeof(XLAT_STR_280)
#  endif
#  ifdef XLAT_STR_281
  + sizeof(XLAT_STR_281)
#  endif
#  ifdef XLAT_STR_282
  + sizeof(XLAT_STR_282)
#  endif
#  ifdef XLAT_STR_283
  + sizeof(XLAT_STR_283)
#  endif
#  ifdef XLAT_STR_284
  + sizeof(XLAT_STR_284)
#  endif
#  ifdef XLAT_STR_285
  + sizeof(XLAT_STR_285)
#  endif
#  ifdef XLAT_STR_286
  + sizeof(XLAT_STR_286)
#  endif
#  ifdef XLAT_STR_287
  + sizeof(XLAT_STR_287)
#  endif
#  ifdef XLAT_STR_288
  + sizeof(XLAT_STR_288)
#  endif
#  ifdef XLAT_STR_289
  + sizeof(XLAT_STR_289)
#  endif
#  ifdef XLAT_STR_290
  + sizeof(XLAT_STR_290)
#  endif
#  ifdef XLAT_STR_291
  + sizeof(XLAT_STR_291)
#  endif
#  ifdef XLAT_STR_292
  + sizeof(XLAT_STR_292)
#  endif
#  ifdef XLAT_STR_293
  + sizeof(XLAT_STR_293)
#  endif
#  ifdef XLAT_STR_294
  + sizeof(XLAT_STR_294)
#  endif
#  ifdef XLAT_STR_295
  + sizeof(XLAT_STR_295)
#  endif
#  ifdef XLAT_STR_296
  + sizeof(XLAT_STR_296)
#  endif
#  ifdef XLAT_STR_297
  + sizeof(XLAT_STR_297)
#  endif
#  ifdef XLAT_STR_298
  + sizeof(XLAT_STR_298)
#  endif
#  ifdef XLAT_STR_299
  + sizeof(XLAT_STR_299)
#  endif
#  ifdef XLAT_STR_300
  + sizeof(XLAT_STR_300)
#  endif
#  ifdef XLAT_STR_301
  + sizeof(XLAT_STR_301)
#  endif
#  ifdef XLAT_STR_302
  + sizeof(XLAT_STR_302)
#  endif
#  ifdef XLAT_STR_303
  + sizeof(XLAT_STR_303)
#  endif
#  ifdef XLAT_STR_304
  + sizeof(XLAT_STR_304)
#  endif
#  ifdef XLAT_STR_305
  + sizeof(XLAT_STR_305)
#  endif
#  ifdef XLAT_STR_306
  + sizeof(XLAT_STR_306)
#  endif
#  ifdef XLAT_STR_307
  + sizeof(XLAT_STR_307)
#  endif
#  ifdef XLAT_STR_308
  + sizeof(XLAT_STR_308)
#  endif
#  ifdef XLAT_STR_309
  + sizeof(XLAT_STR_309)
#  endif
#  ifdef XLAT_STR_310
  + sizeof(XLAT_STR_310)
#  endif
#  ifdef XLAT_STR_311
  + sizeof(XLAT_STR_311)
#  endif
#  ifdef XLAT_STR_312
  + sizeof(XLAT_STR_312)
#  endif
#  ifdef XLAT_STR_313
  + sizeof(XLAT_STR_313)
#  endif
#  ifdef XLAT_STR_314
  + sizeof(XLAT_STR_314)
#  endif
#  ifdef XLAT_STR_315
  + sizeof(XLAT_STR_315)
#  endif
#  ifdef XLAT_STR_316
  + sizeof(XLAT_STR_316)
#  endif
#  ifdef XLAT_STR_317
  + sizeof(XLAT_STR_317)
#  endif
#  ifdef XLAT_STR_318
  + sizeof(XLAT_STR_318)
#  endif
#  ifdef XLAT_STR_319
  + sizeof(XLAT_STR_319)
#  endif
#  ifdef XLAT_STR_320
  + sizeof(XLAT_STR_320)
#  endif
#  ifdef XLAT_STR_321
  + sizeof(XLAT_STR_321)
#  endif
#  ifdef XLAT_STR_322
  + sizeof(XLAT_STR_322)
#  endif
#  ifdef XLAT_STR_323
  + sizeof(XLAT_STR_323)
#  endif
#  ifdef XLAT_STR_324
  + sizeof(XLAT_STR_324)
#  endif
#  ifdef XLAT_STR_325
  + sizeof(XLAT_STR_325)
#  endif
#  ifdef XLAT_STR_326
  + sizeof(XLAT_STR_326)
#  endif
#  ifdef XLAT_STR_327
  + sizeof(XLAT_STR_327)
#  endif
#  ifdef XLAT_STR_328
  + sizeof(XLAT_STR_328)
#  endif
#  ifdef XLAT_STR_329
  + sizeof(XLAT_STR_329)
#  endif
#  ifdef XLAT_STR_330
  + sizeof(XLAT_STR_330)
#  endif
#  ifdef XLAT_STR_331
  + sizeof(XLAT_STR_331)
#  endif
#  ifdef XLAT_STR_332
  + sizeof(XLAT_STR_332)
#  endif
#  ifdef XLAT_STR_333
  + sizeof(XLAT_STR_333)
#  endif
#  ifdef XLAT_STR_334
  + sizeof(XLAT_STR_334)
#  endif
#  ifdef XLAT_STR_335
  + sizeof(XLAT_STR_335)
#  endif
#  ifdef XLAT_STR_336
  + sizeof(XLAT_STR_336)
#  endif
#  ifdef XLAT_STR_337
  + sizeof(XLAT_STR_337)
#  endif
#  ifdef XLAT_STR_338
  + sizeof(XLAT_STR_338)
#  endif
#  ifdef XLAT_STR_339
  + sizeof(XLAT_STR_339)
#  endif
#  ifdef XLAT_STR_340
  + sizeof(XLAT_STR_340)
#  endif
#  ifdef XLAT_STR_341
  + sizeof(XLAT_STR_341)
#  endif
#  ifdef XLAT_STR_342
  + sizeof(XLAT_STR_342)
#  endif
#  ifdef XLAT_STR_343
  + sizeof(XLAT_STR_343)
#  endif
#  ifdef XLAT_STR_344
  + sizeof(XLAT_STR_344)
#  endif
#  ifdef XLAT_STR_345
  + sizeof(XLAT_STR_345)
#  endif
#  ifdef XLAT_STR_346
  + sizeof(XLAT_STR_346)
#  endif
#  ifdef XLAT_STR_347
  + sizeof(XLAT_STR_347)
#  endif
#  ifdef XLAT_STR_348
  + sizeof(XLAT_STR_348)
#  endif
#  ifdef XLAT_STR_349
  + sizeof(XLAT_STR_349)
#  endif
#  ifdef XLAT_STR_350
  + sizeof(XLAT_STR_350)
#  endif
#  ifdef XLAT_STR_351
  + sizeof(XLAT_STR_351)
#  endif
#  ifdef XLAT_STR_352
  + sizeof(XLAT_STR_352)
#  endif
#  ifdef XLAT_STR_353
  + sizeof(XLAT_STR_353)
#  endif
#  ifdef XLAT_STR_354
  + sizeof(XLAT_STR_354)
#  endif
#  ifdef XLAT_STR_355
  + sizeof(XLAT_STR_355)
#  endif
#  ifdef XLAT_STR_356
  + sizeof(XLAT_STR_356)
#  endif
#  ifdef XLAT_STR_357
  + sizeof(XLAT_STR_357)
#  endif
#  ifdef XLAT_STR_358
  + sizeof(XLAT_STR_358)
#  endif
#  ifdef XLAT_STR_359
  + sizeof(XLAT_STR_359)
#  endif
#  ifdef XLAT_STR_360
  + sizeof(XLAT_STR_360)
#  endif
#  ifdef XLAT_STR_361
  + sizeof(XLAT_STR_361)
#  endif
#  ifdef XLAT_STR_362
  + sizeof(XLAT_STR_362)
#  endif
#  ifdef XLAT_STR_363
  + sizeof(XLAT_STR_363)
#  endif
#  ifdef XLAT_STR_364
  + sizeof(XLAT_STR_364)
#  endif
#  ifdef XLAT_STR_365
  + sizeof(XLAT_STR_365)
#  endif
#  ifdef XLAT_STR_366
  + sizeof(XLAT_STR_366)
#  endif
#  ifdef XLAT_STR_367
  + sizeof(XLAT_STR_367)
#  endif
#  ifdef XLAT_STR_368
  + sizeof(XLAT_STR_368)
#  endif
#  ifdef XLAT_STR_369
  + sizeof(XLAT_STR_369)
#  endif
#  ifdef XLAT_STR_370
  + sizeof(XLAT_STR_370)
#  endif
#  ifdef XLAT_STR_371
  + sizeof(XLAT_STR_371)
#  endif
#  ifdef XLAT_STR_372
  + sizeof(XLAT_STR_372)
#  endif
#  ifdef XLAT_STR_373
  + sizeof(XLAT_STR_373)
#  endif
#  ifdef XLAT_STR_374
  + sizeof(XLAT_STR_374)
#  endif
#  ifdef XLAT_STR_375
  + sizeof(XLAT_STR_375)
#  endif
#  ifdef XLAT_STR_376
  + sizeof(XLAT_STR_376)
#  endif
#  ifdef XLAT_STR_377
  + sizeof(XLAT_STR_377)
#  endif
#  ifdef XLAT_STR_378
  + sizeof(XLAT_STR_378)
#  endif
#  ifdef XLAT_STR_379
  + sizeof(XLAT_STR_379)
#  endif
#  ifdef XLAT_STR_380
  + sizeof(XLAT_STR_380)
#  endif
#  ifdef XLAT_STR_381
  + sizeof(XLAT_STR_381)
#  endif
#  ifdef XLAT_STR_382
  + sizeof(XLAT_STR_382)
#  endif
#  ifdef XLAT_STR_383
  + sizeof(XLAT_STR_383)
#  endif
#  ifdef XLAT_STR_384
  + sizeof(XLAT_STR_384)
#  endif
#  ifdef XLAT_STR_385
  + sizeof(XLAT_STR_385)
#  endif
#  ifdef XLAT_STR_386
  + sizeof(XLAT_STR_386)
#  endif
#  ifdef XLAT_STR_387
  + sizeof(XLAT_STR_387)
#  endif
#  ifdef XLAT_STR_388
  + sizeof(XLAT_STR_388)
#  endif
#  ifdef XLAT_STR_389
  + sizeof(XLAT_STR_389)
#  endif
#  ifdef XLAT_STR_390
  + sizeof(XLAT_STR_390)
#  endif
#  ifdef XLAT_STR_391
  + sizeof(XLAT_STR_391)
#  endif
#  ifdef XLAT_STR_392
  + sizeof(XLAT_STR_392)
#  endif
#  ifdef XLAT_STR_393
  + sizeof(XLAT_STR_393)
#  endif
#  ifdef XLAT_STR_394
  + sizeof(XLAT_STR_394)
#  endif
#  ifdef XLAT_STR_395
  + sizeof(XLAT_STR_395)
#  endif
#  ifdef XLAT_STR_396
  + sizeof(XLAT_STR_396)
#  endif
#  ifdef XLAT_STR_397
  + sizeof(XLAT_STR_397)
#  endif
#  ifdef XLAT_STR_398
  + sizeof(XLAT_STR_398)
#  endif
#  ifdef XLAT_STR_399
  + sizeof(XLAT_STR_399)
#  endif
#  ifdef XLAT_STR_400
  + sizeof(XLAT_STR_400)
#  endif
#  ifdef XLAT_STR_401
  + sizeof(XLAT_STR_401)
#  endif
#  ifdef XLAT_STR_402
  + sizeof(XLAT_STR_402)
#  endif
#  ifdef XLAT_STR_403
  + sizeof(XLAT_STR_403)
#  endif
#  ifdef XLAT_STR_404
  + sizeof(XLAT_STR_404)
#  endif
#  ifdef XLAT_STR_405
  + sizeof(XLAT_STR_405)
#  endif
#  ifdef XLAT_STR_406
  + sizeof(XLAT_STR_406)
#  endif
#  ifdef XLAT_STR_407
  + sizeof(XLAT_STR_407)
#  endif
#  ifdef XLAT_STR_408
  + sizeof(XLAT_STR_408)
#  endif
#  ifdef XLAT_STR_409
  + sizeof(XLAT_STR_409)
#  endif
#  ifdef XLAT_STR_410
  + sizeof(XLAT_STR_410)
#  endif
#  ifdef XLAT_STR_411
  + sizeof(XLAT_STR_411)
#  endif
#  ifdef XLAT_STR_412
  + sizeof(XLAT_STR_412)
#  endif
#  ifdef XLAT_STR_413
  + sizeof(XLAT_STR_413)
#  endif
#  ifdef XLAT_STR_414
  + sizeof(XLAT_STR_414)
#  endif
#  ifdef XLAT_STR_415
  + sizeof(XLAT_STR_415)
#  endif
#  ifdef XLAT_STR_416
  + sizeof(XLAT_STR_416)
#  endif
#  ifdef XLAT_STR_417
  + sizeof(XLAT_STR_417)
#  endif
#  ifdef XLAT_STR_418
  + sizeof(XLAT_STR_418)
#  endif
#  ifdef XLAT_STR_419
  + sizeof(XLAT_STR_419)
#  endif
#  ifdef XLAT_STR_420
  + sizeof(XLAT_STR_420)
#  endif
#  ifdef XLAT_STR_421
  + sizeof(XLAT_STR_421)
#  endif
#  ifdef XLAT_STR_422
  + sizeof(XLAT_STR_422)
#  endif
#  ifdef XLAT_STR_423
  + sizeof(XLAT_STR_423)
#  endif
#  ifdef XLAT_STR_424
  + sizeof(XLAT_STR_424)
#  endif
#  ifdef XLAT_STR_425
  + sizeof(XLAT_STR_425)
#  endif
#  ifdef XLAT_STR_426
  + sizeof(XLAT_STR_426)
#  endif
#  ifdef XLAT_STR_427
  + sizeof(XLAT_STR_427)
#  endif
#  ifdef XLAT_STR_428
  + sizeof(XLAT_STR_428)
#  endif
#  ifdef XLAT_STR_429
  + sizeof(XLAT_STR_429)
#  endif
#  ifdef XLAT_STR_430
  + sizeof(XLAT_STR_430)
#  endif
#  ifdef XLAT_STR_431
  + sizeof(XLAT_STR_431)
#  endif
#  ifdef XLAT_STR_432
  + sizeof(XLAT_STR_432)
#  endif
#  ifdef XLAT_STR_433
  + sizeof(XLAT_STR_433)
#  endif
#  ifdef XLAT_STR_434
  + sizeof(XLAT_STR_434)
#  endif
#  ifdef XLAT_STR_435
  + sizeof(XLAT_STR_435)
#  endif
#  ifdef XLAT_STR_436
  + sizeof(XLAT_STR_436)
#  endif
#  ifdef XLAT_STR_437
  + sizeof(XLAT_STR_437)
#  endif
#  ifdef XLAT_STR_438
  + sizeof(XLAT_STR_438)
#  endif
#  ifdef XLAT_STR_439
  + sizeof(XLAT_STR_439)
#  endif
#  ifdef XLAT_STR_440
  + sizeof(XLAT_STR_440)
#  endif
#  ifdef XLAT_STR_441
  + sizeof(XLAT_STR_441)
#  endif
#  ifdef XLAT_STR_442
  + sizeof(XLAT_STR_442)
#  endif
#  ifdef XLAT_STR_443
  + sizeof(XLAT_STR_443)
#  endif
#  ifdef XLAT_STR_444
  + sizeof(XLAT_STR_444)
#  endif
#  ifdef XLAT_STR_445
  + sizeof(XLAT_STR_445)
#  endif
#  ifdef XLAT_STR_446
  + sizeof(XLAT_STR_446)
#  endif
#  ifdef XLAT_STR_447
  + sizeof(XLAT_STR_447)
#  endif
#  ifdef XLAT_STR_448
  + sizeof(XLAT_STR_448)
#  endif
#  ifdef XLAT_STR_449
  + sizeof(XLAT_STR_449)
#  endif
#  ifdef XLAT_STR_450
  + sizeof(XLAT_STR_450)
#  endif
#  ifdef XLAT_STR_451
  + sizeof(XLAT_STR_451)
#  endif
#  ifdef XLAT_STR_452
  + sizeof(XLAT_STR_452)
#  endif
#  ifdef XLAT_STR_453
  + sizeof(XLAT_STR_453)
#  endif
#  ifdef XLAT_STR_454
  + sizeof(XLAT_STR_454)
#  endif
#  ifdef XLAT_STR_455
  + sizeof(XLAT_STR_455)
#  endif
#  ifdef XLAT_STR_456
  + sizeof(XLAT_STR_456)
#  endif
#  ifdef XLAT_STR_457
  + sizeof(XLAT_STR_457)
#  endif
#  ifdef XLAT_STR_458
  + sizeof(XLAT_STR_458)
#  endif
#  ifdef XLAT_STR_459
  + sizeof(XLAT_STR_459)
#  endif
#  ifdef XLAT_STR_460
  + sizeof(XLAT_STR_460)
#  endif
#  ifdef XLAT_STR_461
  + sizeof(XLAT_STR_461)
#  endif
#  ifdef XLAT_STR_462
  + sizeof(XLAT_STR_462)
#  endif
#  ifdef XLAT_STR_463
  + sizeof(XLAT_STR_463)
#  endif
#  ifdef XLAT_STR_464
  + sizeof(XLAT_STR_464)
#  endif
#  ifdef XLAT_STR_465
  + sizeof(XLAT_STR_465)
#  endif
#  ifdef XLAT_STR_466
  + sizeof(XLAT_STR_466)
#  endif
#  ifdef XLAT_STR_467
  + sizeof(XLAT_STR_467)
#  endif
#  ifdef XLAT_STR_468
  + sizeof(XLAT_STR_468)
#  endif
#  ifdef XLAT_STR_469
  + sizeof(XLAT_STR_469)
#  endif
#  ifdef XLAT_STR_470
  + sizeof(XLAT_STR_470)
#  endif
#  ifdef XLAT_STR_471
  + sizeof(XLAT_STR_471)
#  endif
#  ifdef XLAT_STR_472
  + sizeof(XLAT_STR_472)
#  endif
#  ifdef XLAT_STR_473
  + sizeof(XLAT_STR_473)
#  endif
#  ifdef XLAT_STR_474
  + sizeof(XLAT_STR_474)
#  endif
#  ifdef XLAT_STR_475
  + sizeof(XLAT_STR_475)
#  endif
#  ifdef XLAT_STR_476
  + sizeof(XLAT_STR_476)
#  endif
#  ifdef XLAT_STR_477
  + sizeof(XLAT_STR_477)
#  endif
#  ifdef XLAT_STR_478
  + sizeof(XLAT_STR_478)
#  endif
#  ifdef XLAT_STR_479
  + sizeof(XLAT_STR_479)
#  endif
#  ifdef XLAT_STR_480
  + sizeof(XLAT_STR_480)
#  endif
#  ifdef XLAT_STR_481
  + sizeof(XLAT_STR_481)
#  endif
#  ifdef XLAT_STR_482
  + sizeof(XLAT_STR_482)
#  endif
#  ifdef XLAT_STR_483
  + sizeof(XLAT_STR_483)
#  endif
#  ifdef XLAT_STR_484
  + sizeof(XLAT_STR_484)
#  endif
#  ifdef XLAT_STR_485
  + sizeof(XLAT_STR_485)
#  endif
#  ifdef XLAT_STR_486
  + sizeof(XLAT_STR_486)
#  endif
#  ifdef XLAT_STR_487
  + sizeof(XLAT_STR_487)
#  endif
#  ifdef XLAT_STR_488
  + sizeof(XLAT_STR_488)
#  endif
#  ifdef XLAT_STR_489
  + sizeof(XLAT_STR_489)
#  endif
#  ifdef XLAT_STR_490
  + sizeof(XLAT_STR_490)
#  endif
#  ifdef XLAT_STR_491
  + sizeof(XLAT_STR_491)
#  endif
#  ifdef XLAT_STR_492
  + sizeof(XLAT_STR_492)
#  endif
#  ifdef XLAT_STR_493
  + sizeof(XLAT_STR_493)
#  endif
#  ifdef XLAT_STR_494
  + sizeof(XLAT_STR_494)
#  endif
#  ifdef XLAT_STR_495
  + sizeof(XLAT_STR_495)
#  endif
#  ifdef XLAT_STR_496
  + sizeof(XLAT_STR_496)
#  endif
#  ifdef XLAT_STR_497
  + sizeof(XLAT_STR_497)
#  endif
#  ifdef XLAT_STR_498
  + sizeof(XLAT_STR_498)
#  endif
#  ifdef XLAT_STR_499
  + sizeof(XLAT_STR_499)
#  endif
#  ifdef XLAT_STR_500
  + sizeof(XLAT_STR_500)
#  endif
#  ifdef XLAT_STR_501
  + sizeof(XLAT_STR_501)
#  endif
#  ifdef XLAT_STR_502
  + sizeof(XLAT_STR_502)
#  endif
#  ifdef XLAT_STR_503
  + sizeof(XLAT_STR_503)
#  endif
#  ifdef XLAT_STR_504
  + sizeof(XLAT_STR_504)
#  endif
#  ifdef XLAT_STR_505
  + sizeof(XLAT_STR_505)
#  endif
#  ifdef XLAT_STR_506
  + sizeof(XLAT_STR_506)
#  endif
#  ifdef XLAT_STR_507
  + sizeof(XLAT_STR_507)
#  endif
#  ifdef XLAT_STR_508
  + sizeof(XLAT_STR_508)
#  endif
#  ifdef XLAT_STR_509
  + sizeof(XLAT_STR_509)
#  endif
#  ifdef XLAT_STR_510
  + sizeof(XLAT_STR_510)
#  endif
#  ifdef XLAT_STR_511
  + sizeof(XLAT_STR_511)
#  endif
#  ifdef XLAT_STR_512
  + sizeof(XLAT_STR_512)
#  endif
#  ifdef XLAT_STR_513
  + sizeof(XLAT_STR_513)
#  endif
#  ifdef XLAT_STR_514
  + sizeof(XLAT_STR_514)
#  endif
#  ifdef XLAT_STR_515
  + sizeof(XLAT_STR_515)
#  endif
#  ifdef XLAT_STR_516
  + sizeof(XLAT_STR_516)
#  endif
#  ifdef XLAT_STR_517
  + sizeof(XLAT_STR_517)
#  endif
#  ifdef XLAT_STR_518
  + sizeof(XLAT_STR_518)
#  endif
#  ifdef XLAT_STR_519
  + sizeof(XLAT_STR_519)
#  endif
#  ifdef XLAT_STR_520
  + sizeof(XLAT_STR_520)
#  endif
#  ifdef XLAT_STR_521
  + sizeof(XLAT_STR_521)
#  endif
#  ifdef XLAT_STR_522
  + sizeof(XLAT_STR_522)
#  endif
#  ifdef XLAT_STR_523
  + sizeof(XLAT_STR_523)
#  endif
#  ifdef XLAT_STR_524
  + sizeof(XLAT_STR_524)
#  endif
#  ifdef XLAT_STR_525
  + sizeof(XLAT_STR_525)
#  endif
#  ifdef XLAT_STR_526
  + sizeof(XLAT_STR_526)
#  endif
#  ifdef XLAT_STR_527
  + sizeof(XLAT_STR_527)
#  endif
#  ifdef XLAT_STR_528
  + sizeof(XLAT_STR_528)
#  endif
#  ifdef XLAT_STR_529
  + sizeof(XLAT_STR_529)
#  endif
#  ifdef XLAT_STR_530
  + sizeof(XLAT_STR_530)
#  endif
#  ifdef XLAT_STR_531
  + sizeof(XLAT_STR_531)
#  endif
#  ifdef XLAT_STR_532
  + sizeof(XLAT_STR_532)
#  endif
#  ifdef XLAT_STR_533
  + sizeof(XLAT_STR_533)
#  endif
#  ifdef XLAT_STR_534
  + sizeof(XLAT_STR_534)
#  endif
#  ifdef XLAT_STR_535
  + sizeof(XLAT_STR_535)
#  endif
#  ifdef XLAT_STR_536
  + sizeof(XLAT_STR_536)
#  endif
#  ifdef XLAT_STR_537
  + sizeof(XLAT_STR_537)
#  endif
#  ifdef XLAT_STR_538
  + sizeof(XLAT_STR_538)
#  endif
#  ifdef XLAT_STR_539
  + sizeof(XLAT_STR_539)
#  endif
#  ifdef XLAT_STR_540
  + sizeof(XLAT_STR_540)
#  endif
#  ifdef XLAT_STR_541
  + sizeof(XLAT_STR_541)
#  endif
#  ifdef XLAT_STR_542
  + sizeof(XLAT_STR_542)
#  endif
#  ifdef XLAT_STR_543
  + sizeof(XLAT_STR_543)
#  endif
#  ifdef XLAT_STR_544
  + sizeof(XLAT_STR_544)
#  endif
#  ifdef XLAT_STR_545
  + sizeof(XLAT_STR_545)
#  endif
#  ifdef XLAT_STR_546
  + sizeof(XLAT_STR_546)
#  endif
#  ifdef XLAT_STR_547
  + sizeof(XLAT_STR_547)
#  endif
#  ifdef XLAT_STR_548
  + sizeof(XLAT_STR_548)
#  endif
#  ifdef XLAT_STR_549
  + sizeof(XLAT_STR_549)
#  endif
#  ifdef XLAT_STR_550
  + sizeof(XLAT_STR_550)
#  endif
#  ifdef XLAT_STR_551
  + sizeof(XLAT_STR_551)
#  endif
#  ifdef XLAT_STR_552
  + sizeof(XLAT_STR_552)
#  endif
#  ifdef XLAT_STR_553
  + sizeof(XLAT_STR_553)
#  endif
#  ifdef XLAT_STR_554
  + sizeof(XLAT_STR_554)
#  endif
#  ifdef XLAT_STR_555
  + sizeof(XLAT_STR_555)
#  endif
#  ifdef XLAT_STR_556
  + sizeof(XLAT_STR_556)
#  endif
#  ifdef XLAT_STR_557
  + sizeof(XLAT_STR_557)
#  endif
#  ifdef XLAT_STR_558
  + sizeof(XLAT_STR_558)
#  endif
#  ifdef XLAT_STR_559
  + sizeof(XLAT_STR_559)
#  endif
#  ifdef XLAT_STR_560
  + sizeof(XLAT_STR_560)
#  endif
#  ifdef XLAT_STR_561
  + sizeof(XLAT_STR_561)
#  endif
#  ifdef XLAT_STR_562
  + sizeof(XLAT_STR_562)
#  endif
#  ifdef XLAT_STR_563
  + sizeof(XLAT_STR_563)
#  endif
#  ifdef XLAT_STR_564
  + sizeof(XLAT_STR_564)
#  endif
#  ifdef XLAT_STR_565
  + sizeof(XLAT_STR_565)
#  endif
#  ifdef XLAT_STR_566
  + sizeof(XLAT_STR_566)
#  endif
#  ifdef XLAT_STR_567
  + sizeof(XLAT_STR_567)
#  endif
#  ifdef XLAT_STR_568
  + sizeof(XLAT_STR_568)
#  endif
#  ifdef XLAT_STR_569
  + sizeof(XLAT_STR_569)
#  endif
#  ifdef XLAT_STR_570
  + sizeof(XLAT_STR_570)
#  endif
#  ifdef XLAT_STR_571
  + sizeof(XLAT_STR_571)
#  endif
#  ifdef XLAT_STR_572
  + sizeof(XLAT_STR_572)
#  endif
#  ifdef XLAT_STR_573
  + sizeof(XLAT_STR_573)
#  endif
#  ifdef XLAT_STR_574
  + sizeof(XLAT_STR_574)
#  endif
#  ifdef XLAT_STR_575
  + sizeof(XLAT_STR_575)
#  endif
#  ifdef XLAT_STR_576
  + sizeof(XLAT_STR_576)
#  endif
#  ifdef XLAT_STR_577
  + sizeof(XLAT_STR_577)
#  endif
#  ifdef XLAT_STR_578
  + sizeof(XLAT_STR_578)
#  endif
#  ifdef XLAT_STR_579
  + sizeof(XLAT_STR_579)
#  endif
#  ifdef XLAT_STR_580
  + sizeof(XLAT_STR_580)
#  endif
#  ifdef XLAT_STR_581
  + sizeof(XLAT_STR_581)
#  endif
#  ifdef XLAT_STR_582
  + sizeof(XLAT_STR_582)
#  endif
#  ifdef XLAT_STR_583
  + sizeof(XLAT_STR_583)
#  endif
#  ifdef XLAT_STR_584
  + sizeof(XLAT_STR_584)
#  endif
#  ifdef XLAT_STR_585
  + sizeof(XLAT_STR_585)
#  endif
#  ifdef XLAT_STR_586
  + sizeof(XLAT_STR_586)
#  endif
#  ifdef XLAT_STR_587
  + sizeof(XLAT_STR_587)
#  endif
#  ifdef XLAT_STR_588
  + sizeof(XLAT_STR_588)
#  endif
#  ifdef XLAT_STR_589
  + sizeof(XLAT_STR_589)
#  endif
#  ifdef XLAT_STR_590
  + sizeof(XLAT_STR_590)
#  endif
#  ifdef XLAT_STR_591
  + sizeof(XLAT_STR_591)
#  endif
#  ifdef XLAT_STR_592
  + sizeof(XLAT_STR_592)
#  endif
#  ifdef XLAT_STR_593
  + sizeof(XLAT_STR_593)
#  endif
#  ifdef XLAT_STR_594
  + sizeof(XLAT_STR_594)
#  endif
#  ifdef XLAT_STR_595
  + sizeof(XLAT_STR_595)
#  endif
#  ifdef XLAT_STR_596
  + sizeof(XLAT_STR_596)
#  endif
#  ifdef XLAT_STR_597
  + sizeof(XLAT_STR_597)
#  endif
#  ifdef XLAT_STR_598
  + sizeof(XLAT_STR_598)
#  endif
#  ifdef XLAT_STR_599
  + sizeof(XLAT_STR_599)
#  endif
#  ifdef XLAT_STR_600
  + sizeof(XLAT_STR_600)
#  endif
#  ifdef XLAT_STR_601
  + sizeof(XLAT_STR_601)
#  endif
#  ifdef XLAT_STR_602
  + sizeof(XLAT_STR_602)
#  endif
#  ifdef XLAT_STR_603
  + sizeof(XLAT_STR_603)
#  endif
#  ifdef XLAT_STR_604
  + sizeof(XLAT_STR_604)
#  endif
#  ifdef XLAT_STR_605
  + sizeof(XLAT_STR_605)
#  endif
#  ifdef XLAT_STR_606
  + sizeof(XLAT_STR_606)
#  endif
#  ifdef XLAT_STR_607
  + sizeof(XLAT_STR_607)
#  endif
#  ifdef XLAT_STR_608
  + sizeof(XLAT_STR_608)
#  endif
#  ifdef XLAT_STR_609
  + sizeof(XLAT_STR_609)
#  endif
#  ifdef XLAT_STR_610
  + sizeof(XLAT_STR_610)
#  endif
#  ifdef XLAT_STR_611
  + sizeof(XLAT_STR_611)
#  endif
#  ifdef XLAT_STR_612
  + sizeof(XLAT_STR_612)
#  endif
#  ifdef XLAT_STR_613
  + sizeof(XLAT_STR_613)
#  endif
#  ifdef XLAT_STR_614
  + sizeof(XLAT_STR_614)
#  endif
#  ifdef XLAT_STR_615
  + sizeof(XLAT_STR_615)
#  endif
#  ifdef XLAT_STR_616
  + sizeof(XLAT_STR_616)
#  endif
#  ifdef XLAT_STR_617
  + sizeof(XLAT_STR_617)
#  endif
#  ifdef XLAT_STR_618
  + sizeof(XLAT_STR_618)
#  endif
#  ifdef XLAT_STR_619
  + sizeof(XLAT_STR_619)
#  endif
#  ifdef XLAT_STR_620
  + sizeof(XLAT_STR_620)
#  endif
#  ifdef XLAT_STR_621
  + sizeof(XLAT_STR_621)
#  endif
#  ifdef XLAT_STR_622
  + sizeof(XLAT_STR_622)
#  endif
#  ifdef XLAT_STR_623
  + sizeof(XLAT_STR_623)
#  endif
  ,
} };
DIAG_POP_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE

#  undef XLAT_STR_0
#  undef XLAT_VAL_0
#  undef XLAT_STR_1
#  undef XLAT_VAL_1
#  undef XLAT_STR_2
#  undef XLAT_VAL_2
#  undef XLAT_STR_3
#  undef XLAT_VAL_3
#  undef XLAT_STR_4
#  undef XLAT_VAL_4
#  undef XLAT_STR_5
#  undef XLAT_VAL_5
#  undef XLAT_STR_6
#  undef XLAT_VAL_6
#  undef XLAT_STR_7
#  undef XLAT_VAL_7
#  undef XLAT_STR_8
#  undef XLAT_VAL_8
#  undef XLAT_STR_9
#  undef XLAT_VAL_9
#  undef XLAT_STR_10
#  undef XLAT_VAL_10
#  undef XLAT_STR_11
#  undef XLAT_VAL_11
#  undef XLAT_STR_12
#  undef XLAT_VAL_12
#  undef XLAT_STR_13
#  undef XLAT_VAL_13
#  undef XLAT_STR_14
#  undef XLAT_VAL_14
#  undef XLAT_STR_15
#  undef XLAT_VAL_15
#  undef XLAT_STR_16
#  undef XLAT_VAL_16
#  undef XLAT_STR_17
#  undef XLAT_VAL_17
#  undef XLAT_STR_18
#  undef XLAT_VAL_18
#  undef XLAT_STR_19
#  undef XLAT_VAL_19
#  undef XLAT_STR_20
#  undef XLAT_VAL_20
#  undef XLAT_STR_21
#  undef XLAT_VAL_21
#  undef XLAT_STR_22
#  undef XLAT_VAL_22
#  undef XLAT_STR_23
#  undef XLAT_VAL_23
#  undef XLAT_STR_24
#  undef XLAT_VAL_24
#  undef XLAT_STR_25
#  undef XLAT_VAL_25
#  undef XLAT_STR_26
#  undef XLAT_VAL_26
#  undef XLAT_STR_27
#  undef XLAT_VAL_27
#  undef XLAT_STR_28
#  undef XLAT_VAL_28
#  undef XLAT_STR_29
#  undef XLAT_VAL_29
#  undef XLAT_STR_30
#  undef XLAT_VAL_30
#  undef XLAT_STR_31
#  undef XLAT_VAL_31
#  undef XLAT_STR_32
#  undef XLAT_VAL_32
#  undef XLAT_STR_33
#  undef XLAT_VAL_33
#  undef XLAT_STR_34
#  undef XLAT_VAL_34
#  undef XLAT_STR_35
#  undef XLAT_VAL_35
#  undef XLAT_STR_36
#  undef XLAT_VAL_36
#  undef XLAT_STR_37
#  undef XLAT_VAL_37
#  undef XLAT_STR_38
#  undef XLAT_VAL_38
#  undef XLAT_STR_39
#  undef XLAT_VAL_39
#  undef XLAT_STR_40
#  undef XLAT_VAL_40
#  undef XLAT_STR_41
#  undef XLAT_VAL_41
#  undef XLAT_STR_42
#  undef XLAT_VAL_42
#  undef XLAT_STR_43
#  undef XLAT_VAL_43
#  undef XLAT_STR_44
#  undef XLAT_VAL_44
#  undef XLAT_STR_45
#  undef XLAT_VAL_45
#  undef XLAT_STR_46
#  undef XLAT_VAL_46
#  undef XLAT_STR_47
#  undef XLAT_VAL_47
#  undef XLAT_STR_48
#  undef XLAT_VAL_48
#  undef XLAT_STR_49
#  undef XLAT_VAL_49
#  undef XLAT_STR_50
#  undef XLAT_VAL_50
#  undef XLAT_STR_51
#  undef XLAT_VAL_51
#  undef XLAT_STR_52
#  undef XLAT_VAL_52
#  undef XLAT_STR_53
#  undef XLAT_VAL_53
#  undef XLAT_STR_54
#  undef XLAT_VAL_54
#  undef XLAT_STR_55
#  undef XLAT_VAL_55
#  undef XLAT_STR_56
#  undef XLAT_VAL_56
#  undef XLAT_STR_57
#  undef XLAT_VAL_57
#  undef XLAT_STR_58
#  undef XLAT_VAL_58
#  undef XLAT_STR_59
#  undef XLAT_VAL_59
#  undef XLAT_STR_60
#  undef XLAT_VAL_60
#  undef XLAT_STR_61
#  undef XLAT_VAL_61
#  undef XLAT_STR_62
#  undef XLAT_VAL_62
#  undef XLAT_STR_63
#  undef XLAT_VAL_63
#  undef XLAT_STR_64
#  undef XLAT_VAL_64
#  undef XLAT_STR_65
#  undef XLAT_VAL_65
#  undef XLAT_STR_66
#  undef XLAT_VAL_66
#  undef XLAT_STR_67
#  undef XLAT_VAL_67
#  undef XLAT_STR_68
#  undef XLAT_VAL_68
#  undef XLAT_STR_69
#  undef XLAT_VAL_69
#  undef XLAT_STR_70
#  undef XLAT_VAL_70
#  undef XLAT_STR_71
#  undef XLAT_VAL_71
#  undef XLAT_STR_72
#  undef XLAT_VAL_72
#  undef XLAT_STR_73
#  undef XLAT_VAL_73
#  undef XLAT_STR_74
#  undef XLAT_VAL_74
#  undef XLAT_STR_75
#  undef XLAT_VAL_75
#  undef XLAT_STR_76
#  undef XLAT_VAL_76
#  undef XLAT_STR_77
#  undef XLAT_VAL_77
#  undef XLAT_STR_78
#  undef XLAT_VAL_78
#  undef XLAT_STR_79
#  undef XLAT_VAL_79
#  undef XLAT_STR_80
#  undef XLAT_VAL_80
#  undef XLAT_STR_81
#  undef XLAT_VAL_81
#  undef XLAT_STR_82
#  undef XLAT_VAL_82
#  undef XLAT_STR_83
#  undef XLAT_VAL_83
#  undef XLAT_STR_84
#  undef XLAT_VAL_84
#  undef XLAT_STR_85
#  undef XLAT_VAL_85
#  undef XLAT_STR_86
#  undef XLAT_VAL_86
#  undef XLAT_STR_87
#  undef XLAT_VAL_87
#  undef XLAT_STR_88
#  undef XLAT_VAL_88
#  undef XLAT_STR_89
#  undef XLAT_VAL_89
#  undef XLAT_STR_90
#  undef XLAT_VAL_90
#  undef XLAT_STR_91
#  undef XLAT_VAL_91
#  undef XLAT_STR_92
#  undef XLAT_VAL_92
#  undef XLAT_STR_93
#  undef XLAT_VAL_93
#  undef XLAT_STR_94
#  undef XLAT_VAL_94
#  undef XLAT_STR_95
#  undef XLAT_VAL_95
#  undef XLAT_STR_96
#  undef XLAT_VAL_96
#  undef XLAT_STR_97
#  undef XLAT_VAL_97
#  undef XLAT_STR_98
#  undef XLAT_VAL_98
#  undef XLAT_STR_99
#  undef XLAT_VAL_99
#  undef XLAT_STR_100
#  undef XLAT_VAL_100
#  undef XLAT_STR_101
#  undef XLAT_VAL_101
#  undef XLAT_STR_102
#  undef XLAT_VAL_102
#  undef XLAT_STR_103
#  undef XLAT_VAL_103
#  undef XLAT_STR_104
#  undef XLAT_VAL_104
#  undef XLAT_STR_105
#  undef XLAT_VAL_105
#  undef XLAT_STR_106
#  undef XLAT_VAL_106
#  undef XLAT_STR_107
#  undef XLAT_VAL_107
#  undef XLAT_STR_108
#  undef XLAT_VAL_108
#  undef XLAT_STR_109
#  undef XLAT_VAL_109
#  undef XLAT_STR_110
#  undef XLAT_VAL_110
#  undef XLAT_STR_111
#  undef XLAT_VAL_111
#  undef XLAT_STR_112
#  undef XLAT_VAL_112
#  undef XLAT_STR_113
#  undef XLAT_VAL_113
#  undef XLAT_STR_114
#  undef XLAT_VAL_114
#  undef XLAT_STR_115
#  undef XLAT_VAL_115
#  undef XLAT_STR_116
#  undef XLAT_VAL_116
#  undef XLAT_STR_117
#  undef XLAT_VAL_117
#  undef XLAT_STR_118
#  undef XLAT_VAL_118
#  undef XLAT_STR_119
#  undef XLAT_VAL_119
#  undef XLAT_STR_120
#  undef XLAT_VAL_120
#  undef XLAT_STR_121
#  undef XLAT_VAL_121
#  undef XLAT_STR_122
#  undef XLAT_VAL_122
#  undef XLAT_STR_123
#  undef XLAT_VAL_123
#  undef XLAT_STR_124
#  undef XLAT_VAL_124
#  undef XLAT_STR_125
#  undef XLAT_VAL_125
#  undef XLAT_STR_126
#  undef XLAT_VAL_126
#  undef XLAT_STR_127
#  undef XLAT_VAL_127
#  undef XLAT_STR_128
#  undef XLAT_VAL_128
#  undef XLAT_STR_129
#  undef XLAT_VAL_129
#  undef XLAT_STR_130
#  undef XLAT_VAL_130
#  undef XLAT_STR_131
#  undef XLAT_VAL_131
#  undef XLAT_STR_132
#  undef XLAT_VAL_132
#  undef XLAT_STR_133
#  undef XLAT_VAL_133
#  undef XLAT_STR_134
#  undef XLAT_VAL_134
#  undef XLAT_STR_135
#  undef XLAT_VAL_135
#  undef XLAT_STR_136
#  undef XLAT_VAL_136
#  undef XLAT_STR_137
#  undef XLAT_VAL_137
#  undef XLAT_STR_138
#  undef XLAT_VAL_138
#  undef XLAT_STR_139
#  undef XLAT_VAL_139
#  undef XLAT_STR_140
#  undef XLAT_VAL_140
#  undef XLAT_STR_141
#  undef XLAT_VAL_141
#  undef XLAT_STR_142
#  undef XLAT_VAL_142
#  undef XLAT_STR_143
#  undef XLAT_VAL_143
#  undef XLAT_STR_144
#  undef XLAT_VAL_144
#  undef XLAT_STR_145
#  undef XLAT_VAL_145
#  undef XLAT_STR_146
#  undef XLAT_VAL_146
#  undef XLAT_STR_147
#  undef XLAT_VAL_147
#  undef XLAT_STR_148
#  undef XLAT_VAL_148
#  undef XLAT_STR_149
#  undef XLAT_VAL_149
#  undef XLAT_STR_150
#  undef XLAT_VAL_150
#  undef XLAT_STR_151
#  undef XLAT_VAL_151
#  undef XLAT_STR_152
#  undef XLAT_VAL_152
#  undef XLAT_STR_153
#  undef XLAT_VAL_153
#  undef XLAT_STR_154
#  undef XLAT_VAL_154
#  undef XLAT_STR_155
#  undef XLAT_VAL_155
#  undef XLAT_STR_156
#  undef XLAT_VAL_156
#  undef XLAT_STR_157
#  undef XLAT_VAL_157
#  undef XLAT_STR_158
#  undef XLAT_VAL_158
#  undef XLAT_STR_159
#  undef XLAT_VAL_159
#  undef XLAT_STR_160
#  undef XLAT_VAL_160
#  undef XLAT_STR_161
#  undef XLAT_VAL_161
#  undef XLAT_STR_162
#  undef XLAT_VAL_162
#  undef XLAT_STR_163
#  undef XLAT_VAL_163
#  undef XLAT_STR_164
#  undef XLAT_VAL_164
#  undef XLAT_STR_165
#  undef XLAT_VAL_165
#  undef XLAT_STR_166
#  undef XLAT_VAL_166
#  undef XLAT_STR_167
#  undef XLAT_VAL_167
#  undef XLAT_STR_168
#  undef XLAT_VAL_168
#  undef XLAT_STR_169
#  undef XLAT_VAL_169
#  undef XLAT_STR_170
#  undef XLAT_VAL_170
#  undef XLAT_STR_171
#  undef XLAT_VAL_171
#  undef XLAT_STR_172
#  undef XLAT_VAL_172
#  undef XLAT_STR_173
#  undef XLAT_VAL_173
#  undef XLAT_STR_174
#  undef XLAT_VAL_174
#  undef XLAT_STR_175
#  undef XLAT_VAL_175
#  undef XLAT_STR_176
#  undef XLAT_VAL_176
#  undef XLAT_STR_177
#  undef XLAT_VAL_177
#  undef XLAT_STR_178
#  undef XLAT_VAL_178
#  undef XLAT_STR_179
#  undef XLAT_VAL_179
#  undef XLAT_STR_180
#  undef XLAT_VAL_180
#  undef XLAT_STR_181
#  undef XLAT_VAL_181
#  undef XLAT_STR_182
#  undef XLAT_VAL_182
#  undef XLAT_STR_183
#  undef XLAT_VAL_183
#  undef XLAT_STR_184
#  undef XLAT_VAL_184
#  undef XLAT_STR_185
#  undef XLAT_VAL_185
#  undef XLAT_STR_186
#  undef XLAT_VAL_186
#  undef XLAT_STR_187
#  undef XLAT_VAL_187
#  undef XLAT_STR_188
#  undef XLAT_VAL_188
#  undef XLAT_STR_189
#  undef XLAT_VAL_189
#  undef XLAT_STR_190
#  undef XLAT_VAL_190
#  undef XLAT_STR_191
#  undef XLAT_VAL_191
#  undef XLAT_STR_192
#  undef XLAT_VAL_192
#  undef XLAT_STR_193
#  undef XLAT_VAL_193
#  undef XLAT_STR_194
#  undef XLAT_VAL_194
#  undef XLAT_STR_195
#  undef XLAT_VAL_195
#  undef XLAT_STR_196
#  undef XLAT_VAL_196
#  undef XLAT_STR_197
#  undef XLAT_VAL_197
#  undef XLAT_STR_198
#  undef XLAT_VAL_198
#  undef XLAT_STR_199
#  undef XLAT_VAL_199
#  undef XLAT_STR_200
#  undef XLAT_VAL_200
#  undef XLAT_STR_201
#  undef XLAT_VAL_201
#  undef XLAT_STR_202
#  undef XLAT_VAL_202
#  undef XLAT_STR_203
#  undef XLAT_VAL_203
#  undef XLAT_STR_204
#  undef XLAT_VAL_204
#  undef XLAT_STR_205
#  undef XLAT_VAL_205
#  undef XLAT_STR_206
#  undef XLAT_VAL_206
#  undef XLAT_STR_207
#  undef XLAT_VAL_207
#  undef XLAT_STR_208
#  undef XLAT_VAL_208
#  undef XLAT_STR_209
#  undef XLAT_VAL_209
#  undef XLAT_STR_210
#  undef XLAT_VAL_210
#  undef XLAT_STR_211
#  undef XLAT_VAL_211
#  undef XLAT_STR_212
#  undef XLAT_VAL_212
#  undef XLAT_STR_213
#  undef XLAT_VAL_213
#  undef XLAT_STR_214
#  undef XLAT_VAL_214
#  undef XLAT_STR_215
#  undef XLAT_VAL_215
#  undef XLAT_STR_216
#  undef XLAT_VAL_216
#  undef XLAT_STR_217
#  undef XLAT_VAL_217
#  undef XLAT_STR_218
#  undef XLAT_VAL_218
#  undef XLAT_STR_219
#  undef XLAT_VAL_219
#  undef XLAT_STR_220
#  undef XLAT_VAL_220
#  undef XLAT_STR_221
#  undef XLAT_VAL_221
#  undef XLAT_STR_222
#  undef XLAT_VAL_222
#  undef XLAT_STR_223
#  undef XLAT_VAL_223
#  undef XLAT_STR_224
#  undef XLAT_VAL_224
#  undef XLAT_STR_225
#  undef XLAT_VAL_225
#  undef XLAT_STR_226
#  undef XLAT_VAL_226
#  undef XLAT_STR_227
#  undef XLAT_VAL_227
#  undef XLAT_STR_228
#  undef XLAT_VAL_228
#  undef XLAT_STR_229
#  undef XLAT_VAL_229
#  undef XLAT_STR_230
#  undef XLAT_VAL_230
#  undef XLAT_STR_231
#  undef XLAT_VAL_231
#  undef XLAT_STR_232
#  undef XLAT_VAL_232
#  undef XLAT_STR_233
#  undef XLAT_VAL_233
#  undef XLAT_STR_234
#  undef XLAT_VAL_234
#  undef XLAT_STR_235
#  undef XLAT_VAL_235
#  undef XLAT_STR_236
#  undef XLAT_VAL_236
#  undef XLAT_STR_237
#  undef XLAT_VAL_237
#  undef XLAT_STR_238
#  undef XLAT_VAL_238
#  undef XLAT_STR_239
#  undef XLAT_VAL_239
#  undef XLAT_STR_240
#  undef XLAT_VAL_240
#  undef XLAT_STR_241
#  undef XLAT_VAL_241
#  undef XLAT_STR_242
#  undef XLAT_VAL_242
#  undef XLAT_STR_243
#  undef XLAT_VAL_243
#  undef XLAT_STR_244
#  undef XLAT_VAL_244
#  undef XLAT_STR_245
#  undef XLAT_VAL_245
#  undef XLAT_STR_246
#  undef XLAT_VAL_246
#  undef XLAT_STR_247
#  undef XLAT_VAL_247
#  undef XLAT_STR_248
#  undef XLAT_VAL_248
#  undef XLAT_STR_249
#  undef XLAT_VAL_249
#  undef XLAT_STR_250
#  undef XLAT_VAL_250
#  undef XLAT_STR_251
#  undef XLAT_VAL_251
#  undef XLAT_STR_252
#  undef XLAT_VAL_252
#  undef XLAT_STR_253
#  undef XLAT_VAL_253
#  undef XLAT_STR_254
#  undef XLAT_VAL_254
#  undef XLAT_STR_255
#  undef XLAT_VAL_255
#  undef XLAT_STR_256
#  undef XLAT_VAL_256
#  undef XLAT_STR_257
#  undef XLAT_VAL_257
#  undef XLAT_STR_258
#  undef XLAT_VAL_258
#  undef XLAT_STR_259
#  undef XLAT_VAL_259
#  undef XLAT_STR_260
#  undef XLAT_VAL_260
#  undef XLAT_STR_261
#  undef XLAT_VAL_261
#  undef XLAT_STR_262
#  undef XLAT_VAL_262
#  undef XLAT_STR_263
#  undef XLAT_VAL_263
#  undef XLAT_STR_264
#  undef XLAT_VAL_264
#  undef XLAT_STR_265
#  undef XLAT_VAL_265
#  undef XLAT_STR_266
#  undef XLAT_VAL_266
#  undef XLAT_STR_267
#  undef XLAT_VAL_267
#  undef XLAT_STR_268
#  undef XLAT_VAL_268
#  undef XLAT_STR_269
#  undef XLAT_VAL_269
#  undef XLAT_STR_270
#  undef XLAT_VAL_270
#  undef XLAT_STR_271
#  undef XLAT_VAL_271
#  undef XLAT_STR_272
#  undef XLAT_VAL_272
#  undef XLAT_STR_273
#  undef XLAT_VAL_273
#  undef XLAT_STR_274
#  undef XLAT_VAL_274
#  undef XLAT_STR_275
#  undef XLAT_VAL_275
#  undef XLAT_STR_276
#  undef XLAT_VAL_276
#  undef XLAT_STR_277
#  undef XLAT_VAL_277
#  undef XLAT_STR_278
#  undef XLAT_VAL_278
#  undef XLAT_STR_279
#  undef XLAT_VAL_279
#  undef XLAT_STR_280
#  undef XLAT_VAL_280
#  undef XLAT_STR_281
#  undef XLAT_VAL_281
#  undef XLAT_STR_282
#  undef XLAT_VAL_282
#  undef XLAT_STR_283
#  undef XLAT_VAL_283
#  undef XLAT_STR_284
#  undef XLAT_VAL_284
#  undef XLAT_STR_285
#  undef XLAT_VAL_285
#  undef XLAT_STR_286
#  undef XLAT_VAL_286
#  undef XLAT_STR_287
#  undef XLAT_VAL_287
#  undef XLAT_STR_288
#  undef XLAT_VAL_288
#  undef XLAT_STR_289
#  undef XLAT_VAL_289
#  undef XLAT_STR_290
#  undef XLAT_VAL_290
#  undef XLAT_STR_291
#  undef XLAT_VAL_291
#  undef XLAT_STR_292
#  undef XLAT_VAL_292
#  undef XLAT_STR_293
#  undef XLAT_VAL_293
#  undef XLAT_STR_294
#  undef XLAT_VAL_294
#  undef XLAT_STR_295
#  undef XLAT_VAL_295
#  undef XLAT_STR_296
#  undef XLAT_VAL_296
#  undef XLAT_STR_297
#  undef XLAT_VAL_297
#  undef XLAT_STR_298
#  undef XLAT_VAL_298
#  undef XLAT_STR_299
#  undef XLAT_VAL_299
#  undef XLAT_STR_300
#  undef XLAT_VAL_300
#  undef XLAT_STR_301
#  undef XLAT_VAL_301
#  undef XLAT_STR_302
#  undef XLAT_VAL_302
#  undef XLAT_STR_303
#  undef XLAT_VAL_303
#  undef XLAT_STR_304
#  undef XLAT_VAL_304
#  undef XLAT_STR_305
#  undef XLAT_VAL_305
#  undef XLAT_STR_306
#  undef XLAT_VAL_306
#  undef XLAT_STR_307
#  undef XLAT_VAL_307
#  undef XLAT_STR_308
#  undef XLAT_VAL_308
#  undef XLAT_STR_309
#  undef XLAT_VAL_309
#  undef XLAT_STR_310
#  undef XLAT_VAL_310
#  undef XLAT_STR_311
#  undef XLAT_VAL_311
#  undef XLAT_STR_312
#  undef XLAT_VAL_312
#  undef XLAT_STR_313
#  undef XLAT_VAL_313
#  undef XLAT_STR_314
#  undef XLAT_VAL_314
#  undef XLAT_STR_315
#  undef XLAT_VAL_315
#  undef XLAT_STR_316
#  undef XLAT_VAL_316
#  undef XLAT_STR_317
#  undef XLAT_VAL_317
#  undef XLAT_STR_318
#  undef XLAT_VAL_318
#  undef XLAT_STR_319
#  undef XLAT_VAL_319
#  undef XLAT_STR_320
#  undef XLAT_VAL_320
#  undef XLAT_STR_321
#  undef XLAT_VAL_321
#  undef XLAT_STR_322
#  undef XLAT_VAL_322
#  undef XLAT_STR_323
#  undef XLAT_VAL_323
#  undef XLAT_STR_324
#  undef XLAT_VAL_324
#  undef XLAT_STR_325
#  undef XLAT_VAL_325
#  undef XLAT_STR_326
#  undef XLAT_VAL_326
#  undef XLAT_STR_327
#  undef XLAT_VAL_327
#  undef XLAT_STR_328
#  undef XLAT_VAL_328
#  undef XLAT_STR_329
#  undef XLAT_VAL_329
#  undef XLAT_STR_330
#  undef XLAT_VAL_330
#  undef XLAT_STR_331
#  undef XLAT_VAL_331
#  undef XLAT_STR_332
#  undef XLAT_VAL_332
#  undef XLAT_STR_333
#  undef XLAT_VAL_333
#  undef XLAT_STR_334
#  undef XLAT_VAL_334
#  undef XLAT_STR_335
#  undef XLAT_VAL_335
#  undef XLAT_STR_336
#  undef XLAT_VAL_336
#  undef XLAT_STR_337
#  undef XLAT_VAL_337
#  undef XLAT_STR_338
#  undef XLAT_VAL_338
#  undef XLAT_STR_339
#  undef XLAT_VAL_339
#  undef XLAT_STR_340
#  undef XLAT_VAL_340
#  undef XLAT_STR_341
#  undef XLAT_VAL_341
#  undef XLAT_STR_342
#  undef XLAT_VAL_342
#  undef XLAT_STR_343
#  undef XLAT_VAL_343
#  undef XLAT_STR_344
#  undef XLAT_VAL_344
#  undef XLAT_STR_345
#  undef XLAT_VAL_345
#  undef XLAT_STR_346
#  undef XLAT_VAL_346
#  undef XLAT_STR_347
#  undef XLAT_VAL_347
#  undef XLAT_STR_348
#  undef XLAT_VAL_348
#  undef XLAT_STR_349
#  undef XLAT_VAL_349
#  undef XLAT_STR_350
#  undef XLAT_VAL_350
#  undef XLAT_STR_351
#  undef XLAT_VAL_351
#  undef XLAT_STR_352
#  undef XLAT_VAL_352
#  undef XLAT_STR_353
#  undef XLAT_VAL_353
#  undef XLAT_STR_354
#  undef XLAT_VAL_354
#  undef XLAT_STR_355
#  undef XLAT_VAL_355
#  undef XLAT_STR_356
#  undef XLAT_VAL_356
#  undef XLAT_STR_357
#  undef XLAT_VAL_357
#  undef XLAT_STR_358
#  undef XLAT_VAL_358
#  undef XLAT_STR_359
#  undef XLAT_VAL_359
#  undef XLAT_STR_360
#  undef XLAT_VAL_360
#  undef XLAT_STR_361
#  undef XLAT_VAL_361
#  undef XLAT_STR_362
#  undef XLAT_VAL_362
#  undef XLAT_STR_363
#  undef XLAT_VAL_363
#  undef XLAT_STR_364
#  undef XLAT_VAL_364
#  undef XLAT_STR_365
#  undef XLAT_VAL_365
#  undef XLAT_STR_366
#  undef XLAT_VAL_366
#  undef XLAT_STR_367
#  undef XLAT_VAL_367
#  undef XLAT_STR_368
#  undef XLAT_VAL_368
#  undef XLAT_STR_369
#  undef XLAT_VAL_369
#  undef XLAT_STR_370
#  undef XLAT_VAL_370
#  undef XLAT_STR_371
#  undef XLAT_VAL_371
#  undef XLAT_STR_372
#  undef XLAT_VAL_372
#  undef XLAT_STR_373
#  undef XLAT_VAL_373
#  undef XLAT_STR_374
#  undef XLAT_VAL_374
#  undef XLAT_STR_375
#  undef XLAT_VAL_375
#  undef XLAT_STR_376
#  undef XLAT_VAL_376
#  undef XLAT_STR_377
#  undef XLAT_VAL_377
#  undef XLAT_STR_378
#  undef XLAT_VAL_378
#  undef XLAT_STR_379
#  undef XLAT_VAL_379
#  undef XLAT_STR_380
#  undef XLAT_VAL_380
#  undef XLAT_STR_381
#  undef XLAT_VAL_381
#  undef XLAT_STR_382
#  undef XLAT_VAL_382
#  undef XLAT_STR_383
#  undef XLAT_VAL_383
#  undef XLAT_STR_384
#  undef XLAT_VAL_384
#  undef XLAT_STR_385
#  undef XLAT_VAL_385
#  undef XLAT_STR_386
#  undef XLAT_VAL_386
#  undef XLAT_STR_387
#  undef XLAT_VAL_387
#  undef XLAT_STR_388
#  undef XLAT_VAL_388
#  undef XLAT_STR_389
#  undef XLAT_VAL_389
#  undef XLAT_STR_390
#  undef XLAT_VAL_390
#  undef XLAT_STR_391
#  undef XLAT_VAL_391
#  undef XLAT_STR_392
#  undef XLAT_VAL_392
#  undef XLAT_STR_393
#  undef XLAT_VAL_393
#  undef XLAT_STR_394
#  undef XLAT_VAL_394
#  undef XLAT_STR_395
#  undef XLAT_VAL_395
#  undef XLAT_STR_396
#  undef XLAT_VAL_396
#  undef XLAT_STR_397
#  undef XLAT_VAL_397
#  undef XLAT_STR_398
#  undef XLAT_VAL_398
#  undef XLAT_STR_399
#  undef XLAT_VAL_399
#  undef XLAT_STR_400
#  undef XLAT_VAL_400
#  undef XLAT_STR_401
#  undef XLAT_VAL_401
#  undef XLAT_STR_402
#  undef XLAT_VAL_402
#  undef XLAT_STR_403
#  undef XLAT_VAL_403
#  undef XLAT_STR_404
#  undef XLAT_VAL_404
#  undef XLAT_STR_405
#  undef XLAT_VAL_405
#  undef XLAT_STR_406
#  undef XLAT_VAL_406
#  undef XLAT_STR_407
#  undef XLAT_VAL_407
#  undef XLAT_STR_408
#  undef XLAT_VAL_408
#  undef XLAT_STR_409
#  undef XLAT_VAL_409
#  undef XLAT_STR_410
#  undef XLAT_VAL_410
#  undef XLAT_STR_411
#  undef XLAT_VAL_411
#  undef XLAT_STR_412
#  undef XLAT_VAL_412
#  undef XLAT_STR_413
#  undef XLAT_VAL_413
#  undef XLAT_STR_414
#  undef XLAT_VAL_414
#  undef XLAT_STR_415
#  undef XLAT_VAL_415
#  undef XLAT_STR_416
#  undef XLAT_VAL_416
#  undef XLAT_STR_417
#  undef XLAT_VAL_417
#  undef XLAT_STR_418
#  undef XLAT_VAL_418
#  undef XLAT_STR_419
#  undef XLAT_VAL_419
#  undef XLAT_STR_420
#  undef XLAT_VAL_420
#  undef XLAT_STR_421
#  undef XLAT_VAL_421
#  undef XLAT_STR_422
#  undef XLAT_VAL_422
#  undef XLAT_STR_423
#  undef XLAT_VAL_423
#  undef XLAT_STR_424
#  undef XLAT_VAL_424
#  undef XLAT_STR_425
#  undef XLAT_VAL_425
#  undef XLAT_STR_426
#  undef XLAT_VAL_426
#  undef XLAT_STR_427
#  undef XLAT_VAL_427
#  undef XLAT_STR_428
#  undef XLAT_VAL_428
#  undef XLAT_STR_429
#  undef XLAT_VAL_429
#  undef XLAT_STR_430
#  undef XLAT_VAL_430
#  undef XLAT_STR_431
#  undef XLAT_VAL_431
#  undef XLAT_STR_432
#  undef XLAT_VAL_432
#  undef XLAT_STR_433
#  undef XLAT_VAL_433
#  undef XLAT_STR_434
#  undef XLAT_VAL_434
#  undef XLAT_STR_435
#  undef XLAT_VAL_435
#  undef XLAT_STR_436
#  undef XLAT_VAL_436
#  undef XLAT_STR_437
#  undef XLAT_VAL_437
#  undef XLAT_STR_438
#  undef XLAT_VAL_438
#  undef XLAT_STR_439
#  undef XLAT_VAL_439
#  undef XLAT_STR_440
#  undef XLAT_VAL_440
#  undef XLAT_STR_441
#  undef XLAT_VAL_441
#  undef XLAT_STR_442
#  undef XLAT_VAL_442
#  undef XLAT_STR_443
#  undef XLAT_VAL_443
#  undef XLAT_STR_444
#  undef XLAT_VAL_444
#  undef XLAT_STR_445
#  undef XLAT_VAL_445
#  undef XLAT_STR_446
#  undef XLAT_VAL_446
#  undef XLAT_STR_447
#  undef XLAT_VAL_447
#  undef XLAT_STR_448
#  undef XLAT_VAL_448
#  undef XLAT_STR_449
#  undef XLAT_VAL_449
#  undef XLAT_STR_450
#  undef XLAT_VAL_450
#  undef XLAT_STR_451
#  undef XLAT_VAL_451
#  undef XLAT_STR_452
#  undef XLAT_VAL_452
#  undef XLAT_STR_453
#  undef XLAT_VAL_453
#  undef XLAT_STR_454
#  undef XLAT_VAL_454
#  undef XLAT_STR_455
#  undef XLAT_VAL_455
#  undef XLAT_STR_456
#  undef XLAT_VAL_456
#  undef XLAT_STR_457
#  undef XLAT_VAL_457
#  undef XLAT_STR_458
#  undef XLAT_VAL_458
#  undef XLAT_STR_459
#  undef XLAT_VAL_459
#  undef XLAT_STR_460
#  undef XLAT_VAL_460
#  undef XLAT_STR_461
#  undef XLAT_VAL_461
#  undef XLAT_STR_462
#  undef XLAT_VAL_462
#  undef XLAT_STR_463
#  undef XLAT_VAL_463
#  undef XLAT_STR_464
#  undef XLAT_VAL_464
#  undef XLAT_STR_465
#  undef XLAT_VAL_465
#  undef XLAT_STR_466
#  undef XLAT_VAL_466
#  undef XLAT_STR_467
#  undef XLAT_VAL_467
#  undef XLAT_STR_468
#  undef XLAT_VAL_468
#  undef XLAT_STR_469
#  undef XLAT_VAL_469
#  undef XLAT_STR_470
#  undef XLAT_VAL_470
#  undef XLAT_STR_471
#  undef XLAT_VAL_471
#  undef XLAT_STR_472
#  undef XLAT_VAL_472
#  undef XLAT_STR_473
#  undef XLAT_VAL_473
#  undef XLAT_STR_474
#  undef XLAT_VAL_474
#  undef XLAT_STR_475
#  undef XLAT_VAL_475
#  undef XLAT_STR_476
#  undef XLAT_VAL_476
#  undef XLAT_STR_477
#  undef XLAT_VAL_477
#  undef XLAT_STR_478
#  undef XLAT_VAL_478
#  undef XLAT_STR_479
#  undef XLAT_VAL_479
#  undef XLAT_STR_480
#  undef XLAT_VAL_480
#  undef XLAT_STR_481
#  undef XLAT_VAL_481
#  undef XLAT_STR_482
#  undef XLAT_VAL_482
#  undef XLAT_STR_483
#  undef XLAT_VAL_483
#  undef XLAT_STR_484
#  undef XLAT_VAL_484
#  undef XLAT_STR_485
#  undef XLAT_VAL_485
#  undef XLAT_STR_486
#  undef XLAT_VAL_486
#  undef XLAT_STR_487
#  undef XLAT_VAL_487
#  undef XLAT_STR_488
#  undef XLAT_VAL_488
#  undef XLAT_STR_489
#  undef XLAT_VAL_489
#  undef XLAT_STR_490
#  undef XLAT_VAL_490
#  undef XLAT_STR_491
#  undef XLAT_VAL_491
#  undef XLAT_STR_492
#  undef XLAT_VAL_492
#  undef XLAT_STR_493
#  undef XLAT_VAL_493
#  undef XLAT_STR_494
#  undef XLAT_VAL_494
#  undef XLAT_STR_495
#  undef XLAT_VAL_495
#  undef XLAT_STR_496
#  undef XLAT_VAL_496
#  undef XLAT_STR_497
#  undef XLAT_VAL_497
#  undef XLAT_STR_498
#  undef XLAT_VAL_498
#  undef XLAT_STR_499
#  undef XLAT_VAL_499
#  undef XLAT_STR_500
#  undef XLAT_VAL_500
#  undef XLAT_STR_501
#  undef XLAT_VAL_501
#  undef XLAT_STR_502
#  undef XLAT_VAL_502
#  undef XLAT_STR_503
#  undef XLAT_VAL_503
#  undef XLAT_STR_504
#  undef XLAT_VAL_504
#  undef XLAT_STR_505
#  undef XLAT_VAL_505
#  undef XLAT_STR_506
#  undef XLAT_VAL_506
#  undef XLAT_STR_507
#  undef XLAT_VAL_507
#  undef XLAT_STR_508
#  undef XLAT_VAL_508
#  undef XLAT_STR_509
#  undef XLAT_VAL_509
#  undef XLAT_STR_510
#  undef XLAT_VAL_510
#  undef XLAT_STR_511
#  undef XLAT_VAL_511
#  undef XLAT_STR_512
#  undef XLAT_VAL_512
#  undef XLAT_STR_513
#  undef XLAT_VAL_513
#  undef XLAT_STR_514
#  undef XLAT_VAL_514
#  undef XLAT_STR_515
#  undef XLAT_VAL_515
#  undef XLAT_STR_516
#  undef XLAT_VAL_516
#  undef XLAT_STR_517
#  undef XLAT_VAL_517
#  undef XLAT_STR_518
#  undef XLAT_VAL_518
#  undef XLAT_STR_519
#  undef XLAT_VAL_519
#  undef XLAT_STR_520
#  undef XLAT_VAL_520
#  undef XLAT_STR_521
#  undef XLAT_VAL_521
#  undef XLAT_STR_522
#  undef XLAT_VAL_522
#  undef XLAT_STR_523
#  undef XLAT_VAL_523
#  undef XLAT_STR_524
#  undef XLAT_VAL_524
#  undef XLAT_STR_525
#  undef XLAT_VAL_525
#  undef XLAT_STR_526
#  undef XLAT_VAL_526
#  undef XLAT_STR_527
#  undef XLAT_VAL_527
#  undef XLAT_STR_528
#  undef XLAT_VAL_528
#  undef XLAT_STR_529
#  undef XLAT_VAL_529
#  undef XLAT_STR_530
#  undef XLAT_VAL_530
#  undef XLAT_STR_531
#  undef XLAT_VAL_531
#  undef XLAT_STR_532
#  undef XLAT_VAL_532
#  undef XLAT_STR_533
#  undef XLAT_VAL_533
#  undef XLAT_STR_534
#  undef XLAT_VAL_534
#  undef XLAT_STR_535
#  undef XLAT_VAL_535
#  undef XLAT_STR_536
#  undef XLAT_VAL_536
#  undef XLAT_STR_537
#  undef XLAT_VAL_537
#  undef XLAT_STR_538
#  undef XLAT_VAL_538
#  undef XLAT_STR_539
#  undef XLAT_VAL_539
#  undef XLAT_STR_540
#  undef XLAT_VAL_540
#  undef XLAT_STR_541
#  undef XLAT_VAL_541
#  undef XLAT_STR_542
#  undef XLAT_VAL_542
#  undef XLAT_STR_543
#  undef XLAT_VAL_543
#  undef XLAT_STR_544
#  undef XLAT_VAL_544
#  undef XLAT_STR_545
#  undef XLAT_VAL_545
#  undef XLAT_STR_546
#  undef XLAT_VAL_546
#  undef XLAT_STR_547
#  undef XLAT_VAL_547
#  undef XLAT_STR_548
#  undef XLAT_VAL_548
#  undef XLAT_STR_549
#  undef XLAT_VAL_549
#  undef XLAT_STR_550
#  undef XLAT_VAL_550
#  undef XLAT_STR_551
#  undef XLAT_VAL_551
#  undef XLAT_STR_552
#  undef XLAT_VAL_552
#  undef XLAT_STR_553
#  undef XLAT_VAL_553
#  undef XLAT_STR_554
#  undef XLAT_VAL_554
#  undef XLAT_STR_555
#  undef XLAT_VAL_555
#  undef XLAT_STR_556
#  undef XLAT_VAL_556
#  undef XLAT_STR_557
#  undef XLAT_VAL_557
#  undef XLAT_STR_558
#  undef XLAT_VAL_558
#  undef XLAT_STR_559
#  undef XLAT_VAL_559
#  undef XLAT_STR_560
#  undef XLAT_VAL_560
#  undef XLAT_STR_561
#  undef XLAT_VAL_561
#  undef XLAT_STR_562
#  undef XLAT_VAL_562
#  undef XLAT_STR_563
#  undef XLAT_VAL_563
#  undef XLAT_STR_564
#  undef XLAT_VAL_564
#  undef XLAT_STR_565
#  undef XLAT_VAL_565
#  undef XLAT_STR_566
#  undef XLAT_VAL_566
#  undef XLAT_STR_567
#  undef XLAT_VAL_567
#  undef XLAT_STR_568
#  undef XLAT_VAL_568
#  undef XLAT_STR_569
#  undef XLAT_VAL_569
#  undef XLAT_STR_570
#  undef XLAT_VAL_570
#  undef XLAT_STR_571
#  undef XLAT_VAL_571
#  undef XLAT_STR_572
#  undef XLAT_VAL_572
#  undef XLAT_STR_573
#  undef XLAT_VAL_573
#  undef XLAT_STR_574
#  undef XLAT_VAL_574
#  undef XLAT_STR_575
#  undef XLAT_VAL_575
#  undef XLAT_STR_576
#  undef XLAT_VAL_576
#  undef XLAT_STR_577
#  undef XLAT_VAL_577
#  undef XLAT_STR_578
#  undef XLAT_VAL_578
#  undef XLAT_STR_579
#  undef XLAT_VAL_579
#  undef XLAT_STR_580
#  undef XLAT_VAL_580
#  undef XLAT_STR_581
#  undef XLAT_VAL_581
#  undef XLAT_STR_582
#  undef XLAT_VAL_582
#  undef XLAT_STR_583
#  undef XLAT_VAL_583
#  undef XLAT_STR_584
#  undef XLAT_VAL_584
#  undef XLAT_STR_585
#  undef XLAT_VAL_585
#  undef XLAT_STR_586
#  undef XLAT_VAL_586
#  undef XLAT_STR_587
#  undef XLAT_VAL_587
#  undef XLAT_STR_588
#  undef XLAT_VAL_588
#  undef XLAT_STR_589
#  undef XLAT_VAL_589
#  undef XLAT_STR_590
#  undef XLAT_VAL_590
#  undef XLAT_STR_591
#  undef XLAT_VAL_591
#  undef XLAT_STR_592
#  undef XLAT_VAL_592
#  undef XLAT_STR_593
#  undef XLAT_VAL_593
#  undef XLAT_STR_594
#  undef XLAT_VAL_594
#  undef XLAT_STR_595
#  undef XLAT_VAL_595
#  undef XLAT_STR_596
#  undef XLAT_VAL_596
#  undef XLAT_STR_597
#  undef XLAT_VAL_597
#  undef XLAT_STR_598
#  undef XLAT_VAL_598
#  undef XLAT_STR_599
#  undef XLAT_VAL_599
#  undef XLAT_STR_600
#  undef XLAT_VAL_600
#  undef XLAT_STR_601
#  undef XLAT_VAL_601
#  undef XLAT_STR_602
#  undef XLAT_VAL_602
#  undef XLAT_STR_603
#  undef XLAT_VAL_603
#  undef XLAT_STR_604
#  undef XLAT_VAL_604
#  undef XLAT_STR_605
#  undef XLAT_VAL_605
#  undef XLAT_STR_606
#  undef XLAT_VAL_606
#  undef XLAT_STR_607
#  undef XLAT_VAL_607
#  undef XLAT_STR_608
#  undef XLAT_VAL_608
#  undef XLAT_STR_609
#  undef XLAT_VAL_609
#  undef XLAT_STR_610
#  undef XLAT_VAL_610
#  undef XLAT_STR_611
#  undef XLAT_VAL_611
#  undef XLAT_STR_612
#  undef XLAT_VAL_612
#  undef XLAT_STR_613
#  undef XLAT_VAL_613
#  undef XLAT_STR_614
#  undef XLAT_VAL_614
#  undef XLAT_STR_615
#  undef XLAT_VAL_615
#  undef XLAT_STR_616
#  undef XLAT_VAL_616
#  undef XLAT_STR_617
#  undef XLAT_VAL_617
#  undef XLAT_STR_618
#  undef XLAT_VAL_618
#  undef XLAT_STR_619
#  undef XLAT_VAL_619
#  undef XLAT_STR_620
#  undef XLAT_VAL_620
#  undef XLAT_STR_621
#  undef XLAT_VAL_621
#  undef XLAT_STR_622
#  undef XLAT_VAL_622
#  undef XLAT_STR_623
#  undef XLAT_VAL_623
# endif /* !IN_MPERS */

#endif /* !XLAT_MACROS_ONLY */
